@@ -14,10 +14,9 @@ import contextlib
 from PyQt6.QtCore import pyqtSignal, QObject, QProcess, QCoreApplication
 from PyQt6.QtWidgets import QDialog
 
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets import EricMessageBox
 
-import Globals
-import Preferences
+from eric7 import Globals, Preferences
 
 from . import rootPrefix, condaVersion
 from .CondaExecDialog import CondaExecDialog
@@ -498,7 +497,9 @@ class Conda(QObject):
             raise RuntimeError("One of 'name' or 'prefix' must be given.")
 
         if packages:
-            from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+            from eric7.UI.DeleteFilesConfirmationDialog import (
+                DeleteFilesConfirmationDialog,
+            )
 
             dlg = DeleteFilesConfirmationDialog(
                 self.parent(),
