@@ -20,15 +20,15 @@ from PyQt6.QtWidgets import (
     QDialog,
 )
 
-from EricWidgets import EricFileDialog, EricMessageBox, EricTextInputDialog
-from EricWidgets.EricApplication import ericApp
-from EricGui.EricOverrideCursor import EricOverrideCursor
+from eric7.EricWidgets import EricFileDialog, EricMessageBox, EricTextInputDialog
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricGui.EricOverrideCursor import EricOverrideCursor
 
 from .Ui_CondaPackagesWidget import Ui_CondaPackagesWidget
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
-import CondaInterface
+from eric7 import CondaInterface
 
 
 class CondaPackagesWidget(QWidget, Ui_CondaPackagesWidget):
@@ -75,7 +75,7 @@ class CondaPackagesWidget(QWidget, Ui_CondaPackagesWidget):
         self.statusLabel.hide()
 
         self.condaMenuButton.setObjectName("conda_supermenu_button")
-        self.condaMenuButton.setIcon(UI.PixmapCache.getIcon("superMenu"))
+        self.condaMenuButton.setIcon(EricPixmapCache.getIcon("superMenu"))
         self.condaMenuButton.setToolTip(self.tr("Conda Menu"))
         self.condaMenuButton.setPopupMode(QToolButton.ToolButtonPopupMode.InstantPopup)
         self.condaMenuButton.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonIconOnly)
@@ -83,14 +83,14 @@ class CondaPackagesWidget(QWidget, Ui_CondaPackagesWidget):
         self.condaMenuButton.setAutoRaise(True)
         self.condaMenuButton.setShowMenuInside(True)
 
-        self.refreshButton.setIcon(UI.PixmapCache.getIcon("reload"))
-        self.upgradeButton.setIcon(UI.PixmapCache.getIcon("1uparrow"))
-        self.upgradeAllButton.setIcon(UI.PixmapCache.getIcon("2uparrow"))
-        self.uninstallButton.setIcon(UI.PixmapCache.getIcon("minus"))
-        self.searchToggleButton.setIcon(UI.PixmapCache.getIcon("find"))
-        self.searchButton.setIcon(UI.PixmapCache.getIcon("findNext"))
-        self.installButton.setIcon(UI.PixmapCache.getIcon("plus"))
-        self.showDetailsButton.setIcon(UI.PixmapCache.getIcon("info"))
+        self.refreshButton.setIcon(EricPixmapCache.getIcon("reload"))
+        self.upgradeButton.setIcon(EricPixmapCache.getIcon("1uparrow"))
+        self.upgradeAllButton.setIcon(EricPixmapCache.getIcon("2uparrow"))
+        self.uninstallButton.setIcon(EricPixmapCache.getIcon("minus"))
+        self.searchToggleButton.setIcon(EricPixmapCache.getIcon("find"))
+        self.searchButton.setIcon(EricPixmapCache.getIcon("findNext"))
+        self.installButton.setIcon(EricPixmapCache.getIcon("plus"))
+        self.showDetailsButton.setIcon(EricPixmapCache.getIcon("info"))
 
         if CondaInterface.condaVersion() >= (4, 4, 0):
             self.searchOptionsWidget.hide()
@@ -706,7 +706,7 @@ class CondaPackagesWidget(QWidget, Ui_CondaPackagesWidget):
         """
         Private slot to edit the user configuration.
         """
-        from QScintilla.MiniEditor import MiniEditor
+        from eric7.QScintilla.MiniEditor import MiniEditor
 
         cfgFile = CondaInterface.userConfiguration()
         if not cfgFile:
