@@ -19,6 +19,7 @@ import select
 import signal
 import socket
 import sys
+import sysconfig
 import traceback
 import types
 
@@ -164,8 +165,8 @@ class DebugClientBase:
         self.buffer = ""
 
         # The precompiled regexp to filter variables against
-        self.globalsFilterObjects = None
-        self.localsFilterObjects = None
+        self.globalsFilterObjects = (None, False)  # filter regexp, show flag
+        self.localsFilterObjects = (None, False)  # filter regexp, show flag
 
         self._fncache = {}
         self.dircache = []
@@ -445,6 +446,12 @@ class DebugClientBase:
             self.dircache = []
             self.disassembly = None
             sys.argv = []
+            if params["argv"] and params["argv"][0].startswith("--plugin="):
+                # we are debugging an eric IDE plug-in
+                ide = os.path.join(
+                    sysconfig.get_path("platlib"), "eric7", "eric7_ide.py"
+                )
+                params["filename"] = ide
             self.__setCoding(params["filename"])
             sys.argv.append(params["filename"])
             sys.argv.extend(params["argv"])
@@ -486,6 +493,12 @@ class DebugClientBase:
         elif method == "RequestRun":
             self.disassembly = None
             sys.argv = []
+            if params["argv"] and params["argv"][0].startswith("--plugin="):
+                # we are executing an eric IDE plug-in
+                ide = os.path.join(
+                    sysconfig.get_path("platlib"), "eric7", "eric7_ide.py"
+                )
+                params["filename"] = ide
             self.__setCoding(params["filename"])
             sys.argv.append(params["filename"])
             sys.argv.extend(params["argv"])
@@ -522,6 +535,12 @@ class DebugClientBase:
 
             self.disassembly = None
             sys.argv = []
+            if params["argv"] and params["argv"][0].startswith("--plugin="):
+                # we are coverage testing an eric IDE plug-in
+                ide = os.path.join(
+                    sysconfig.get_path("platlib"), "eric7", "eric7_ide.py"
+                )
+                params["filename"] = ide
             self.__setCoding(params["filename"])
             sys.argv.append(params["filename"])
             sys.argv.extend(params["argv"])
@@ -562,6 +581,12 @@ class DebugClientBase:
 
             self.disassembly = None
             sys.argv = []
+            if params["argv"] and params["argv"][0].startswith("--plugin="):
+                # we are profiling an eric IDE plug-in
+                ide = os.path.join(
+                    sysconfig.get_path("platlib"), "eric7", "eric7_ide.py"
+                )
+                params["filename"] = ide
             self.__setCoding(params["filename"])
             sys.argv.append(params["filename"])
             sys.argv.extend(params["argv"])
@@ -1377,11 +1402,11 @@ class DebugClientBase:
             frmnr -= 1
 
         if f is None:
-            if scope:
+            if scope == 1:
                 varDict = self.debugMod.__dict__
             else:
                 scope = -2
-        elif scope:
+        elif scope == 1:
             varDict = f.f_globals
         elif f.f_globals is f.f_locals:
             scope = -1
@@ -1410,7 +1435,7 @@ class DebugClientBase:
         Private method to return the variables of a frame to the debug server.
 
         @param var list encoded name of the requested variable
-        @type list of str
+        @type list of str and int
         @param frmnr distance of frame reported on. 0 is the current frame
         @type int
         @param scope 1 to report global variables, 0 for local variables
@@ -1429,11 +1454,11 @@ class DebugClientBase:
             frmnr -= 1
 
         if f is None:
-            if scope:
+            if scope == 1:
                 varDict = self.debugMod.__dict__
             else:
                 scope = -1
-        elif scope:
+        elif scope == 1:
             varDict = f.f_globals
         elif f.f_globals is f.f_locals:
             scope = -1
@@ -1448,7 +1473,9 @@ class DebugClientBase:
             idx, varDict = next(varGen)
             if idx != -2:  # more elements available
                 var.insert(0, idx)
-                varlist = self.__formatVariablesList(varDict, scope, filterList)
+                varlist = self.__formatVariablesList(
+                    varDict, scope, filterList, var[1:]
+                )
         elif scope != -1:
             variable = varDict
             # Lookup the wanted attribute
@@ -1473,7 +1500,9 @@ class DebugClientBase:
 
                     idx, varDict = next(varGen)
                     if idx != -2:  # more elements available
-                        varlist = self.__formatVariablesList(varDict, scope, filterList)
+                        varlist = self.__formatVariablesList(
+                            varDict, scope, filterList, var
+                        )
 
             var.insert(0, idx)
 
@@ -1486,7 +1515,7 @@ class DebugClientBase:
             },
         )
 
-    def __formatVariablesList(self, variables, scope, filterList=None):
+    def __formatVariablesList(self, variables, scope, filterList=None, var=None):
         """
         Private method to produce a formated variables list.
 
@@ -1500,13 +1529,16 @@ class DebugClientBase:
         @type list of tuple of (str, Any) or (str, str, Any)
         @param scope 1 to filter using the globals filter, 0 using the locals
             filter.
-            Variables are only added to the list, if their name do not match
-            any of the filter expressions.
+            Variables are only added to the list, if their access path does not match
+            any of the filter expressions and the 'show/no show' indication.
         @type int
         @param filterList list of variable types to be filtered.
             Variables are only added to the list, if their type is not
-            contained in the filter list.
-        @type list of str
+            contained in the filter list. (defaults to None)
+        @type list of str (optional)
+        @param var list encoded name of the requested variable (access path) (defaults
+            to None)
+        @type list of str and int (optional)
         @return A tuple consisting of a list of formatted variables. Each
             variable entry is a tuple of three elements, the variable name,
             its type and value.
@@ -1515,10 +1547,13 @@ class DebugClientBase:
         filterList = set(filterList or [])
 
         varlist = []
-        patternFilterObjects = (
+        patternFilterObjects, showFlag = (
             self.globalsFilterObjects if scope else self.localsFilterObjects
         )
 
+        if var:
+            var = ".".join(str(v) for v in var)
+
         for variabel in variables:
             valtype = None
             rvalue = None
@@ -1530,7 +1565,11 @@ class DebugClientBase:
                 key, valtype, rvalue = variabel
 
             # filter based on the filter pattern
-            if patternFilterObjects and patternFilterObjects.match(str(key)):
+            keyPath = "{0}.{1}".format(var, key) if var else key
+            if patternFilterObjects and (
+                (not showFlag and patternFilterObjects.match(str(keyPath)))
+                or (showFlag and not patternFilterObjects.match(str(keyPath)))
+            ):
                 continue
 
             # filter hidden attributes (filter #0)
@@ -1649,15 +1688,25 @@ class DebugClientBase:
         @param filterString string of filter patterns separated by ';'
         """
         patternFilterObjects = None
-        if filterString.strip():
-            pattern = filterString.replace(";", "|")
-            with contextlib.suppress(re.error):
-                patternFilterObjects = re.compile(pattern)
+        filterString = filterString.strip()
+        if filterString:
+            if filterString[0] == "~":
+                showFlag = False
+                filterString = filterString[1:].strip()
+            else:
+                showFlag = True
+            if filterString:
+                filterList = filterString.split(";")
+                pattern = "|".join(f.strip() for f in filterList)
+                with contextlib.suppress(re.error):
+                    patternFilterObjects = re.compile(pattern)
+        else:
+            showFlag = False
 
         if scope:
-            self.globalsFilterObjects = patternFilterObjects
+            self.globalsFilterObjects = (patternFilterObjects, showFlag)
         else:
-            self.localsFilterObjects = patternFilterObjects
+            self.localsFilterObjects = (patternFilterObjects, showFlag)
 
     def __completionList(self, text):
         """
