@@ -12,11 +12,11 @@ import pathlib
 from PyQt6.QtCore import pyqtSignal, Qt, QItemSelectionModel, QSortFilterProxyModel
 from PyQt6.QtWidgets import QTreeView, QAbstractItemView, QHeaderView, QMenu, QDialog
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
-from Globals import recentNameBreakpointFiles, recentNameBreakpointConditions
+from eric7.Globals import recentNameBreakpointFiles, recentNameBreakpointConditions
 
-import Preferences
+from eric7 import Preferences
 
 
 class BreakPointViewer(QTreeView):
