@@ -11,10 +11,10 @@ import os
 
 from PyQt6.QtWidgets import QDialog, QDialogButtonBox, QComboBox, QInputDialog
 
-from EricWidgets.EricPathPicker import EricPathPickerModes
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricPathPicker import EricPathPickerModes
+from eric7.EricWidgets.EricApplication import ericApp
 
-import Preferences
+from eric7 import Preferences
 
 
 class StartDialog(QDialog):
@@ -128,6 +128,11 @@ class StartDialog(QDialog):
         self.ui.setupUi(self)
 
         self.ui.venvComboBox.addItem("")
+        projectEnvironmentString = (
+            ericApp().getObject("DebugServer").getProjectEnvironmentString()
+        )
+        if projectEnvironmentString:
+            self.ui.venvComboBox.addItem(projectEnvironmentString)
         self.ui.venvComboBox.addItems(
             sorted(ericApp().getObject("VirtualEnvManager").getVirtualenvNames())
         )
