@@ -15,8 +15,8 @@ import sys
 import re
 import contextlib
 
-from Utilities import html_uencode
-from Utilities.ModuleParser import RB_SOURCE, Function
+from eric7.Utilities import html_uencode
+from eric7.Utilities.ModuleParser import RB_SOURCE, Function
 
 from . import TemplatesListsStyleCSS
 
