@@ -13,7 +13,7 @@ import os
 import shutil
 import subprocess  # secok
 
-from Utilities import joinext, html_encode, getQtBinariesPath, generateQtToolName
+from eric7.Utilities import joinext, html_encode, getQtBinariesPath, generateQtToolName
 
 HelpCollection = r"""<?xml version="1.0" encoding="utf-8" ?>
 <QHelpCollectionProject version="1.0">
