@@ -8,6 +8,6 @@ Package implementing the source code documentation tools.
 """
 
 supportedExtensionsDictForApis = {
-    "Python3": [".py", ".pyw", ".py3", ".pyw3"],
+    "Python3": [".py", ".pyw", ".py3", ".pyw3", ".pyi"],
     "Ruby": [".rb"],
 }
