@@ -16,14 +16,12 @@ from PyQt6.QtWidgets import QDialog, QTreeWidgetItem
 with contextlib.suppress(ImportError):
     from PyQt6.QtNetwork import QSslCertificate, QSslConfiguration, QSsl
 
-from EricWidgets import EricMessageBox, EricFileDialog
+from eric7.EricWidgets import EricMessageBox, EricFileDialog
 
 from .Ui_EricSslCertificatesDialog import Ui_EricSslCertificatesDialog
 
-import Preferences
-import Utilities
-import UI.PixmapCache
-import Globals
+from eric7 import Globals, Preferences, Utilities
+from eric7.EricGui import EricPixmapCache
 
 
 class EricSslCertificatesDialog(QDialog, Ui_EricSslCertificatesDialog):
@@ -42,15 +40,15 @@ class EricSslCertificatesDialog(QDialog, Ui_EricSslCertificatesDialog):
         super().__init__(parent)
         self.setupUi(self)
 
-        self.serversViewButton.setIcon(UI.PixmapCache.getIcon("certificates"))
-        self.serversDeleteButton.setIcon(UI.PixmapCache.getIcon("certificateDelete"))
-        self.serversExportButton.setIcon(UI.PixmapCache.getIcon("certificateExport"))
-        self.serversImportButton.setIcon(UI.PixmapCache.getIcon("certificateImport"))
+        self.serversViewButton.setIcon(EricPixmapCache.getIcon("certificates"))
+        self.serversDeleteButton.setIcon(EricPixmapCache.getIcon("certificateDelete"))
+        self.serversExportButton.setIcon(EricPixmapCache.getIcon("certificateExport"))
+        self.serversImportButton.setIcon(EricPixmapCache.getIcon("certificateImport"))
 
-        self.caViewButton.setIcon(UI.PixmapCache.getIcon("certificates"))
-        self.caDeleteButton.setIcon(UI.PixmapCache.getIcon("certificateDelete"))
-        self.caExportButton.setIcon(UI.PixmapCache.getIcon("certificateExport"))
-        self.caImportButton.setIcon(UI.PixmapCache.getIcon("certificateImport"))
+        self.caViewButton.setIcon(EricPixmapCache.getIcon("certificates"))
+        self.caDeleteButton.setIcon(EricPixmapCache.getIcon("certificateDelete"))
+        self.caExportButton.setIcon(EricPixmapCache.getIcon("certificateExport"))
+        self.caImportButton.setIcon(EricPixmapCache.getIcon("certificateImport"))
 
         self.__populateServerCertificatesTree()
         self.__populateCaCertificatesTree()
@@ -124,7 +122,7 @@ class EricSslCertificatesDialog(QDialog, Ui_EricSslCertificatesDialog):
         Private slot to show data of the selected server certificate.
         """
         with contextlib.suppress(ImportError):
-            from EricNetwork.EricSslCertificatesInfoDialog import (
+            from eric7.EricNetwork.EricSslCertificatesInfoDialog import (
                 EricSslCertificatesInfoDialog,
             )
 
@@ -343,7 +341,7 @@ class EricSslCertificatesDialog(QDialog, Ui_EricSslCertificatesDialog):
         Private slot to show data of the selected CA certificate.
         """
         with contextlib.suppress(ImportError):
-            from EricNetwork.EricSslCertificatesInfoDialog import (
+            from eric7.EricNetwork.EricSslCertificatesInfoDialog import (
                 EricSslCertificatesInfoDialog,
             )
 
