@@ -13,11 +13,11 @@ from PyQt6.QtCore import pyqtSignal, pyqtSlot, Qt, QCoreApplication
 from PyQt6.QtGui import QColor, QIcon, QCursor, QPalette
 from PyQt6.QtWidgets import QWidget, QBoxLayout, QWIDGETSIZE_MAX, QMenu
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .EricClickableLabel import EricClickableLabel
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
 
 class EricIconBar(QWidget):
@@ -265,7 +265,7 @@ class EricIconBar(QWidget):
                 int(self.__barSize * self.MoreLabelAspect), self.__barSize
             )
             self.__moreLabel.setPixmap(
-                UI.PixmapCache.getIcon("sbDotsH96").pixmap(
+                EricPixmapCache.getIcon("sbDotsH96").pixmap(
                     int(self.__barSize * self.MoreLabelAspect), self.__barSize
                 )
             )
@@ -274,7 +274,7 @@ class EricIconBar(QWidget):
                 self.__barSize, int(self.__barSize * self.MoreLabelAspect)
             )
             self.__moreLabel.setPixmap(
-                UI.PixmapCache.getIcon("sbDotsV96").pixmap(
+                EricPixmapCache.getIcon("sbDotsV96").pixmap(
                     self.__barSize, int(self.__barSize * self.MoreLabelAspect)
                 )
             )
