@@ -19,11 +19,11 @@ from PyQt6.QtWidgets import (
     QAbstractButton,
 )
 
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets import EricMessageBox
 
 from .Ui_EricToolBarDialog import Ui_EricToolBarDialog
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
 
 class EricToolBarItem:
@@ -78,10 +78,10 @@ class EricToolBarDialog(QDialog, Ui_EricToolBarDialog):
         self.__toolBarItemToWidgetActionID = {}
         # maps toolbar item IDs to widget action IDs
 
-        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow"))
-        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow"))
-        self.leftButton.setIcon(UI.PixmapCache.getIcon("1leftarrow"))
-        self.rightButton.setIcon(UI.PixmapCache.getIcon("1rightarrow"))
+        self.upButton.setIcon(EricPixmapCache.getIcon("1uparrow"))
+        self.downButton.setIcon(EricPixmapCache.getIcon("1downarrow"))
+        self.leftButton.setIcon(EricPixmapCache.getIcon("1leftarrow"))
+        self.rightButton.setIcon(EricPixmapCache.getIcon("1rightarrow"))
 
         self.__restoreDefaultsButton = self.buttonBox.button(
             QDialogButtonBox.StandardButton.RestoreDefaults
