@@ -12,7 +12,7 @@ import os
 from .Config import multiProjectFileFormatVersion
 from .XMLStreamReaderBase import XMLStreamReaderBase
 
-import Utilities
+from eric7 import Utilities
 
 
 class MultiProjectReader(XMLStreamReaderBase):
