@@ -10,7 +10,7 @@ Module to read the plug-in repository contents file.
 from .Config import pluginRepositoryFileFormatVersion
 from .XMLStreamReaderBase import XMLStreamReaderBase
 
-import Preferences
+from eric7 import Preferences
 
 
 class PluginRepositoryReader(XMLStreamReaderBase):
