@@ -10,14 +10,14 @@ Module implementing a class for reading an XML tasks file.
 import time
 import contextlib
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .Config import tasksFileFormatVersion
 from .XMLStreamReaderBase import XMLStreamReaderBase
 
-from Tasks.Task import TaskType, TaskPriority
+from eric7.Tasks.Task import TaskType, TaskPriority
 
-import Utilities
+from eric7 import Utilities
 
 
 class TasksReader(XMLStreamReaderBase):
