@@ -15,6 +15,7 @@ import contextlib
 import os
 import re
 import sys
+import sysconfig
 
 from PyQt6.QtCore import (
     QByteArray,
@@ -274,11 +275,19 @@ def getPythonLibraryDirectory():
     @return path to the Python library directory
     @rtype str
     """
-    import sysconfig
-
     return sysconfig.get_path("platlib")
 
 
+def getPythonScriptsDirectory():
+    """
+    Function to determine the path to Python's scripts directory.
+
+    @return path to the Python scripts directory
+    @rtype str
+    """
+    return sysconfig.get_path("scripts")
+
+
 def getPyQt6ModulesDirectory():
     """
     Function to determine the path to PyQt6 modules directory.
@@ -304,7 +313,7 @@ def getPyQtToolsPath(version=5):
     @return path to the PyQt tools
     @rtype str
     """
-    import Preferences
+    from eric7 import Preferences
 
     toolsPath = ""
 
@@ -320,7 +329,7 @@ def getPyQtToolsPath(version=5):
     if not toolsPath:
         program = "pylupdate{0}".format(version)
         if venvName:
-            from EricWidgets.EricApplication import ericApp
+            from eric7.EricWidgets.EricApplication import ericApp
 
             venvManager = ericApp().getObject("VirtualEnvManager")
             dirName = venvManager.getVirtualenvDirectory(venvName)
@@ -352,7 +361,7 @@ def getQtBinariesPath(libexec=False):
     @return path of the Qt binaries
     @rtype str
     """
-    import Preferences
+    from eric7 import Preferences
 
     binPath = ""
 
@@ -402,15 +411,10 @@ def getQtBinariesPath(libexec=False):
         program = "designer"
         if isWindowsPlatform():
             program += ".exe"
-            dirName = os.path.dirname(sys.executable)
-            if os.path.exists(os.path.join(dirName, program)):
-                binPath = dirName
-            elif os.path.exists(os.path.join(dirName, "Scripts", program)):
-                binPath = os.path.join(dirName, "Scripts")
-        else:
-            dirName = os.path.dirname(sys.executable)
-            if os.path.exists(os.path.join(dirName, program)):
-                binPath = dirName
+
+        progPath = os.path.join(getPythonScriptsDirectory(), program)
+        if os.path.exists(progPath):
+            binPath = getPythonScriptsDirectory()
 
     return QDir.toNativeSeparators(binPath)
 
