@@ -13,13 +13,12 @@ import time
 
 from PyQt6.QtWidgets import QApplication, QInputDialog
 
-from EricWidgets import EricMessageBox
-from EricWidgets.EricProgressDialog import EricProgressDialog
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricProgressDialog import EricProgressDialog
 
 from .UMLDiagramBuilder import UMLDiagramBuilder
 
-import Utilities
-import Preferences
+from eric7 import Preferences, Utilities
 
 
 class ApplicationDiagramBuilder(UMLDiagramBuilder):
@@ -58,7 +57,7 @@ class ApplicationDiagramBuilder(UMLDiagramBuilder):
         @return dictionary of modules contained in the application
         @rtype dict
         """
-        import Utilities.ModuleParser
+        from eric7.Utilities import ModuleParser
 
         extensions = Preferences.getPython("Python3Extensions") + [".rb"]
         moduleDict = {}
@@ -89,7 +88,7 @@ class ApplicationDiagramBuilder(UMLDiagramBuilder):
                 if module.endswith("__init__.py"):
                     continue
                 try:
-                    mod = Utilities.ModuleParser.readModule(
+                    mod = ModuleParser.readModule(
                         module, extensions=extensions, caching=False
                     )
                 except ImportError:
