@@ -13,12 +13,11 @@ import time
 
 from PyQt6.QtWidgets import QApplication, QGraphicsTextItem
 
-from EricWidgets.EricProgressDialog import EricProgressDialog
+from eric7.EricWidgets.EricProgressDialog import EricProgressDialog
 
 from .UMLDiagramBuilder import UMLDiagramBuilder
 
-import Utilities
-import Preferences
+from eric7 import Preferences, Utilities
 
 
 class ImportsDiagramBuilder(UMLDiagramBuilder):
@@ -88,7 +87,7 @@ class ImportsDiagramBuilder(UMLDiagramBuilder):
         @return dictionary of modules contained in the package
         @rtype dict
         """
-        import Utilities.ModuleParser
+        from eric7.Utilities import ModuleParser
 
         extensions = Preferences.getPython("Python3Extensions")
         moduleDict = {}
@@ -119,7 +118,7 @@ class ImportsDiagramBuilder(UMLDiagramBuilder):
                     QApplication.processEvents()
                     now = time.monotonic()
                 try:
-                    mod = Utilities.ModuleParser.readModule(
+                    mod = ModuleParser.readModule(
                         module, extensions=extensions, caching=False
                     )
                 except ImportError:
