@@ -14,12 +14,11 @@ from itertools import zip_longest
 
 from PyQt6.QtWidgets import QApplication, QGraphicsTextItem
 
-from EricWidgets.EricProgressDialog import EricProgressDialog
+from eric7.EricWidgets.EricProgressDialog import EricProgressDialog
 
 from .UMLDiagramBuilder import UMLDiagramBuilder
 
-import Utilities
-import Preferences
+from eric7 import Preferences, Utilities
 
 
 class PackageDiagramBuilder(UMLDiagramBuilder):
@@ -87,7 +86,7 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
         @return dictionary of modules contained in the package
         @rtype dict
         """
-        import Utilities.ModuleParser
+        from eric7.Utilities import ModuleParser
 
         supportedExt = [
             "*{0}".format(ext) for ext in Preferences.getPython("Python3Extensions")
@@ -119,7 +118,7 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
                     QApplication.processEvents()
                     now = time.monotonic()
                 try:
-                    mod = Utilities.ModuleParser.readModule(
+                    mod = ModuleParser.readModule(
                         module, extensions=extensions, caching=False
                     )
                 except ImportError:
@@ -142,7 +141,7 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
         @return dictionary of sub-packages contained in this package
         @rtype dict
         """
-        import Utilities.ModuleParser
+        from eric7.Utilities import ModuleParser
 
         supportedExt = [
             "*{0}".format(ext) for ext in Preferences.getPython("Python3Extensions")
@@ -191,7 +190,7 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
                         QApplication.processEvents()
                         now = time.monotonic()
                     try:
-                        mod = Utilities.ModuleParser.readModule(
+                        mod = ModuleParser.readModule(
                             module, extensions=extensions, caching=False
                         )
                     except ImportError:
