@@ -12,8 +12,7 @@ import os
 
 from PyQt6.QtWidgets import QGraphicsTextItem
 
-import Utilities
-import Preferences
+from eric7 import Preferences, Utilities
 
 from .UMLDiagramBuilder import UMLDiagramBuilder
 
@@ -81,14 +80,14 @@ class UMLClassDiagramBuilder(UMLDiagramBuilder):
 
         The algorithm is borrowed from Boa Constructor.
         """
-        import Utilities.ModuleParser
+        from eric7.Utilities import ModuleParser
 
         self.allClasses = {}
         self.allModules = {}
 
         try:
             extensions = Preferences.getPython("Python3Extensions") + [".rb"]
-            module = Utilities.ModuleParser.readModule(
+            module = ModuleParser.readModule(
                 self.file, extensions=extensions, caching=False
             )
         except ImportError:
