@@ -15,11 +15,11 @@ from PyQt6.QtCore import pyqtSlot, Qt, QCoreApplication
 from PyQt6.QtGui import QAction
 from PyQt6.QtWidgets import QToolBar, QGraphicsScene
 
-from EricWidgets import EricMessageBox, EricFileDialog
-from EricWidgets.EricMainWindow import EricMainWindow
+from eric7.EricWidgets import EricMessageBox, EricFileDialog
+from eric7.EricWidgets.EricMainWindow import EricMainWindow
 
-import UI.Config
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
+from eric7.UI import Config
 
 
 class UMLDialogType(enum.Enum):
@@ -119,32 +119,36 @@ class UMLDialog(EricMainWindow):
         """
         Private slot to initialize the actions.
         """
-        self.closeAct = QAction(UI.PixmapCache.getIcon("close"), self.tr("Close"), self)
+        self.closeAct = QAction(
+            EricPixmapCache.getIcon("close"), self.tr("Close"), self
+        )
         self.closeAct.triggered.connect(self.close)
 
-        self.openAct = QAction(UI.PixmapCache.getIcon("open"), self.tr("Load"), self)
+        self.openAct = QAction(EricPixmapCache.getIcon("open"), self.tr("Load"), self)
         self.openAct.triggered.connect(self.load)
 
         self.saveAct = QAction(
-            UI.PixmapCache.getIcon("fileSave"), self.tr("Save"), self
+            EricPixmapCache.getIcon("fileSave"), self.tr("Save"), self
         )
         self.saveAct.triggered.connect(self.__save)
 
         self.saveAsAct = QAction(
-            UI.PixmapCache.getIcon("fileSaveAs"), self.tr("Save As..."), self
+            EricPixmapCache.getIcon("fileSaveAs"), self.tr("Save As..."), self
         )
         self.saveAsAct.triggered.connect(self.__saveAs)
 
         self.saveImageAct = QAction(
-            UI.PixmapCache.getIcon("fileSavePixmap"), self.tr("Save as Image"), self
+            EricPixmapCache.getIcon("fileSavePixmap"), self.tr("Save as Image"), self
         )
         self.saveImageAct.triggered.connect(self.umlView.saveImage)
 
-        self.printAct = QAction(UI.PixmapCache.getIcon("print"), self.tr("Print"), self)
+        self.printAct = QAction(
+            EricPixmapCache.getIcon("print"), self.tr("Print"), self
+        )
         self.printAct.triggered.connect(self.umlView.printDiagram)
 
         self.printPreviewAct = QAction(
-            UI.PixmapCache.getIcon("printPreview"), self.tr("Print Preview"), self
+            EricPixmapCache.getIcon("printPreview"), self.tr("Print Preview"), self
         )
         self.printPreviewAct.triggered.connect(self.umlView.printPreviewDiagram)
 
@@ -153,11 +157,11 @@ class UMLDialog(EricMainWindow):
         Private slot to initialize the toolbars.
         """
         self.windowToolBar = QToolBar(self.tr("Window"), self)
-        self.windowToolBar.setIconSize(UI.Config.ToolBarIconSize)
+        self.windowToolBar.setIconSize(Config.ToolBarIconSize)
         self.windowToolBar.addAction(self.closeAct)
 
         self.fileToolBar = QToolBar(self.tr("File"), self)
-        self.fileToolBar.setIconSize(UI.Config.ToolBarIconSize)
+        self.fileToolBar.setIconSize(Config.ToolBarIconSize)
         self.fileToolBar.addAction(self.openAct)
         self.fileToolBar.addSeparator()
         self.fileToolBar.addAction(self.saveAct)
