@@ -36,23 +36,22 @@ try:
 except ImportError:
     WEBENGINE_AVAILABLE = False
 
-from EricWidgets import EricFileDialog, EricMessageBox
-from EricWidgets.EricApplication import ericApp
-from EricWidgets.EricTextEditSearchWidget import (
+from eric7.EricWidgets import EricFileDialog, EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricTextEditSearchWidget import (
     EricTextEditSearchWidget,
     EricTextEditType,
 )
 
-import UI.PixmapCache
-import Utilities
-import Preferences
+from eric7.EricGui import EricPixmapCache
+from eric7 import Preferences, Utilities
 
 from .OpenPagesWidget import OpenPagesWidget
 from .HelpBookmarksWidget import HelpBookmarksWidget
 
-from WebBrowser.QtHelp.HelpTocWidget import HelpTocWidget
-from WebBrowser.QtHelp.HelpIndexWidget import HelpIndexWidget
-from WebBrowser.QtHelp.HelpSearchWidget import HelpSearchWidget
+from eric7.WebBrowser.QtHelp.HelpTocWidget import HelpTocWidget
+from eric7.WebBrowser.QtHelp.HelpIndexWidget import HelpIndexWidget
+from eric7.WebBrowser.QtHelp.HelpSearchWidget import HelpSearchWidget
 
 
 class HelpViewerWidget(QWidget):
@@ -128,13 +127,13 @@ class HelpViewerWidget(QWidget):
         self.__helpSelector.activated.connect(self.__helpTopicSelected)
 
         self.__openButton = QToolButton(self)
-        self.__openButton.setIcon(UI.PixmapCache.getIcon("open"))
+        self.__openButton.setIcon(EricPixmapCache.getIcon("open"))
         self.__openButton.setToolTip(self.tr("Open a local file"))
         self.__openButton.clicked.connect(self.__openFile)
         self.__selectorLayout.addWidget(self.__openButton)
 
         self.__actionsButton = QToolButton(self)
-        self.__actionsButton.setIcon(UI.PixmapCache.getIcon("actionsToolButton"))
+        self.__actionsButton.setIcon(EricPixmapCache.getIcon("actionsToolButton"))
         self.__actionsButton.setToolTip(self.tr("Select action from menu"))
         self.__actionsButton.setPopupMode(QToolButton.ToolButtonPopupMode.InstantPopup)
         self.__selectorLayout.addWidget(self.__actionsButton)
@@ -150,12 +149,12 @@ class HelpViewerWidget(QWidget):
         self.__navButtonsLayout.addStretch()
 
         self.__backwardButton = QToolButton(self)
-        self.__backwardButton.setIcon(UI.PixmapCache.getIcon("back"))
+        self.__backwardButton.setIcon(EricPixmapCache.getIcon("back"))
         self.__backwardButton.setToolTip(self.tr("Move one page backward"))
         self.__backwardButton.clicked.connect(self.__backward)
 
         self.__forwardButton = QToolButton(self)
-        self.__forwardButton.setIcon(UI.PixmapCache.getIcon("forward"))
+        self.__forwardButton.setIcon(EricPixmapCache.getIcon("forward"))
         self.__forwardButton.setToolTip(self.tr("Move one page forward"))
         self.__forwardButton.clicked.connect(self.__forward)
 
@@ -167,7 +166,7 @@ class HelpViewerWidget(QWidget):
         self.__navButtonsLayout.addLayout(self.__backForButtonLayout)
 
         self.__reloadButton = QToolButton(self)
-        self.__reloadButton.setIcon(UI.PixmapCache.getIcon("reload"))
+        self.__reloadButton.setIcon(EricPixmapCache.getIcon("reload"))
         self.__reloadButton.setToolTip(self.tr("Reload the current page"))
         self.__reloadButton.clicked.connect(self.__reload)
         self.__navButtonsLayout.addWidget(self.__reloadButton)
@@ -178,19 +177,19 @@ class HelpViewerWidget(QWidget):
         self.__navButtonsLayout.addWidget(self.__buttonLine1)
 
         self.__zoomInButton = QToolButton(self)
-        self.__zoomInButton.setIcon(UI.PixmapCache.getIcon("zoomIn"))
+        self.__zoomInButton.setIcon(EricPixmapCache.getIcon("zoomIn"))
         self.__zoomInButton.setToolTip(self.tr("Zoom in on the current page"))
         self.__zoomInButton.clicked.connect(self.__zoomIn)
         self.__navButtonsLayout.addWidget(self.__zoomInButton)
 
         self.__zoomOutButton = QToolButton(self)
-        self.__zoomOutButton.setIcon(UI.PixmapCache.getIcon("zoomOut"))
+        self.__zoomOutButton.setIcon(EricPixmapCache.getIcon("zoomOut"))
         self.__zoomOutButton.setToolTip(self.tr("Zoom out on the current page"))
         self.__zoomOutButton.clicked.connect(self.__zoomOut)
         self.__navButtonsLayout.addWidget(self.__zoomOutButton)
 
         self.__zoomResetButton = QToolButton(self)
-        self.__zoomResetButton.setIcon(UI.PixmapCache.getIcon("zoomReset"))
+        self.__zoomResetButton.setIcon(EricPixmapCache.getIcon("zoomReset"))
         self.__zoomResetButton.setToolTip(
             self.tr("Reset the zoom level of the current page")
         )
@@ -203,13 +202,13 @@ class HelpViewerWidget(QWidget):
         self.__navButtonsLayout.addWidget(self.__buttonLine2)
 
         self.__addPageButton = QToolButton(self)
-        self.__addPageButton.setIcon(UI.PixmapCache.getIcon("plus"))
+        self.__addPageButton.setIcon(EricPixmapCache.getIcon("plus"))
         self.__addPageButton.setToolTip(self.tr("Add a new empty page"))
         self.__addPageButton.clicked.connect(self.__addNewPage)
         self.__navButtonsLayout.addWidget(self.__addPageButton)
 
         self.__closePageButton = QToolButton(self)
-        self.__closePageButton.setIcon(UI.PixmapCache.getIcon("minus"))
+        self.__closePageButton.setIcon(EricPixmapCache.getIcon("minus"))
         self.__closePageButton.setToolTip(self.tr("Close the current page"))
         self.__closePageButton.clicked.connect(self.closeCurrentPage)
         self.__navButtonsLayout.addWidget(self.__closePageButton)
@@ -220,7 +219,7 @@ class HelpViewerWidget(QWidget):
         self.__navButtonsLayout.addWidget(self.__buttonLine3)
 
         self.__searchButton = QToolButton(self)
-        self.__searchButton.setIcon(UI.PixmapCache.getIcon("find"))
+        self.__searchButton.setIcon(EricPixmapCache.getIcon("find"))
         self.__searchButton.setToolTip(self.tr("Show or hide the search pane"))
         self.__searchButton.setCheckable(True)
         self.__searchButton.setChecked(False)
@@ -356,7 +355,7 @@ class HelpViewerWidget(QWidget):
         @rtype QToolButton
         """
         button = QToolButton(self)
-        button.setIcon(UI.PixmapCache.getIcon(iconName))
+        button.setIcon(EricPixmapCache.getIcon(iconName))
         button.setToolTip(toolTip)
         button.setCheckable(True)
         self.__buttonGroup.addButton(button)
@@ -714,7 +713,7 @@ class HelpViewerWidget(QWidget):
         Private slot to look for new documentation to be loaded into the
         help database.
         """
-        from WebBrowser.QtHelp.HelpDocsInstaller import HelpDocsInstaller
+        from eric7.WebBrowser.QtHelp.HelpDocsInstaller import HelpDocsInstaller
 
         self.__helpInstaller = HelpDocsInstaller(self.__helpEngine.collectionFile())
         self.__helpInstaller.errorMessage.connect(self.__showInstallationError)
@@ -774,7 +773,7 @@ class HelpViewerWidget(QWidget):
         """
         Private slot to manage the QtHelp documentation database.
         """
-        from WebBrowser.QtHelp.QtHelpDocumentationConfigurationDialog import (
+        from eric7.WebBrowser.QtHelp.QtHelpDocumentationConfigurationDialog import (
             QtHelpDocumentationConfigurationDialog,
         )
 
@@ -1111,7 +1110,7 @@ class HelpViewerWidget(QWidget):
 
         self.__initQWebEngineSettings()
 
-        from WebBrowser.Network.QtHelpSchemeHandler import QtHelpSchemeHandler
+        from eric7.WebBrowser.Network.QtHelpSchemeHandler import QtHelpSchemeHandler
 
         self.__qtHelpSchemeHandler = QtHelpSchemeHandler(self.__helpEngine)
         self.__webProfile.installUrlSchemeHandler(
