@@ -23,22 +23,21 @@ from PyQt6.QtWidgets import (
     QMenu,
 )
 
-from EricGui.EricAction import EricAction
-from EricWidgets.EricMainWindow import EricMainWindow
-from EricWidgets import EricFileDialog, EricMessageBox
-from EricWidgets.EricClickableLabel import EricClickableLabel
+from eric7.EricGui.EricAction import EricAction
+from eric7.EricWidgets.EricMainWindow import EricMainWindow
+from eric7.EricWidgets import EricFileDialog, EricMessageBox
+from eric7.EricWidgets.EricClickableLabel import EricClickableLabel
 
-from Globals import strGroup, recentNameHexFiles
+from eric7.Globals import strGroup, recentNameHexFiles
 
 from .HexEditWidget import HexEditWidget
 from .HexEditSearchReplaceWidget import HexEditSearchReplaceWidget
 from .HexEditGotoWidget import HexEditGotoWidget
 
-import UI.PixmapCache
-import UI.Config
+from eric7.EricGui import EricPixmapCache
+from eric7.UI import Config
 
-import Preferences
-import Utilities
+from eric7 import Preferences, Utilities
 
 
 class HexEditMainWindow(EricMainWindow):
@@ -77,7 +76,7 @@ class HexEditMainWindow(EricMainWindow):
         }
 
         self.__fromEric = fromEric
-        self.setWindowIcon(UI.PixmapCache.getIcon("hexEditor"))
+        self.setWindowIcon(EricPixmapCache.getIcon("hexEditor"))
 
         if not self.__fromEric:
             self.setStyle(Preferences.getUI("Style"), Preferences.getUI("StyleSheet"))
@@ -160,7 +159,7 @@ class HexEditMainWindow(EricMainWindow):
         """
         self.newWindowAct = EricAction(
             self.tr("New Window"),
-            UI.PixmapCache.getIcon("newWindow"),
+            EricPixmapCache.getIcon("newWindow"),
             self.tr("New &Window"),
             0,
             0,
@@ -183,7 +182,7 @@ class HexEditMainWindow(EricMainWindow):
         # correct texts will be set later
         self.openAct = EricAction(
             self.tr("Open"),
-            UI.PixmapCache.getIcon("open"),
+            EricPixmapCache.getIcon("open"),
             self.tr("&Open..."),
             QKeySequence(self.tr("Ctrl+O", "File|Open")),
             0,
@@ -202,7 +201,7 @@ class HexEditMainWindow(EricMainWindow):
 
         self.saveAct = EricAction(
             self.tr("Save"),
-            UI.PixmapCache.getIcon("fileSave"),
+            EricPixmapCache.getIcon("fileSave"),
             self.tr("&Save"),
             QKeySequence(self.tr("Ctrl+S", "File|Save")),
             0,
@@ -221,7 +220,7 @@ class HexEditMainWindow(EricMainWindow):
 
         self.saveAsAct = EricAction(
             self.tr("Save As"),
-            UI.PixmapCache.getIcon("fileSaveAs"),
+            EricPixmapCache.getIcon("fileSaveAs"),
             self.tr("Save &As..."),
             QKeySequence(self.tr("Shift+Ctrl+S", "File|Save As")),
             0,
@@ -265,7 +264,7 @@ class HexEditMainWindow(EricMainWindow):
 
         self.closeAct = EricAction(
             self.tr("Close"),
-            UI.PixmapCache.getIcon("close"),
+            EricPixmapCache.getIcon("close"),
             self.tr("&Close"),
             QKeySequence(self.tr("Ctrl+W", "File|Close")),
             0,
@@ -316,7 +315,7 @@ class HexEditMainWindow(EricMainWindow):
 
         self.exitAct = EricAction(
             self.tr("Quit"),
-            UI.PixmapCache.getIcon("exit"),
+            EricPixmapCache.getIcon("exit"),
             self.tr("&Quit"),
             QKeySequence(self.tr("Ctrl+Q", "File|Quit")),
             0,
@@ -337,7 +336,7 @@ class HexEditMainWindow(EricMainWindow):
         """
         self.undoAct = EricAction(
             self.tr("Undo"),
-            UI.PixmapCache.getIcon("editUndo"),
+            EricPixmapCache.getIcon("editUndo"),
             self.tr("&Undo"),
             QKeySequence(self.tr("Ctrl+Z", "Edit|Undo")),
             QKeySequence(self.tr("Alt+Backspace", "Edit|Undo")),
@@ -353,7 +352,7 @@ class HexEditMainWindow(EricMainWindow):
 
         self.redoAct = EricAction(
             self.tr("Redo"),
-            UI.PixmapCache.getIcon("editRedo"),
+            EricPixmapCache.getIcon("editRedo"),
             self.tr("&Redo"),
             QKeySequence(self.tr("Ctrl+Shift+Z", "Edit|Redo")),
             0,
@@ -388,7 +387,7 @@ class HexEditMainWindow(EricMainWindow):
 
         self.cutAct = EricAction(
             self.tr("Cut"),
-            UI.PixmapCache.getIcon("editCut"),
+            EricPixmapCache.getIcon("editCut"),
             self.tr("Cu&t"),
             QKeySequence(self.tr("Ctrl+X", "Edit|Cut")),
             QKeySequence(self.tr("Shift+Del", "Edit|Cut")),
@@ -407,7 +406,7 @@ class HexEditMainWindow(EricMainWindow):
 
         self.copyAct = EricAction(
             self.tr("Copy"),
-            UI.PixmapCache.getIcon("editCopy"),
+            EricPixmapCache.getIcon("editCopy"),
             self.tr("&Copy"),
             QKeySequence(self.tr("Ctrl+C", "Edit|Copy")),
             QKeySequence(self.tr("Ctrl+Ins", "Edit|Copy")),
@@ -426,7 +425,7 @@ class HexEditMainWindow(EricMainWindow):
 
         self.pasteAct = EricAction(
             self.tr("Paste"),
-            UI.PixmapCache.getIcon("editPaste"),
+            EricPixmapCache.getIcon("editPaste"),
             self.tr("&Paste"),
             QKeySequence(self.tr("Ctrl+V", "Edit|Paste")),
             QKeySequence(self.tr("Shift+Ins", "Edit|Paste")),
@@ -442,7 +441,7 @@ class HexEditMainWindow(EricMainWindow):
 
         self.selectAllAct = EricAction(
             self.tr("Select All"),
-            UI.PixmapCache.getIcon("editSelectAll"),
+            EricPixmapCache.getIcon("editSelectAll"),
             self.tr("&Select All"),
             QKeySequence(self.tr("Ctrl+A", "Edit|Select All")),
             0,
@@ -523,7 +522,7 @@ class HexEditMainWindow(EricMainWindow):
 
         self.searchAct = EricAction(
             self.tr("Search"),
-            UI.PixmapCache.getIcon("find"),
+            EricPixmapCache.getIcon("find"),
             self.tr("&Search..."),
             QKeySequence(self.tr("Ctrl+F", "Search|Search")),
             0,
@@ -543,7 +542,7 @@ class HexEditMainWindow(EricMainWindow):
 
         self.searchNextAct = EricAction(
             self.tr("Search next"),
-            UI.PixmapCache.getIcon("findNext"),
+            EricPixmapCache.getIcon("findNext"),
             self.tr("Search &next"),
             QKeySequence(self.tr("F3", "Search|Search next")),
             0,
@@ -563,7 +562,7 @@ class HexEditMainWindow(EricMainWindow):
 
         self.searchPrevAct = EricAction(
             self.tr("Search previous"),
-            UI.PixmapCache.getIcon("findPrev"),
+            EricPixmapCache.getIcon("findPrev"),
             self.tr("Search &previous"),
             QKeySequence(self.tr("Shift+F3", "Search|Search previous")),
             0,
@@ -605,7 +604,7 @@ class HexEditMainWindow(EricMainWindow):
 
         self.gotoAct = EricAction(
             self.tr("Goto Offset"),
-            UI.PixmapCache.getIcon("goto"),
+            EricPixmapCache.getIcon("goto"),
             self.tr("&Goto Offset..."),
             QKeySequence(
                 QCoreApplication.translate(
@@ -684,7 +683,7 @@ class HexEditMainWindow(EricMainWindow):
 
         self.whatsThisAct = EricAction(
             self.tr("What's This?"),
-            UI.PixmapCache.getIcon("whatsThis"),
+            EricPixmapCache.getIcon("whatsThis"),
             self.tr("&What's This?"),
             QKeySequence(self.tr("Shift+F1", "Help|What's This?'")),
             0,
@@ -711,7 +710,7 @@ class HexEditMainWindow(EricMainWindow):
         """
         self.prefAct = EricAction(
             self.tr("Preferences"),
-            UI.PixmapCache.getIcon("configure"),
+            EricPixmapCache.getIcon("configure"),
             self.tr("&Preferences..."),
             0,
             0,
@@ -847,7 +846,7 @@ class HexEditMainWindow(EricMainWindow):
         """
         filetb = self.addToolBar(self.tr("File"))
         filetb.setObjectName("FileToolBar")
-        filetb.setIconSize(UI.Config.ToolBarIconSize)
+        filetb.setIconSize(Config.ToolBarIconSize)
         filetb.addAction(self.newWindowAct)
         filetb.addAction(self.openAct)
         filetb.addSeparator()
@@ -860,7 +859,7 @@ class HexEditMainWindow(EricMainWindow):
 
         edittb = self.addToolBar(self.tr("Edit"))
         edittb.setObjectName("EditToolBar")
-        edittb.setIconSize(UI.Config.ToolBarIconSize)
+        edittb.setIconSize(Config.ToolBarIconSize)
         edittb.addAction(self.undoAct)
         edittb.addAction(self.redoAct)
         edittb.addSeparator()
@@ -870,7 +869,7 @@ class HexEditMainWindow(EricMainWindow):
 
         searchtb = self.addToolBar(self.tr("Find"))
         searchtb.setObjectName("SearchToolBar")
-        searchtb.setIconSize(UI.Config.ToolBarIconSize)
+        searchtb.setIconSize(Config.ToolBarIconSize)
         searchtb.addAction(self.searchAct)
         searchtb.addAction(self.searchNextAct)
         searchtb.addAction(self.searchPrevAct)
@@ -878,12 +877,12 @@ class HexEditMainWindow(EricMainWindow):
         if not self.__fromEric:
             settingstb = self.addToolBar(self.tr("Settings"))
             settingstb.setObjectName("SettingsToolBar")
-            settingstb.setIconSize(UI.Config.ToolBarIconSize)
+            settingstb.setIconSize(Config.ToolBarIconSize)
             settingstb.addAction(self.prefAct)
 
         helptb = self.addToolBar(self.tr("Help"))
         helptb.setObjectName("HelpToolBar")
-        helptb.setIconSize(UI.Config.ToolBarIconSize)
+        helptb.setIconSize(Config.ToolBarIconSize)
         helptb.addAction(self.whatsThisAct)
 
     def __createStatusBar(self):
@@ -1489,7 +1488,7 @@ class HexEditMainWindow(EricMainWindow):
         """
         Private slot to set the preferences.
         """
-        from Preferences.ConfigurationDialog import (
+        from eric7.Preferences.ConfigurationDialog import (
             ConfigurationDialog,
             ConfigurationMode,
         )
