@@ -11,10 +11,10 @@ from PyQt6.QtCore import pyqtSlot, Qt, QByteArray, QRegularExpression
 from PyQt6.QtGui import QRegularExpressionValidator
 from PyQt6.QtWidgets import QWidget
 
-from EricGui.EricAction import EricAction
-from EricWidgets import EricMessageBox
+from eric7.EricGui.EricAction import EricAction
+from eric7.EricWidgets import EricMessageBox
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
 
 class HexEditSearchReplaceWidget(QWidget):
@@ -80,16 +80,18 @@ class HexEditSearchReplaceWidget(QWidget):
             self.__ui = Ui_HexEditSearchWidget()
         self.__ui.setupUi(self)
 
-        self.__ui.closeButton.setIcon(UI.PixmapCache.getIcon("close"))
-        self.__ui.findPrevButton.setIcon(UI.PixmapCache.getIcon("1leftarrow"))
-        self.__ui.findNextButton.setIcon(UI.PixmapCache.getIcon("1rightarrow"))
+        self.__ui.closeButton.setIcon(EricPixmapCache.getIcon("close"))
+        self.__ui.findPrevButton.setIcon(EricPixmapCache.getIcon("1leftarrow"))
+        self.__ui.findNextButton.setIcon(EricPixmapCache.getIcon("1rightarrow"))
 
         if replace:
-            self.__ui.replaceButton.setIcon(UI.PixmapCache.getIcon("editReplace"))
+            self.__ui.replaceButton.setIcon(EricPixmapCache.getIcon("editReplace"))
             self.__ui.replaceSearchButton.setIcon(
-                UI.PixmapCache.getIcon("editReplaceSearch")
+                EricPixmapCache.getIcon("editReplaceSearch")
+            )
+            self.__ui.replaceAllButton.setIcon(
+                EricPixmapCache.getIcon("editReplaceAll")
             )
-            self.__ui.replaceAllButton.setIcon(UI.PixmapCache.getIcon("editReplaceAll"))
 
         for dataFormat in formatOrder:
             formatStr, validator = self.__formatAndValidators[dataFormat]
