@@ -22,12 +22,12 @@ from PyQt6.QtCore import (
 from PyQt6.QtGui import QFont, QPalette, QKeySequence, QPainter
 from PyQt6.QtWidgets import QAbstractScrollArea, QApplication
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .HexEditChunks import HexEditChunks
 from .HexEditUndoStack import HexEditUndoStack
 
-import Globals
+from eric7 import Globals
 
 
 class HexEditWidget(QAbstractScrollArea):
