@@ -14,15 +14,14 @@ import uuid
 from PyQt6.QtCore import pyqtSlot, QCoreApplication, QTimer, QThread
 from PyQt6.QtWidgets import QInputDialog, QLineEdit, QDialog
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
 
-from EricNetwork.EricJsonServer import EricJsonServer
+from eric7.EricNetwork.EricJsonServer import EricJsonServer
 
-from QScintilla.Editor import Editor
+from eric7.QScintilla.Editor import Editor
 
-import Preferences
-import Globals
+from eric7 import Globals, Preferences
 
 from .RefactoringPreviewDialog import RefactoringPreviewDialog
 
@@ -417,7 +416,7 @@ class JediServer(EricJsonServer):
         """
         euuid = result["Uuid"]
         with contextlib.suppress(ImportError):
-            from QScintilla.Editor import ReferenceItem
+            from eric7.QScintilla.Editor import ReferenceItem
 
             if "Error" not in result:
                 # ignore errors silently
