@@ -21,10 +21,10 @@ from PyQt6.QtWidgets import (
     QDialog,
 )
 
-from EricWidgets import EricMessageBox, EricPathPickerDialog
-from EricWidgets.EricPathPicker import EricPathPickerModes
-from EricWidgets.EricFileSaveConfirmDialog import confirmOverwrite
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox, EricPathPickerDialog
+from eric7.EricWidgets.EricPathPicker import EricPathPickerModes
+from eric7.EricWidgets.EricFileSaveConfirmDialog import confirmOverwrite
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .Ui_MicroPythonFileManagerWidget import Ui_MicroPythonFileManagerWidget
 
@@ -36,12 +36,10 @@ from .MicroPythonFileSystemUtilities import (
     listdirStat,
 )
 
-from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
-import UI.PixmapCache
-import Preferences
-import Utilities
-import Globals
+from eric7.EricGui import EricPixmapCache
+from eric7 import Globals, Preferences, Utilities
 
 
 class MicroPythonFileManagerWidget(QWidget, Ui_MicroPythonFileManagerWidget):
@@ -67,17 +65,17 @@ class MicroPythonFileManagerWidget(QWidget, Ui_MicroPythonFileManagerWidget):
         self.__repl = parent
         self.__deviceWithLocalAccess = deviceWithLocalAccess
 
-        self.syncButton.setIcon(UI.PixmapCache.getIcon("2rightarrow"))
-        self.putButton.setIcon(UI.PixmapCache.getIcon("1rightarrow"))
-        self.putAsButton.setIcon(UI.PixmapCache.getIcon("putAs"))
-        self.getButton.setIcon(UI.PixmapCache.getIcon("1leftarrow"))
-        self.getAsButton.setIcon(UI.PixmapCache.getIcon("getAs"))
-        self.localUpButton.setIcon(UI.PixmapCache.getIcon("1uparrow"))
-        self.localHomeButton.setIcon(UI.PixmapCache.getIcon("home"))
-        self.localReloadButton.setIcon(UI.PixmapCache.getIcon("reload"))
-        self.deviceUpButton.setIcon(UI.PixmapCache.getIcon("1uparrow"))
-        self.deviceHomeButton.setIcon(UI.PixmapCache.getIcon("home"))
-        self.deviceReloadButton.setIcon(UI.PixmapCache.getIcon("reload"))
+        self.syncButton.setIcon(EricPixmapCache.getIcon("2rightarrow"))
+        self.putButton.setIcon(EricPixmapCache.getIcon("1rightarrow"))
+        self.putAsButton.setIcon(EricPixmapCache.getIcon("putAs"))
+        self.getButton.setIcon(EricPixmapCache.getIcon("1leftarrow"))
+        self.getAsButton.setIcon(EricPixmapCache.getIcon("getAs"))
+        self.localUpButton.setIcon(EricPixmapCache.getIcon("1uparrow"))
+        self.localHomeButton.setIcon(EricPixmapCache.getIcon("home"))
+        self.localReloadButton.setIcon(EricPixmapCache.getIcon("reload"))
+        self.deviceUpButton.setIcon(EricPixmapCache.getIcon("1uparrow"))
+        self.deviceHomeButton.setIcon(EricPixmapCache.getIcon("home"))
+        self.deviceReloadButton.setIcon(EricPixmapCache.getIcon("reload"))
 
         self.deviceUpButton.setEnabled(not self.__repl.isMicrobit())
         self.deviceHomeButton.setEnabled(not self.__repl.isMicrobit())
