@@ -14,13 +14,13 @@ import contextlib
 from PyQt6.QtCore import pyqtSlot, Qt, QCoreApplication, QThread, QEventLoop
 from PyQt6.QtWidgets import QDialog
 
-from EricWidgets.EricPathPicker import EricPathPickerModes
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricPathPicker import EricPathPickerModes
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .Ui_UF2FlashDialog import Ui_UF2FlashDialog
 
-import UI.PixmapCache
-import Utilities
+from eric7.EricGui import EricPixmapCache
+from eric7 import Utilities
 
 from . import MicroPythonDevices
 
@@ -671,7 +671,7 @@ class UF2FlashDialog(QDialog, Ui_UF2FlashDialog):
         super().__init__(parent)
         self.setupUi(self)
 
-        self.refreshButton.setIcon(UI.PixmapCache.getIcon("rescan"))
+        self.refreshButton.setIcon(EricPixmapCache.getIcon("rescan"))
 
         self.firmwarePicker.setMode(EricPathPickerModes.OPEN_FILE_MODE)
         self.firmwarePicker.setFilters(
