@@ -12,14 +12,14 @@ import copy
 from PyQt6.QtCore import pyqtSlot, Qt, QEvent, QItemSelectionModel
 from PyQt6.QtWidgets import QDialog, QInputDialog, QLineEdit
 
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets import EricMessageBox
 
 from .Ui_IrcIdentitiesEditDialog import Ui_IrcIdentitiesEditDialog
 
 from .IrcNetworkManager import IrcIdentity
 
-import Utilities
-import UI.PixmapCache
+from eric7 import Utilities
+from eric7.EricGui import EricPixmapCache
 
 
 class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
@@ -39,15 +39,15 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
         super().__init__(parent)
         self.setupUi(self)
 
-        self.addButton.setIcon(UI.PixmapCache.getIcon("plus"))
-        self.copyButton.setIcon(UI.PixmapCache.getIcon("editCopy"))
-        self.renameButton.setIcon(UI.PixmapCache.getIcon("editRename"))
-        self.deleteButton.setIcon(UI.PixmapCache.getIcon("minus"))
-        self.nicknameAddButton.setIcon(UI.PixmapCache.getIcon("plus"))
-        self.nicknameDeleteButton.setIcon(UI.PixmapCache.getIcon("minus"))
-        self.nicknameUpButton.setIcon(UI.PixmapCache.getIcon("1uparrow"))
-        self.nicknameDownButton.setIcon(UI.PixmapCache.getIcon("1downarrow"))
-        self.showPasswordButton.setIcon(UI.PixmapCache.getIcon("showPassword"))
+        self.addButton.setIcon(EricPixmapCache.getIcon("plus"))
+        self.copyButton.setIcon(EricPixmapCache.getIcon("editCopy"))
+        self.renameButton.setIcon(EricPixmapCache.getIcon("editRename"))
+        self.deleteButton.setIcon(EricPixmapCache.getIcon("minus"))
+        self.nicknameAddButton.setIcon(EricPixmapCache.getIcon("plus"))
+        self.nicknameDeleteButton.setIcon(EricPixmapCache.getIcon("minus"))
+        self.nicknameUpButton.setIcon(EricPixmapCache.getIcon("1uparrow"))
+        self.nicknameDownButton.setIcon(EricPixmapCache.getIcon("1downarrow"))
+        self.showPasswordButton.setIcon(EricPixmapCache.getIcon("showPassword"))
 
         self.__manager = manager
 
@@ -493,11 +493,11 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
         """
         if checked:
             self.passwordEdit.setEchoMode(QLineEdit.EchoMode.Normal)
-            self.showPasswordButton.setIcon(UI.PixmapCache.getIcon("hidePassword"))
+            self.showPasswordButton.setIcon(EricPixmapCache.getIcon("hidePassword"))
             self.showPasswordButton.setToolTip(self.tr("Press to hide the password"))
         else:
             self.passwordEdit.setEchoMode(QLineEdit.EchoMode.Password)
-            self.showPasswordButton.setIcon(UI.PixmapCache.getIcon("showPassword"))
+            self.showPasswordButton.setIcon(EricPixmapCache.getIcon("showPassword"))
             self.showPasswordButton.setToolTip(self.tr("Press to show the password"))
 
     def accept(self):
