@@ -16,13 +16,13 @@ from PyQt6.QtCore import pyqtSlot, QObject, QProcess, QUrl, QCoreApplication, QT
 from PyQt6.QtWidgets import QDialog, QInputDialog, QLineEdit
 from PyQt6.QtNetwork import QNetworkAccessManager, QNetworkRequest, QNetworkReply
 
-from EricWidgets import EricMessageBox
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
 
-from EricNetwork.EricNetworkProxyFactory import proxyAuthenticationRequired
+from eric7.EricNetwork.EricNetworkProxyFactory import proxyAuthenticationRequired
 
 try:
-    from EricNetwork.EricSslErrorHandler import EricSslErrorHandler
+    from eric7.EricNetwork.EricSslErrorHandler import EricSslErrorHandler
 
     SSL_AVAILABLE = True
 except ImportError:
@@ -31,8 +31,7 @@ except ImportError:
 from .PipDialog import PipDialog
 from .PipVulnerabilityChecker import PipVulnerabilityChecker
 
-import Preferences
-import Globals
+from eric7 import Globals, Preferences
 
 
 class Pip(QObject):
@@ -508,7 +507,9 @@ class Pip(QObject):
         """
         res = False
         if packages and venvName:
-            from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+            from eric7.UI.DeleteFilesConfirmationDialog import (
+                DeleteFilesConfirmationDialog,
+            )
 
             dlg = DeleteFilesConfirmationDialog(
                 self.parent(),
@@ -547,7 +548,7 @@ class Pip(QObject):
                     except OSError:
                         return
 
-                    from UI.DeleteFilesConfirmationDialog import (
+                    from eric7.UI.DeleteFilesConfirmationDialog import (
                         DeleteFilesConfirmationDialog,
                     )
 
