@@ -20,13 +20,16 @@ from PyQt6.QtCore import pyqtSignal, QObject, QFile, QUrl, QIODevice
 from PyQt6.QtGui import QPixmap
 from PyQt6.QtNetwork import QNetworkAccessManager, QNetworkRequest, QNetworkReply
 
-from EricWidgets import EricMessageBox
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
 
-from EricNetwork.EricNetworkProxyFactory import proxyAuthenticationRequired
+from eric7.EricNetwork.EricNetworkProxyFactory import proxyAuthenticationRequired
 
 try:
-    from EricNetwork.EricSslErrorHandler import EricSslErrorHandler, EricSslErrorState
+    from eric7.EricNetwork.EricSslErrorHandler import (
+        EricSslErrorHandler,
+        EricSslErrorState,
+    )
 
     SSL_AVAILABLE = True
 except ImportError:
@@ -41,11 +44,9 @@ from .PluginExceptions import (
     PluginClassFormatError,
 )
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
-import Globals
-import Utilities
-import Preferences
+from eric7 import Globals, Preferences, Utilities
 
 from eric7config import getConfig
 
@@ -313,13 +314,13 @@ class PluginManager(QObject):
             if key in self.pluginDirs:
                 if self.pluginDirs[key] not in sys.path:
                     sys.path.insert(2, self.pluginDirs[key])
-                UI.PixmapCache.addSearchPath(self.pluginDirs[key])
+                EricPixmapCache.addSearchPath(self.pluginDirs[key])
 
         if self.__develPluginFile:
             path = Utilities.splitPath(self.__develPluginFile)[0]
             if path not in sys.path:
                 sys.path.insert(2, path)
-            UI.PixmapCache.addSearchPath(path)
+            EricPixmapCache.addSearchPath(path)
 
     def __loadPlugins(self):
         """
@@ -1330,7 +1331,7 @@ class PluginManager(QObject):
                 url = Preferences.getUI("PluginRepositoryUrl7")
 
                 # read the repository file
-                from EricXML.PluginRepositoryReader import PluginRepositoryReader
+                from eric7.EricXML.PluginRepositoryReader import PluginRepositoryReader
 
                 reader = PluginRepositoryReader(f, self.checkPluginEntry)
                 reader.readXML()
@@ -1456,7 +1457,7 @@ class PluginManager(QObject):
             pip = ericApp().getObject("Pip")
         except KeyError:
             # Installation is performed via the plug-in installation script.
-            from PipInterface.Pip import Pip
+            from eric7.PipInterface.Pip import Pip
 
             pip = Pip(self)
         pip.installPackages(packages, interpreter=Globals.getPythonExecutable())
