@@ -44,24 +44,25 @@ from PyQt6.QtNetwork import (
 
 from .Ui_PluginRepositoryDialog import Ui_PluginRepositoryDialog
 
-from EricWidgets import EricMessageBox
-from EricWidgets.EricMainWindow import EricMainWindow
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricMainWindow import EricMainWindow
+from eric7.EricWidgets.EricApplication import ericApp
 
-from EricNetwork.EricNetworkProxyFactory import proxyAuthenticationRequired
+from eric7.EricNetwork.EricNetworkProxyFactory import proxyAuthenticationRequired
 
 try:
-    from EricNetwork.EricSslErrorHandler import EricSslErrorHandler, EricSslErrorState
+    from eric7.EricNetwork.EricSslErrorHandler import (
+        EricSslErrorHandler,
+        EricSslErrorState,
+    )
 
     SSL_AVAILABLE = True
 except ImportError:
     SSL_AVAILABLE = False
 
-import Globals
-import Utilities
-import Preferences
+from eric7 import Globals, Preferences, Utilities
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
 from eric7config import getConfig
 
@@ -120,19 +121,21 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
             self.__actionButtonsLayout.addStretch()
 
             self.__updateButton = QToolButton(self)
-            self.__updateButton.setIcon(UI.PixmapCache.getIcon("reload"))
+            self.__updateButton.setIcon(EricPixmapCache.getIcon("reload"))
             self.__updateButton.setToolTip(self.tr("Update"))
             self.__updateButton.clicked.connect(self.__updateList)
             self.__actionButtonsLayout.addWidget(self.__updateButton)
 
             self.__downloadButton = QToolButton(self)
-            self.__downloadButton.setIcon(UI.PixmapCache.getIcon("download"))
+            self.__downloadButton.setIcon(EricPixmapCache.getIcon("download"))
             self.__downloadButton.setToolTip(self.tr("Download"))
             self.__downloadButton.clicked.connect(self.__downloadButtonClicked)
             self.__actionButtonsLayout.addWidget(self.__downloadButton)
 
             self.__downloadInstallButton = QToolButton(self)
-            self.__downloadInstallButton.setIcon(UI.PixmapCache.getIcon("downloadPlus"))
+            self.__downloadInstallButton.setIcon(
+                EricPixmapCache.getIcon("downloadPlus")
+            )
             self.__downloadInstallButton.setToolTip(self.tr("Download & Install"))
             self.__downloadInstallButton.clicked.connect(
                 self.__downloadInstallButtonClicked
@@ -140,13 +143,13 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
             self.__actionButtonsLayout.addWidget(self.__downloadInstallButton)
 
             self.__downloadCancelButton = QToolButton(self)
-            self.__downloadCancelButton.setIcon(UI.PixmapCache.getIcon("cancel"))
+            self.__downloadCancelButton.setIcon(EricPixmapCache.getIcon("cancel"))
             self.__downloadCancelButton.setToolTip(self.tr("Cancel"))
             self.__downloadCancelButton.clicked.connect(self.__downloadCancel)
             self.__actionButtonsLayout.addWidget(self.__downloadCancelButton)
 
             self.__installButton = QToolButton(self)
-            self.__installButton.setIcon(UI.PixmapCache.getIcon("plus"))
+            self.__installButton.setIcon(EricPixmapCache.getIcon("plus"))
             self.__installButton.setToolTip(self.tr("Install"))
             self.__installButton.clicked.connect(self.__closeAndInstall)
             self.__actionButtonsLayout.addWidget(self.__installButton)
@@ -499,7 +502,7 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         ui = ericApp().getObject("UserInterface") if not self.__external else None
         if ui is not None:
             ui.showNotification(
-                UI.PixmapCache.getPixmap("plugin48"),
+                EricPixmapCache.getPixmap("plugin48"),
                 self.tr("Download Plugin Files"),
                 self.tr("""The requested plugins were downloaded."""),
             )
@@ -548,7 +551,7 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
             self.__repositoryMissing = False
             f = QFile(self.pluginRepositoryFile)
             if f.open(QIODevice.OpenModeFlag.ReadOnly):
-                from EricXML.PluginRepositoryReader import PluginRepositoryReader
+                from eric7.EricXML.PluginRepositoryReader import PluginRepositoryReader
 
                 reader = PluginRepositoryReader(f, self.addEntry)
                 reader.readXML()
@@ -782,22 +785,22 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         iconColumn = 0 if self.__integratedWidget else 1
         updateStatus = self.__updateStatus(filename, version)
         if updateStatus == PluginRepositoryWidget.PluginStatusUpToDate:
-            itm.setIcon(iconColumn, UI.PixmapCache.getIcon("empty"))
+            itm.setIcon(iconColumn, EricPixmapCache.getIcon("empty"))
             itm.setToolTip(iconColumn, self.tr("up-to-date"))
         elif updateStatus == PluginRepositoryWidget.PluginStatusNew:
-            itm.setIcon(iconColumn, UI.PixmapCache.getIcon("download"))
+            itm.setIcon(iconColumn, EricPixmapCache.getIcon("download"))
             itm.setToolTip(iconColumn, self.tr("new download available"))
             self.__newItems += 1
         elif updateStatus == PluginRepositoryWidget.PluginStatusLocalUpdate:
-            itm.setIcon(iconColumn, UI.PixmapCache.getIcon("updateLocal"))
+            itm.setIcon(iconColumn, EricPixmapCache.getIcon("updateLocal"))
             itm.setToolTip(iconColumn, self.tr("update installable"))
             self.__updateLocalItems += 1
         elif updateStatus == PluginRepositoryWidget.PluginStatusRemoteUpdate:
-            itm.setIcon(iconColumn, UI.PixmapCache.getIcon("updateRemote"))
+            itm.setIcon(iconColumn, EricPixmapCache.getIcon("updateRemote"))
             itm.setToolTip(iconColumn, self.tr("updated download available"))
             self.__updateRemoteItems += 1
         elif updateStatus == PluginRepositoryWidget.PluginStatusError:
-            itm.setIcon(iconColumn, UI.PixmapCache.getIcon("warning"))
+            itm.setIcon(iconColumn, EricPixmapCache.getIcon("warning"))
             itm.setToolTip(iconColumn, self.tr("error determining status"))
 
     def __updateStatus(self, filename, version):
@@ -1152,7 +1155,7 @@ def PluginRepositoryDownloadCleanup(quiet=False):
     if os.path.exists(pluginRepositoryFile):
         f = QFile(pluginRepositoryFile)
         if f.open(QIODevice.OpenModeFlag.ReadOnly):
-            from EricXML.PluginRepositoryReader import PluginRepositoryReader
+            from eric7.EricXML.PluginRepositoryReader import PluginRepositoryReader
 
             reader = PluginRepositoryReader(f, registerPlugin)
             reader.readXML()
