@@ -27,13 +27,12 @@ from PyQt6.QtWidgets import (
     QLineEdit,
 )
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .Ui_CodeStyleCheckerDialog import Ui_CodeStyleCheckerDialog
 
-import UI.PixmapCache
-import Preferences
-import Utilities
+from eric7.EricGui import EricPixmapCache
+from eric7 import Preferences, Utilities
 
 from . import pycodestyle
 from . import CodeStyleCheckerUtilities
@@ -121,10 +120,10 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
 
         self.optionsTabWidget.setCurrentIndex(0)
 
-        self.excludeMessagesSelectButton.setIcon(UI.PixmapCache.getIcon("select"))
-        self.includeMessagesSelectButton.setIcon(UI.PixmapCache.getIcon("select"))
-        self.fixIssuesSelectButton.setIcon(UI.PixmapCache.getIcon("select"))
-        self.noFixIssuesSelectButton.setIcon(UI.PixmapCache.getIcon("select"))
+        self.excludeMessagesSelectButton.setIcon(EricPixmapCache.getIcon("select"))
+        self.includeMessagesSelectButton.setIcon(EricPixmapCache.getIcon("select"))
+        self.fixIssuesSelectButton.setIcon(EricPixmapCache.getIcon("select"))
+        self.noFixIssuesSelectButton.setIcon(EricPixmapCache.getIcon("select"))
 
         self.docTypeComboBox.addItem(self.tr("PEP-257"), "pep257")
         self.docTypeComboBox.addItem(self.tr("Eric"), "eric")
@@ -160,10 +159,10 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         self.resultList.headerItem().setText(self.resultList.columnCount(), "")
         self.resultList.header().setSortIndicator(0, Qt.SortOrder.AscendingOrder)
 
-        self.addBuiltinButton.setIcon(UI.PixmapCache.getIcon("plus"))
-        self.deleteBuiltinButton.setIcon(UI.PixmapCache.getIcon("minus"))
-        self.addWhitelistButton.setIcon(UI.PixmapCache.getIcon("plus"))
-        self.deleteWhitelistButton.setIcon(UI.PixmapCache.getIcon("minus"))
+        self.addBuiltinButton.setIcon(EricPixmapCache.getIcon("plus"))
+        self.deleteBuiltinButton.setIcon(EricPixmapCache.getIcon("minus"))
+        self.addWhitelistButton.setIcon(EricPixmapCache.getIcon("plus"))
+        self.deleteWhitelistButton.setIcon(EricPixmapCache.getIcon("minus"))
 
         self.restartButton.setEnabled(False)
         self.fixButton.setEnabled(False)
@@ -293,13 +292,13 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         CodeStyleCheckerUtilities.setItemIcon(itm, 1, msgCode, result.get("severity"))
 
         if result["fixed"]:
-            itm.setIcon(0, UI.PixmapCache.getIcon("issueFixed"))
+            itm.setIcon(0, EricPixmapCache.getIcon("issueFixed"))
         elif (
             msgCode in FixableCodeStyleIssues
             and not result["autofixing"]
             and msgCode not in self.__noFixCodesList
         ):
-            itm.setIcon(0, UI.PixmapCache.getIcon("issueFixable"))
+            itm.setIcon(0, EricPixmapCache.getIcon("issueFixable"))
             fixable = True
 
         itm.setTextAlignment(0, Qt.AlignmentFlag.AlignRight)
@@ -338,7 +337,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         """
         if result["fixed"]:
             itm.setText(2, result["display"])
-            itm.setIcon(0, UI.PixmapCache.getIcon("issueFixed"))
+            itm.setIcon(0, EricPixmapCache.getIcon("issueFixed"))
 
             itm.setData(0, self.messageRole, result["display"])
         else:
