@@ -14,13 +14,15 @@ from PyQt6.QtCore import pyqtSlot
 from PyQt6.QtGui import QColor
 from PyQt6.QtWidgets import QDialog, QDialogButtonBox, QColorDialog
 
-from EricWidgets.EricPathPicker import EricPathPickerModes
+from eric7.EricWidgets.EricPathPicker import EricPathPickerModes
 
 from .Ui_EricdocConfigDialog import Ui_EricdocConfigDialog
-from DocumentationTools.Config import eric7docDefaultColors, eric7docColorParameterNames
+from eric7.DocumentationTools.Config import (
+    eric7docDefaultColors,
+    eric7docColorParameterNames,
+)
 
-import Globals
-import Utilities
+from eric7 import Globals, Utilities
 
 from eric7config import getConfig
 
