@@ -12,20 +12,20 @@ import contextlib
 
 from PyQt6.QtCore import QObject, QCoreApplication
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
-import Preferences
-from Preferences.Shortcuts import readShortcuts
-import UI.Info
+from eric7 import Preferences
+from eric7.Preferences.Shortcuts import readShortcuts
+from eric7.UI import Info
 
-from VcsPlugins.vcsPySvn.SvnUtilities import getConfigPath, getServersPath
+from eric7.Plugins.VcsPlugins.vcsPySvn.SvnUtilities import getConfigPath, getServersPath
 
 # Start-Of-Header
 name = "PySvn Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = False
 deactivateable = True
-version = UI.Info.VersionOnly
+version = Info.VersionOnly
 pluginType = "version_control"
 pluginTypename = "PySvn"
 className = "VcsPySvnPlugin"
@@ -107,7 +107,9 @@ def createConfigurationPage(configDlg):
     @return reference to the configuration page
     """
     global subversionCfgPluginObject
-    from VcsPlugins.vcsPySvn.ConfigurationPage.SubversionPage import SubversionPage
+    from eric7.Plugins.VcsPlugins.vcsPySvn.ConfigurationPage.SubversionPage import (
+        SubversionPage,
+    )
 
     if subversionCfgPluginObject is None:
         subversionCfgPluginObject = VcsPySvnPlugin(None)
@@ -162,7 +164,7 @@ class VcsPySvnPlugin(QObject):
             "LogLimit": 20,
         }
 
-        from VcsPlugins.vcsPySvn.ProjectHelper import PySvnProjectHelper
+        from eric7.Plugins.VcsPlugins.vcsPySvn.ProjectHelper import PySvnProjectHelper
 
         self.__projectHelperObject = PySvnProjectHelper(None, None)
         with contextlib.suppress(KeyError):
@@ -197,7 +199,7 @@ class VcsPySvnPlugin(QObject):
         @return tuple of reference to instantiated viewmanager and
             activation status (boolean)
         """
-        from VcsPlugins.vcsPySvn.subversion import Subversion
+        from eric7.Plugins.VcsPlugins.vcsPySvn.subversion import Subversion
 
         self.__object = Subversion(self, self.__ui)
 
