@@ -11,7 +11,7 @@ import json
 
 from PyQt6.QtCore import QUrl, QByteArray, QTimer
 
-import Utilities
+from eric7 import Utilities
 
 from .TranslationEngine import TranslationEngine
 
