@@ -11,7 +11,7 @@ import os
 
 from PyQt6.QtCore import QProcessEnvironment
 
-import Utilities
+from eric7 import Utilities
 
 
 def getConfigPath():
