@@ -11,13 +11,14 @@ import os
 
 from PyQt6.QtWidgets import QMenu, QDialog
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricGui import EricPixmapCache
 
-from Project.ProjectBrowserModel import ProjectBrowserFileItem
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
 
-from VCS.ProjectBrowserHelper import VcsProjectBrowserHelper
+from eric7.Project.ProjectBrowserModel import ProjectBrowserFileItem
 
-import UI.PixmapCache
+from eric7.VCS.ProjectBrowserHelper import VcsProjectBrowserHelper
 
 
 class GitProjectBrowserHelper(VcsProjectBrowserHelper):
@@ -71,6 +72,8 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
                 act.setEnabled(True)
             for act in standardItems:
                 act.setEnabled(False)
+            # special conditions below
+            self.annotateSkipAct.setEnabled(os.path.exists(self.__skipListFileName()))
         else:
             for act in self.vcsMenuActions:
                 act.setEnabled(False)
@@ -184,7 +187,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsGit", "icons", "git.svg")
             ),
             self.vcs.vcsName(),
@@ -196,32 +199,32 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Commit changes to repository..."),
             self._VCSCommit,
         )
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd"),
+            EricPixmapCache.getIcon("vcsAdd"),
             self.tr("Add/Stage to repository"),
             self._VCSAdd,
         )
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Unstage changes"),
             self.__GitUnstage,
         )
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Remove from repository (and disk)"),
             self._VCSRemove,
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Remove from repository only"),
             self.__GitForget,
         )
@@ -233,37 +236,39 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsLog"),
+            EricPixmapCache.getIcon("vcsLog"),
             self.tr("Show log browser"),
             self._VCSLogBrowser,
         )
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus"), self.tr("Show status"), self._VCSStatus
+            EricPixmapCache.getIcon("vcsStatus"),
+            self.tr("Show status"),
+            self._VCSStatus,
         )
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences"),
             self._VCSDiff,
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsSbsDiff"),
+            EricPixmapCache.getIcon("vcsSbsDiff"),
             self.tr("Show differences side-by-side"),
             self.__GitSbsDiff,
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (extended)"),
             self.__GitExtendedDiff,
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsSbsDiff"),
+            EricPixmapCache.getIcon("vcsSbsDiff"),
             self.tr("Show differences side-by-side (extended)"),
             self.__GitSbsExtendedDiff,
         )
@@ -273,9 +278,17 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
             self.tr("Show annotated file"), self.__GitBlame
         )
         self.vcsMenuActions.append(self.annotateAct)
+        self.annotateSkipAct = menu.addAction(
+            self.tr("Show annotated file with skip list"), self.__GitBlameSkip
+        )
+        self.vcsMenuActions.append(self.annotateSkipAct)
+        self.annotateSkipListAct = menu.addAction(
+            self.tr("Create skip list file"), self.__GitBlameSkipListFile
+        )
+        self.vcsMenuActions.append(self.annotateSkipListAct)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Revert changes"),
             self.__GitRevert,
         )
@@ -314,7 +327,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsGit", "icons", "git.svg")
             ),
             self.vcs.vcsName(),
@@ -326,57 +339,59 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Commit changes to repository..."),
             self._VCSCommit,
         )
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd"),
+            EricPixmapCache.getIcon("vcsAdd"),
             self.tr("Add/Stage to repository"),
             self._VCSAdd,
         )
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Unstage changes"),
             self.__GitUnstage,
         )
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Remove from repository (and disk)"),
             self._VCSRemove,
         )
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Remove from repository only"),
             self.__GitForget,
         )
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus"), self.tr("Show status"), self._VCSStatus
+            EricPixmapCache.getIcon("vcsStatus"),
+            self.tr("Show status"),
+            self._VCSStatus,
         )
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences"),
             self._VCSDiff,
         )
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (extended)"),
             self.__GitExtendedDiff,
         )
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Revert changes"),
             self.__GitRevert,
         )
@@ -414,7 +429,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsGit", "icons", "git.svg")
             ),
             self.vcs.vcsName(),
@@ -461,7 +476,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsGit", "icons", "git.svg")
             ),
             self.vcs.vcsName(),
@@ -473,26 +488,26 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Commit changes to repository..."),
             self._VCSCommit,
         )
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd"),
+            EricPixmapCache.getIcon("vcsAdd"),
             self.tr("Add/Stage to repository"),
             self._VCSAdd,
         )
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Unstage changes"),
             self.__GitUnstage,
         )
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Remove from repository (and disk)"),
             self._VCSRemove,
         )
@@ -504,32 +519,34 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsLog"),
+            EricPixmapCache.getIcon("vcsLog"),
             self.tr("Show log browser"),
             self._VCSLogBrowser,
         )
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus"), self.tr("Show status"), self._VCSStatus
+            EricPixmapCache.getIcon("vcsStatus"),
+            self.tr("Show status"),
+            self._VCSStatus,
         )
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences"),
             self._VCSDiff,
         )
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (extended)"),
             self.__GitExtendedDiff,
         )
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Revert changes"),
             self.__GitRevert,
         )
@@ -572,7 +589,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsGit", "icons", "git.svg")
             ),
             self.vcs.vcsName(),
@@ -584,51 +601,53 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Commit changes to repository..."),
             self._VCSCommit,
         )
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd"),
+            EricPixmapCache.getIcon("vcsAdd"),
             self.tr("Add/Stage to repository"),
             self._VCSAdd,
         )
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Unstage changes"),
             self.__GitUnstage,
         )
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Remove from repository (and disk)"),
             self._VCSRemove,
         )
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus"), self.tr("Show status"), self._VCSStatus
+            EricPixmapCache.getIcon("vcsStatus"),
+            self.tr("Show status"),
+            self._VCSStatus,
         )
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences"),
             self._VCSDiff,
         )
         self.vcsDirMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (extended)"),
             self.__GitExtendedDiff,
         )
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Revert changes"),
             self.__GitRevert,
         )
@@ -668,7 +687,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         Private slot called by the context menu to remove the selected file
         from the Git repository leaving a copy in the project directory.
         """
-        from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+        from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
         if self.isTranslationsBrowser:
             items = self.browser.getSelectedItems([ProjectBrowserFileItem])
@@ -802,3 +821,52 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         itm = self.browser.currentItem()
         fn = itm.fileName()
         self.vcs.gitBlame(fn)
+
+    def __GitBlameSkip(self):
+        """
+        Private slot called by the context menu to show the annotations of a
+        file with a project specific skip list.
+        """
+        itm = self.browser.currentItem()
+        fn = itm.fileName()
+        self.vcs.gitBlame(fn, skiplist=self.__skipListFileName())
+
+    def __GitBlameSkipListFile(self):
+        """
+        Private method to create an empty 'git blame' skip list file.
+        """
+        skipList = self.__skipListFileName()
+        res = (
+            EricMessageBox.yesNo(
+                self.browser,
+                self.tr("Create {0} file").format(skipList),
+                self.tr(
+                    """<p>The file <b>{0}</b> exists already."""
+                    """ Overwrite it?</p>"""
+                ).format(skipList),
+                icon=EricMessageBox.Warning,
+            )
+            if os.path.exists(skipList)
+            else True
+        )
+        if res:
+            try:
+                # create a .gitblame_skiplist file
+                with open(skipList, "w") as skip:
+                    skip.write("\n")
+                status = True
+            except OSError:
+                status = False
+
+            if status:
+                self.vcs.vcsAdd(skipList, noDialog=True)
+                self.project.appendFile(skipList)
+
+    def __skipListFileName(self):
+        """
+        Private method to generate the file name for a 'git blame' skip list file.
+
+        @return name of the skip list file
+        @rtype str
+        """
+        return os.path.join(self.project.getProjectPath(), ".gitblame_skiplist")
