@@ -14,10 +14,10 @@ import contextlib
 from PyQt6.QtCore import pyqtSlot, Qt, QEvent
 from PyQt6.QtWidgets import QDialog, QTreeWidgetItem
 
-from EricWidgets.EricPathPicker import EricPathPickerModes
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricPathPicker import EricPathPickerModes
+from eric7.EricWidgets import EricMessageBox
 
-import Globals
+from eric7 import Globals
 
 from .HgUtilities import getConfigPath
 from .HgUserConfigHostFingerprintDialog import HgUserConfigHostFingerprintDialog
@@ -25,7 +25,7 @@ from .HgUserConfigHostMinimumProtocolDialog import HgUserConfigHostMinimumProtoc
 
 from .Ui_HgUserConfigDialog import Ui_HgUserConfigDialog
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
 
 class HgUserConfigDialog(QDialog, Ui_HgUserConfigDialog):
@@ -67,13 +67,13 @@ class HgUserConfigDialog(QDialog, Ui_HgUserConfigDialog):
                 os.path.expanduser("~\\AppData\\Local\\largefiles")
             )
 
-        self.fpAddButton.setIcon(UI.PixmapCache.getIcon("plus"))
-        self.fpDeleteButton.setIcon(UI.PixmapCache.getIcon("minus"))
-        self.fpEditButton.setIcon(UI.PixmapCache.getIcon("edit"))
+        self.fpAddButton.setIcon(EricPixmapCache.getIcon("plus"))
+        self.fpDeleteButton.setIcon(EricPixmapCache.getIcon("minus"))
+        self.fpEditButton.setIcon(EricPixmapCache.getIcon("edit"))
 
-        self.protocolAddButton.setIcon(UI.PixmapCache.getIcon("plus"))
-        self.protocolDeleteButton.setIcon(UI.PixmapCache.getIcon("minus"))
-        self.protocolEditButton.setIcon(UI.PixmapCache.getIcon("edit"))
+        self.protocolAddButton.setIcon(EricPixmapCache.getIcon("plus"))
+        self.protocolDeleteButton.setIcon(EricPixmapCache.getIcon("minus"))
+        self.protocolEditButton.setIcon(EricPixmapCache.getIcon("edit"))
 
         self.minimumProtocolComboBox.addItem(self.tr("Default"), "")
         for protocol in sorted(self.__minimumProtocols.keys()):
@@ -699,7 +699,7 @@ class HgUserConfigDialog(QDialog, Ui_HgUserConfigDialog):
         """
         Private slot to open the user configuration file in a text editor.
         """
-        from QScintilla.MiniEditor import MiniEditor
+        from eric7.QScintilla.MiniEditor import MiniEditor
 
         cfgFile = getConfigPath()
 
