@@ -9,12 +9,11 @@ Module implementing some common utility functions for the Mercurial package.
 
 import os
 import re
-import sys
 
 from PyQt6.QtCore import QProcess, QProcessEnvironment, QCoreApplication
 
-import Utilities
-from Globals import isWindowsPlatform
+from eric7 import Utilities
+from eric7.Globals import isWindowsPlatform
 
 
 def getHgExecutable():
@@ -24,22 +23,17 @@ def getHgExecutable():
     @return path of the Mercurial executable
     @rtype str
     """
-    from Plugins.PluginVcsMercurial import VcsMercurialPlugin
+    from eric7.Plugins.PluginVcsMercurial import VcsMercurialPlugin
 
     exe = VcsMercurialPlugin.getPreferences("MercurialExecutablePath")
     if not exe:
         program = "hg"
         if isWindowsPlatform():
             program += ".exe"
-            dirName = os.path.dirname(sys.executable)
-            if os.path.exists(os.path.join(dirName, program)):
-                exe = os.path.join(dirName, program)
-            elif os.path.exists(os.path.join(dirName, "Scripts", program)):
-                exe = os.path.join(dirName, "Scripts", program)
-        else:
-            dirName = os.path.dirname(sys.executable)
-            if os.path.exists(os.path.join(dirName, program)):
-                exe = os.path.join(dirName, program)
+
+        progPath = os.path.join(Utilities.getPythonScriptsDirectory(), program)
+        if os.path.exists(progPath):
+            exe = progPath
 
         if not exe:
             exe = program
