@@ -11,13 +11,14 @@ import os
 
 from PyQt6.QtWidgets import QMenu, QDialog
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricGui import EricPixmapCache
 
-from Project.ProjectBrowserModel import ProjectBrowserFileItem
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
 
-from VCS.ProjectBrowserHelper import VcsProjectBrowserHelper
+from eric7.Project.ProjectBrowserModel import ProjectBrowserFileItem
 
-import UI.PixmapCache
+from eric7.VCS.ProjectBrowserHelper import VcsProjectBrowserHelper
 
 
 class HgProjectBrowserHelper(VcsProjectBrowserHelper):
@@ -122,8 +123,11 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
                 act.setEnabled(False)
             for act in standardItems:
                 act.setEnabled(False)
-            if not hasattr(self.browser.currentItem(), "fileName"):
-                self.annotateAct.setEnabled(False)
+            self.annotateAct.setEnabled(hasattr(self.browser.currentItem(), "fileName"))
+            self.annotateSkipAct.setEnabled(
+                os.path.exists(self.__skipListFileName())
+                and hasattr(self.browser.currentItem(), "fileName")
+            )
         else:
             controlled = False
             for act in self.vcsMenuActions:
@@ -289,7 +293,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsMercurial", "icons", "mercurial.svg")
             ),
             self.vcs.vcsName(),
@@ -301,7 +305,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Commit changes to repository..."),
             self._VCSCommit,
         )
@@ -309,17 +313,19 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         self.__addExtensionsMenu(menu, "mainMenu")
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd"), self.tr("Add to repository"), self._VCSAdd
+            EricPixmapCache.getIcon("vcsAdd"),
+            self.tr("Add to repository"),
+            self._VCSAdd,
         )
         self.vcsAddMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Remove from repository (and disk)"),
             self._VCSRemove,
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Remove from repository only"),
             self.__HgForget,
         )
@@ -331,48 +337,59 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsLog"),
+            EricPixmapCache.getIcon("vcsLog"),
             self.tr("Show log browser"),
             self._VCSLogBrowser,
         )
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus"), self.tr("Show status"), self._VCSStatus
+            EricPixmapCache.getIcon("vcsStatus"),
+            self.tr("Show status"),
+            self._VCSStatus,
         )
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences"),
             self._VCSDiff,
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsSbsDiff"),
+            EricPixmapCache.getIcon("vcsSbsDiff"),
             self.tr("Show differences side-by-side"),
             self.__HgSbsDiff,
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (extended)"),
             self.__HgExtendedDiff,
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsSbsDiff"),
+            EricPixmapCache.getIcon("vcsSbsDiff"),
             self.tr("Show differences side-by-side (extended)"),
             self.__HgSbsExtendedDiff,
         )
         self.vcsMenuActions.append(act)
+        menu.addSeparator()
         self.annotateAct = menu.addAction(
             self.tr("Show annotated file"), self.__HgAnnotate
         )
         self.vcsMenuActions.append(self.annotateAct)
+        self.annotateSkipAct = menu.addAction(
+            self.tr("Show annotated file with skip list"), self.__HgAnnotateSkip
+        )
+        self.vcsMenuActions.append(self.annotateSkipAct)
+        self.annotateSkipListAct = menu.addAction(
+            self.tr("Create skip list file"), self.__HgAnnotateSkipListFile
+        )
+        self.vcsMenuActions.append(self.annotateSkipListAct)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Revert changes"),
             self.__HgRevert,
         )
@@ -418,7 +435,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsMercurial", "icons", "mercurial.svg")
             ),
             self.vcs.vcsName(),
@@ -430,7 +447,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Commit changes to repository..."),
             self._VCSCommit,
         )
@@ -438,42 +455,46 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         self.__addExtensionsMenu(menu, "multiMenu")
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd"), self.tr("Add to repository"), self._VCSAdd
+            EricPixmapCache.getIcon("vcsAdd"),
+            self.tr("Add to repository"),
+            self._VCSAdd,
         )
         self.vcsAddMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Remove from repository (and disk)"),
             self._VCSRemove,
         )
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Remove from repository only"),
             self.__HgForget,
         )
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus"), self.tr("Show status"), self._VCSStatus
+            EricPixmapCache.getIcon("vcsStatus"),
+            self.tr("Show status"),
+            self._VCSStatus,
         )
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences"),
             self._VCSDiff,
         )
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (extended)"),
             self.__HgExtendedDiff,
         )
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Revert changes"),
             self.__HgRevert,
         )
@@ -515,7 +536,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsMercurial", "icons", "mercurial.svg")
             ),
             self.vcs.vcsName(),
@@ -562,7 +583,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsMercurial", "icons", "mercurial.svg")
             ),
             self.vcs.vcsName(),
@@ -574,7 +595,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Commit changes to repository..."),
             self._VCSCommit,
         )
@@ -582,11 +603,13 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         self.__addExtensionsMenu(menu, "dirMenu")
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd"), self.tr("Add to repository"), self._VCSAdd
+            EricPixmapCache.getIcon("vcsAdd"),
+            self.tr("Add to repository"),
+            self._VCSAdd,
         )
         self.vcsAddDirMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Remove from repository (and disk)"),
             self._VCSRemove,
         )
@@ -598,32 +621,34 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsLog"),
+            EricPixmapCache.getIcon("vcsLog"),
             self.tr("Show log browser"),
             self._VCSLogBrowser,
         )
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus"), self.tr("Show status"), self._VCSStatus
+            EricPixmapCache.getIcon("vcsStatus"),
+            self.tr("Show status"),
+            self._VCSStatus,
         )
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences"),
             self._VCSDiff,
         )
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (extended)"),
             self.__HgExtendedDiff,
         )
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Revert changes"),
             self.__HgRevert,
         )
@@ -671,7 +696,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsMercurial", "icons", "mercurial.svg")
             ),
             self.vcs.vcsName(),
@@ -683,7 +708,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Commit changes to repository..."),
             self._VCSCommit,
         )
@@ -691,36 +716,40 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         self.__addExtensionsMenu(menu, "dirMultiMenu")
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd"), self.tr("Add to repository"), self._VCSAdd
+            EricPixmapCache.getIcon("vcsAdd"),
+            self.tr("Add to repository"),
+            self._VCSAdd,
         )
         self.vcsAddDirMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Remove from repository (and disk)"),
             self._VCSRemove,
         )
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus"), self.tr("Show status"), self._VCSStatus
+            EricPixmapCache.getIcon("vcsStatus"),
+            self.tr("Show status"),
+            self._VCSStatus,
         )
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences"),
             self._VCSDiff,
         )
         self.vcsDirMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (extended)"),
             self.__HgExtendedDiff,
         )
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Revert changes"),
             self.__HgRevert,
         )
@@ -845,6 +874,55 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         fn = itm.fileName()
         self.vcs.hgAnnotate(fn)
 
+    def __HgAnnotateSkip(self):
+        """
+        Private slot called by the context menu to show the annotations of a
+        file with a project specific skip list.
+        """
+        itm = self.browser.currentItem()
+        fn = itm.fileName()
+        self.vcs.hgAnnotate(fn, skiplist=self.__skipListFileName())
+
+    def __HgAnnotateSkipListFile(self):
+        """
+        Private method to create an empty 'hg annotate' skip list file.
+        """
+        skipList = self.__skipListFileName()
+        res = (
+            EricMessageBox.yesNo(
+                self.browser,
+                self.tr("Create {0} file").format(skipList),
+                self.tr(
+                    """<p>The file <b>{0}</b> exists already."""
+                    """ Overwrite it?</p>"""
+                ).format(skipList),
+                icon=EricMessageBox.Warning,
+            )
+            if os.path.exists(skipList)
+            else True
+        )
+        if res:
+            try:
+                # create a .hgannotate_skiplist file
+                with open(skipList, "w") as skip:
+                    skip.write("\n")
+                status = True
+            except OSError:
+                status = False
+
+            if status:
+                self.vcs.vcsAdd(skipList, noDialog=True)
+                self.project.appendFile(skipList)
+
+    def __skipListFileName(self):
+        """
+        Private method to generate the file name for a 'hg annotate' skip list file.
+
+        @return name of the skip list file
+        @rtype str
+        """
+        return os.path.join(self.project.getProjectPath(), ".hgannotate_skiplist")
+
     def __HgResolved(self):
         """
         Private slot called by the context menu to mark conflicts of a file
@@ -888,7 +966,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         Private slot called by the context menu to remove the selected file
         from the Mercurial repository leaving a copy in the project directory.
         """
-        from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+        from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
         if self.isTranslationsBrowser:
             items = self.browser.getSelectedItems([ProjectBrowserFileItem])
