@@ -11,15 +11,16 @@ import os
 
 from PyQt6.QtWidgets import QMenu, QToolBar
 
-from EricWidgets import EricMessageBox
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
 
-from VCS.ProjectHelper import VcsProjectHelper
+from eric7.VCS.ProjectHelper import VcsProjectHelper
 
-from EricGui.EricAction import EricAction
+from eric7.EricGui.EricAction import EricAction
 
-import UI.PixmapCache
-import Preferences
+from eric7.EricGui import EricPixmapCache
+from eric7.UI import Config
+from eric7 import Preferences
 
 
 class HgProjectHelper(VcsProjectHelper):
@@ -119,7 +120,7 @@ class HgProjectHelper(VcsProjectHelper):
         """
         self.vcsNewAct = EricAction(
             self.tr("New from repository"),
-            UI.PixmapCache.getIcon("vcsCheckout"),
+            EricPixmapCache.getIcon("vcsCheckout"),
             self.tr("&New from repository..."),
             0,
             0,
@@ -141,7 +142,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgIncomingAct = EricAction(
             self.tr("Show incoming log"),
-            UI.PixmapCache.getIcon("vcsUpdate"),
+            EricPixmapCache.getIcon("vcsUpdate"),
             self.tr("Show incoming log"),
             0,
             0,
@@ -161,7 +162,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgPullAct = EricAction(
             self.tr("Pull changes"),
-            UI.PixmapCache.getIcon("vcsUpdate"),
+            EricPixmapCache.getIcon("vcsUpdate"),
             self.tr("Pull changes"),
             0,
             0,
@@ -181,7 +182,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.vcsUpdateAct = EricAction(
             self.tr("Update from repository"),
-            UI.PixmapCache.getIcon("vcsUpdate"),
+            EricPixmapCache.getIcon("vcsUpdate"),
             self.tr("&Update from repository"),
             0,
             0,
@@ -203,7 +204,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.vcsCommitAct = EricAction(
             self.tr("Commit changes to repository"),
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("&Commit changes to repository..."),
             0,
             0,
@@ -225,7 +226,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgOutgoingAct = EricAction(
             self.tr("Show outgoing log"),
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Show outgoing log"),
             0,
             0,
@@ -245,7 +246,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgPushAct = EricAction(
             self.tr("Push changes"),
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Push changes"),
             0,
             0,
@@ -265,7 +266,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgPushForcedAct = EricAction(
             self.tr("Push changes (force)"),
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Push changes (force)"),
             0,
             0,
@@ -287,7 +288,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.vcsExportAct = EricAction(
             self.tr("Export from repository"),
-            UI.PixmapCache.getIcon("vcsExport"),
+            EricPixmapCache.getIcon("vcsExport"),
             self.tr("&Export from repository..."),
             0,
             0,
@@ -306,7 +307,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgLogBrowserAct = EricAction(
             self.tr("Show log browser"),
-            UI.PixmapCache.getIcon("vcsLog"),
+            EricPixmapCache.getIcon("vcsLog"),
             self.tr("Show log browser"),
             0,
             0,
@@ -329,7 +330,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.vcsDiffAct = EricAction(
             self.tr("Show differences"),
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show &difference"),
             0,
             0,
@@ -351,7 +352,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgExtDiffAct = EricAction(
             self.tr("Show differences (extended)"),
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (extended)"),
             0,
             0,
@@ -373,7 +374,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.vcsStatusAct = EricAction(
             self.tr("Show status"),
-            UI.PixmapCache.getIcon("vcsStatus"),
+            EricPixmapCache.getIcon("vcsStatus"),
             self.tr("Show &status..."),
             0,
             0,
@@ -392,7 +393,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgSummaryAct = EricAction(
             self.tr("Show Summary"),
-            UI.PixmapCache.getIcon("vcsSummary"),
+            EricPixmapCache.getIcon("vcsSummary"),
             self.tr("Show summary..."),
             0,
             0,
@@ -457,7 +458,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.vcsRevertAct = EricAction(
             self.tr("Revert changes"),
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Re&vert changes"),
             0,
             0,
@@ -478,7 +479,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.vcsMergeAct = EricAction(
             self.tr("Merge"),
-            UI.PixmapCache.getIcon("vcsMerge"),
+            EricPixmapCache.getIcon("vcsMerge"),
             self.tr("Mer&ge changes..."),
             0,
             0,
@@ -539,7 +540,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgReMergeAct = EricAction(
             self.tr("Re-Merge"),
-            UI.PixmapCache.getIcon("vcsMerge"),
+            EricPixmapCache.getIcon("vcsMerge"),
             self.tr("Re-Merge"),
             0,
             0,
@@ -624,7 +625,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.vcsTagAct = EricAction(
             self.tr("Tag in repository"),
-            UI.PixmapCache.getIcon("vcsTag"),
+            EricPixmapCache.getIcon("vcsTag"),
             self.tr("&Tag in repository..."),
             0,
             0,
@@ -678,7 +679,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgBranchAct = EricAction(
             self.tr("Create branch"),
-            UI.PixmapCache.getIcon("vcsBranch"),
+            EricPixmapCache.getIcon("vcsBranch"),
             self.tr("Create &branch..."),
             0,
             0,
@@ -700,7 +701,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgPushBranchAct = EricAction(
             self.tr("Push new branch"),
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Push new branch"),
             0,
             0,
@@ -724,7 +725,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgCloseBranchAct = EricAction(
             self.tr("Close branch"),
-            UI.PixmapCache.getIcon("closehead"),
+            EricPixmapCache.getIcon("closehead"),
             self.tr("Close branch"),
             0,
             0,
@@ -765,7 +766,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.vcsSwitchAct = EricAction(
             self.tr("Switch"),
-            UI.PixmapCache.getIcon("vcsSwitch"),
+            EricPixmapCache.getIcon("vcsSwitch"),
             self.tr("S&witch..."),
             0,
             0,
@@ -998,7 +999,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgBundleAct = EricAction(
             self.tr("Create changegroup"),
-            UI.PixmapCache.getIcon("vcsCreateChangegroup"),
+            EricPixmapCache.getIcon("vcsCreateChangegroup"),
             self.tr("Create changegroup..."),
             0,
             0,
@@ -1020,7 +1021,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgPreviewBundleAct = EricAction(
             self.tr("Preview changegroup"),
-            UI.PixmapCache.getIcon("vcsPreviewChangegroup"),
+            EricPixmapCache.getIcon("vcsPreviewChangegroup"),
             self.tr("Preview changegroup..."),
             0,
             0,
@@ -1042,7 +1043,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgUnbundleAct = EricAction(
             self.tr("Apply changegroups"),
-            UI.PixmapCache.getIcon("vcsApplyChangegroup"),
+            EricPixmapCache.getIcon("vcsApplyChangegroup"),
             self.tr("Apply changegroups..."),
             0,
             0,
@@ -1191,7 +1192,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgImportAct = EricAction(
             self.tr("Import Patch"),
-            UI.PixmapCache.getIcon("vcsImportPatch"),
+            EricPixmapCache.getIcon("vcsImportPatch"),
             self.tr("Import Patch..."),
             0,
             0,
@@ -1211,7 +1212,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgExportAct = EricAction(
             self.tr("Export Patches"),
-            UI.PixmapCache.getIcon("vcsExportPatch"),
+            EricPixmapCache.getIcon("vcsExportPatch"),
             self.tr("Export Patches..."),
             0,
             0,
@@ -1248,7 +1249,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgGraftAct = EricAction(
             self.tr("Copy Changesets"),
-            UI.PixmapCache.getIcon("vcsGraft"),
+            EricPixmapCache.getIcon("vcsGraft"),
             self.tr("Copy Changesets"),
             0,
             0,
@@ -1331,7 +1332,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgAddSubrepoAct = EricAction(
             self.tr("Add"),
-            UI.PixmapCache.getIcon("vcsAdd"),
+            EricPixmapCache.getIcon("vcsAdd"),
             self.tr("Add..."),
             0,
             0,
@@ -1349,7 +1350,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgRemoveSubreposAct = EricAction(
             self.tr("Remove"),
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Remove..."),
             0,
             0,
@@ -1368,7 +1369,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgArchiveAct = EricAction(
             self.tr("Create unversioned archive"),
-            UI.PixmapCache.getIcon("vcsExport"),
+            EricPixmapCache.getIcon("vcsExport"),
             self.tr("Create unversioned archive..."),
             0,
             0,
@@ -1390,7 +1391,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgBookmarksListAct = EricAction(
             self.tr("List bookmarks"),
-            UI.PixmapCache.getIcon("listBookmarks"),
+            EricPixmapCache.getIcon("listBookmarks"),
             self.tr("List bookmarks..."),
             0,
             0,
@@ -1409,7 +1410,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgBookmarkDefineAct = EricAction(
             self.tr("Define bookmark"),
-            UI.PixmapCache.getIcon("addBookmark"),
+            EricPixmapCache.getIcon("addBookmark"),
             self.tr("Define bookmark..."),
             0,
             0,
@@ -1430,7 +1431,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgBookmarkDeleteAct = EricAction(
             self.tr("Delete bookmark"),
-            UI.PixmapCache.getIcon("deleteBookmark"),
+            EricPixmapCache.getIcon("deleteBookmark"),
             self.tr("Delete bookmark..."),
             0,
             0,
@@ -1451,7 +1452,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgBookmarkRenameAct = EricAction(
             self.tr("Rename bookmark"),
-            UI.PixmapCache.getIcon("renameBookmark"),
+            EricPixmapCache.getIcon("renameBookmark"),
             self.tr("Rename bookmark..."),
             0,
             0,
@@ -1472,7 +1473,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgBookmarkMoveAct = EricAction(
             self.tr("Move bookmark"),
-            UI.PixmapCache.getIcon("moveBookmark"),
+            EricPixmapCache.getIcon("moveBookmark"),
             self.tr("Move bookmark..."),
             0,
             0,
@@ -1492,7 +1493,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgBookmarkIncomingAct = EricAction(
             self.tr("Show incoming bookmarks"),
-            UI.PixmapCache.getIcon("incomingBookmark"),
+            EricPixmapCache.getIcon("incomingBookmark"),
             self.tr("Show incoming bookmarks"),
             0,
             0,
@@ -1514,7 +1515,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgBookmarkPullAct = EricAction(
             self.tr("Pull bookmark"),
-            UI.PixmapCache.getIcon("pullBookmark"),
+            EricPixmapCache.getIcon("pullBookmark"),
             self.tr("Pull bookmark"),
             0,
             0,
@@ -1536,7 +1537,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgBookmarkPullCurrentAct = EricAction(
             self.tr("Pull current bookmark"),
-            UI.PixmapCache.getIcon("pullBookmark"),
+            EricPixmapCache.getIcon("pullBookmark"),
             self.tr("Pull current bookmark"),
             0,
             0,
@@ -1557,7 +1558,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgBookmarkOutgoingAct = EricAction(
             self.tr("Show outgoing bookmarks"),
-            UI.PixmapCache.getIcon("outgoingBookmark"),
+            EricPixmapCache.getIcon("outgoingBookmark"),
             self.tr("Show outgoing bookmarks"),
             0,
             0,
@@ -1579,7 +1580,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgBookmarkPushAct = EricAction(
             self.tr("Push bookmark"),
-            UI.PixmapCache.getIcon("pushBookmark"),
+            EricPixmapCache.getIcon("pushBookmark"),
             self.tr("Push bookmark"),
             0,
             0,
@@ -1601,7 +1602,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgBookmarkPushCurrentAct = EricAction(
             self.tr("Push current bookmark"),
-            UI.PixmapCache.getIcon("pushBookmark"),
+            EricPixmapCache.getIcon("pushBookmark"),
             self.tr("Push current bookmark"),
             0,
             0,
@@ -1623,7 +1624,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgBookmarkPushAllAct = EricAction(
             self.tr("Push all bookmarks"),
-            UI.PixmapCache.getIcon("pushBookmark"),
+            EricPixmapCache.getIcon("pushBookmark"),
             self.tr("Push all bookmarks"),
             0,
             0,
@@ -1644,7 +1645,7 @@ class HgProjectHelper(VcsProjectHelper):
 
         self.hgDeleteBackupsAct = EricAction(
             self.tr("Delete all backups"),
-            UI.PixmapCache.getIcon("clearPrivateData"),
+            EricPixmapCache.getIcon("clearPrivateData"),
             self.tr("Delete all backups"),
             0,
             0,
@@ -1752,14 +1753,14 @@ class HgProjectHelper(VcsProjectHelper):
         self.subMenus.append(bisectMenu)
 
         tagsMenu = QMenu(self.tr("Tags"), menu)
-        tagsMenu.setIcon(UI.PixmapCache.getIcon("vcsTag"))
+        tagsMenu.setIcon(EricPixmapCache.getIcon("vcsTag"))
         tagsMenu.setTearOffEnabled(True)
         tagsMenu.addAction(self.vcsTagAct)
         tagsMenu.addAction(self.hgTagListAct)
         self.subMenus.append(tagsMenu)
 
         branchesMenu = QMenu(self.tr("Branches"), menu)
-        branchesMenu.setIcon(UI.PixmapCache.getIcon("vcsBranch"))
+        branchesMenu.setIcon(EricPixmapCache.getIcon("vcsBranch"))
         branchesMenu.setTearOffEnabled(True)
         branchesMenu.addAction(self.hgBranchAct)
         branchesMenu.addAction(self.hgPushBranchAct)
@@ -1768,7 +1769,7 @@ class HgProjectHelper(VcsProjectHelper):
         self.subMenus.append(branchesMenu)
 
         bookmarksMenu = QMenu(self.tr("Bookmarks"), menu)
-        bookmarksMenu.setIcon(UI.PixmapCache.getIcon("bookmark22"))
+        bookmarksMenu.setIcon(EricPixmapCache.getIcon("bookmark22"))
         bookmarksMenu.setTearOffEnabled(True)
         bookmarksMenu.addAction(self.hgBookmarkDefineAct)
         bookmarksMenu.addAction(self.hgBookmarkDeleteAct)
@@ -1802,7 +1803,7 @@ class HgProjectHelper(VcsProjectHelper):
         self.vcs.activeExtensionsChanged.connect(self.__showExtensionMenu)
 
         graftMenu = QMenu(self.tr("Copy Changesets"), menu)
-        graftMenu.setIcon(UI.PixmapCache.getIcon("vcsGraft"))
+        graftMenu.setIcon(EricPixmapCache.getIcon("vcsGraft"))
         graftMenu.setTearOffEnabled(True)
         graftMenu.addAction(self.hgGraftAct)
         graftMenu.addAction(self.hgGraftContinueAct)
@@ -1816,7 +1817,7 @@ class HgProjectHelper(VcsProjectHelper):
         subrepoMenu.addAction(self.hgRemoveSubreposAct)
 
         mergeMenu = QMenu(self.tr("Merge Changesets"), menu)
-        mergeMenu.setIcon(UI.PixmapCache.getIcon("vcsMerge"))
+        mergeMenu.setIcon(EricPixmapCache.getIcon("vcsMerge"))
         mergeMenu.setTearOffEnabled(True)
         mergeMenu.addAction(self.vcsMergeAct)
         mergeMenu.addAction(self.hgShowConflictsAct)
@@ -1827,7 +1828,7 @@ class HgProjectHelper(VcsProjectHelper):
         mergeMenu.addAction(self.hgAbortMergeAct)
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsMercurial", "icons", "mercurial.svg")
             ),
             self.vcs.vcsName(),
@@ -1898,7 +1899,7 @@ class HgProjectHelper(VcsProjectHelper):
         self.__toolbarManager = toolbarManager
 
         self.__toolbar = QToolBar(self.tr("Mercurial"), ui)
-        self.__toolbar.setIconSize(UI.Config.ToolBarIconSize)
+        self.__toolbar.setIconSize(Config.ToolBarIconSize)
         self.__toolbar.setObjectName("MercurialToolbar")
         self.__toolbar.setToolTip(self.tr("Mercurial"))
 
