@@ -22,19 +22,18 @@ from PyQt6.QtWidgets import (
     QTreeWidgetItem,
 )
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
-from EricGui.EricOverrideCursor import EricOverrideCursor
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricGui.EricOverrideCursor import EricOverrideCursor
 
-from EricUtilities.EricMutexLocker import EricMutexLocker
+from eric7.EricUtilities.EricMutexLocker import EricMutexLocker
 
 from .SvnConst import svnStatusMap
 from .SvnDialogMixin import SvnDialogMixin
 
 from .Ui_SvnStatusDialog import Ui_SvnStatusDialog
 
-import Preferences
-import Utilities
+from eric7 import Preferences, Utilities
 
 
 class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
