@@ -17,20 +17,19 @@ import contextlib
 from PyQt6.QtCore import pyqtSignal, Qt, QDateTime, QCoreApplication
 from PyQt6.QtWidgets import QLineEdit, QDialog, QInputDialog, QApplication
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
 
-from EricUtilities.EricMutexLocker import EricMutexLocker
+from eric7.EricUtilities.EricMutexLocker import EricMutexLocker
 
-from VCS.VersionControl import VersionControl
+from eric7.VCS.VersionControl import VersionControl
 
 import pysvn
 
 from .SvnDialog import SvnDialog
 from .SvnUtilities import getConfigPath, amendConfig, createDefaultConfig
 
-import Preferences
-import Utilities
+from eric7 import Preferences, Utilities
 
 
 class Subversion(VersionControl):
@@ -1194,7 +1193,9 @@ class Subversion(VersionControl):
         project = ericApp().getObject("Project")
         names = [project.getRelativePath(nam) for nam in name]
         if names[0]:
-            from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+            from eric7.UI.DeleteFilesConfirmationDialog import (
+                DeleteFilesConfirmationDialog,
+            )
 
             dia = DeleteFilesConfirmationDialog(
                 self.parent(),
@@ -1760,7 +1761,7 @@ class Subversion(VersionControl):
             args = []
             self.addArguments(args, commandList)
 
-            from Plugins.VcsPlugins.vcsSubversion.SvnDialog import (
+            from eric7.Plugins.VcsPlugins.vcsSubversion.SvnDialog import (
                 SvnDialog as SvnProcessDialog,
             )
 
@@ -2315,7 +2316,7 @@ class Subversion(VersionControl):
                 return
 
         if self.sbsDiff is None:
-            from UI.CompareDialog import CompareDialog
+            from eric7.UI.CompareDialog import CompareDialog
 
             self.sbsDiff = CompareDialog()
         self.sbsDiff.show()
