@@ -11,12 +11,13 @@ import os
 
 from PyQt6.QtWidgets import QToolBar
 
-from VCS.ProjectHelper import VcsProjectHelper
+from eric7.VCS.ProjectHelper import VcsProjectHelper
 
-from EricGui.EricAction import EricAction
-from EricWidgets.EricApplication import ericApp
+from eric7.EricGui.EricAction import EricAction
+from eric7.EricWidgets.EricApplication import ericApp
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
+from eric7.UI import Config
 
 
 class SvnProjectHelper(VcsProjectHelper):
@@ -49,7 +50,7 @@ class SvnProjectHelper(VcsProjectHelper):
         """
         self.vcsNewAct = EricAction(
             self.tr("New from repository"),
-            UI.PixmapCache.getIcon("vcsCheckout"),
+            EricPixmapCache.getIcon("vcsCheckout"),
             self.tr("&New from repository..."),
             0,
             0,
@@ -71,7 +72,7 @@ class SvnProjectHelper(VcsProjectHelper):
 
         self.vcsUpdateAct = EricAction(
             self.tr("Update from repository"),
-            UI.PixmapCache.getIcon("vcsUpdate"),
+            EricPixmapCache.getIcon("vcsUpdate"),
             self.tr("&Update from repository"),
             0,
             0,
@@ -93,7 +94,7 @@ class SvnProjectHelper(VcsProjectHelper):
 
         self.vcsCommitAct = EricAction(
             self.tr("Commit changes to repository"),
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("&Commit changes to repository..."),
             0,
             0,
@@ -115,7 +116,7 @@ class SvnProjectHelper(VcsProjectHelper):
 
         self.svnLogBrowserAct = EricAction(
             self.tr("Show log browser"),
-            UI.PixmapCache.getIcon("vcsLog"),
+            EricPixmapCache.getIcon("vcsLog"),
             self.tr("Show log browser"),
             0,
             0,
@@ -138,7 +139,7 @@ class SvnProjectHelper(VcsProjectHelper):
 
         self.vcsDiffAct = EricAction(
             self.tr("Show differences"),
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show &difference"),
             0,
             0,
@@ -160,7 +161,7 @@ class SvnProjectHelper(VcsProjectHelper):
 
         self.svnExtDiffAct = EricAction(
             self.tr("Show differences (extended)"),
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (extended)"),
             0,
             0,
@@ -182,7 +183,7 @@ class SvnProjectHelper(VcsProjectHelper):
 
         self.svnUrlDiffAct = EricAction(
             self.tr("Show differences (URLs)"),
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (URLs)"),
             0,
             0,
@@ -204,7 +205,7 @@ class SvnProjectHelper(VcsProjectHelper):
 
         self.vcsStatusAct = EricAction(
             self.tr("Show status"),
-            UI.PixmapCache.getIcon("vcsStatus"),
+            EricPixmapCache.getIcon("vcsStatus"),
             self.tr("Show &status"),
             0,
             0,
@@ -223,7 +224,7 @@ class SvnProjectHelper(VcsProjectHelper):
 
         self.svnChangeListsAct = EricAction(
             self.tr("Show change lists"),
-            UI.PixmapCache.getIcon("vcsChangeLists"),
+            EricPixmapCache.getIcon("vcsChangeLists"),
             self.tr("Show change lists"),
             0,
             0,
@@ -245,7 +246,7 @@ class SvnProjectHelper(VcsProjectHelper):
 
         self.vcsTagAct = EricAction(
             self.tr("Tag in repository"),
-            UI.PixmapCache.getIcon("vcsTag"),
+            EricPixmapCache.getIcon("vcsTag"),
             self.tr("&Tag in repository..."),
             0,
             0,
@@ -264,7 +265,7 @@ class SvnProjectHelper(VcsProjectHelper):
 
         self.vcsExportAct = EricAction(
             self.tr("Export from repository"),
-            UI.PixmapCache.getIcon("vcsExport"),
+            EricPixmapCache.getIcon("vcsExport"),
             self.tr("&Export from repository..."),
             0,
             0,
@@ -301,7 +302,7 @@ class SvnProjectHelper(VcsProjectHelper):
 
         self.vcsRevertAct = EricAction(
             self.tr("Revert changes"),
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Re&vert changes"),
             0,
             0,
@@ -322,7 +323,7 @@ class SvnProjectHelper(VcsProjectHelper):
 
         self.vcsMergeAct = EricAction(
             self.tr("Merge"),
-            UI.PixmapCache.getIcon("vcsMerge"),
+            EricPixmapCache.getIcon("vcsMerge"),
             self.tr("Mer&ge changes..."),
             0,
             0,
@@ -344,7 +345,7 @@ class SvnProjectHelper(VcsProjectHelper):
 
         self.vcsSwitchAct = EricAction(
             self.tr("Switch"),
-            UI.PixmapCache.getIcon("vcsSwitch"),
+            EricPixmapCache.getIcon("vcsSwitch"),
             self.tr("S&witch..."),
             0,
             0,
@@ -528,7 +529,7 @@ class SvnProjectHelper(VcsProjectHelper):
 
         self.svnRelocateAct = EricAction(
             self.tr("Relocate"),
-            UI.PixmapCache.getIcon("vcsSwitch"),
+            EricPixmapCache.getIcon("vcsSwitch"),
             self.tr("Relocate..."),
             0,
             0,
@@ -550,7 +551,7 @@ class SvnProjectHelper(VcsProjectHelper):
 
         self.svnRepoBrowserAct = EricAction(
             self.tr("Repository Browser"),
-            UI.PixmapCache.getIcon("vcsRepoBrowser"),
+            EricPixmapCache.getIcon("vcsRepoBrowser"),
             self.tr("Repository Browser..."),
             0,
             0,
@@ -614,7 +615,7 @@ class SvnProjectHelper(VcsProjectHelper):
         menu.clear()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsSubversion", "icons", "subversion.svg")
             ),
             self.vcs.vcsName(),
@@ -677,7 +678,7 @@ class SvnProjectHelper(VcsProjectHelper):
             (EricToolBarManager)
         """
         self.__toolbar = QToolBar(self.tr("Subversion (svn)"), ui)
-        self.__toolbar.setIconSize(UI.Config.ToolBarIconSize)
+        self.__toolbar.setIconSize(Config.ToolBarIconSize)
         self.__toolbar.setObjectName("SubversionToolbar")
         self.__toolbar.setToolTip(self.tr("Subversion (svn)"))
 
