@@ -15,16 +15,15 @@ from urllib.parse import quote
 from PyQt6.QtCore import pyqtSignal, QProcess, QCoreApplication
 from PyQt6.QtWidgets import QLineEdit, QDialog, QInputDialog, QApplication
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
 
-from VCS.VersionControl import VersionControl
+from eric7.VCS.VersionControl import VersionControl
 
 from .SvnDialog import SvnDialog
 from .SvnUtilities import getConfigPath, amendConfig, createDefaultConfig
 
-import Preferences
-import Utilities
+from eric7 import Preferences, Utilities
 
 
 class Subversion(VersionControl):
@@ -1091,7 +1090,9 @@ class Subversion(VersionControl):
         project = ericApp().getObject("Project")
         names = [project.getRelativePath(nam) for nam in names]
         if names[0]:
-            from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+            from eric7.UI.DeleteFilesConfirmationDialog import (
+                DeleteFilesConfirmationDialog,
+            )
 
             dlg = DeleteFilesConfirmationDialog(
                 self.parent(),
@@ -2122,7 +2123,7 @@ class Subversion(VersionControl):
                 return
 
         if self.sbsDiff is None:
-            from UI.CompareDialog import CompareDialog
+            from eric7.UI.CompareDialog import CompareDialog
 
             self.sbsDiff = CompareDialog()
         self.sbsDiff.show()
