@@ -13,7 +13,7 @@ from PyQt6.QtCore import pyqtSlot
 from PyQt6.QtGui import QColor
 from PyQt6.QtWidgets import QColorDialog, QDialog, QDialogButtonBox
 
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets import EricMessageBox
 
 from .Ui_ColorDialogWizardDialog import Ui_ColorDialogWizardDialog
 
@@ -168,7 +168,7 @@ class ColorDialogWizardDialog(QDialog, Ui_ColorDialogWizardDialog):
                 istring, self.eTitle.text(), os.linesep
             )
             code += "{0}QColorDialog.ColorDialogOption.ShowAlphaChannel".format(istring)
-            code += "{0}){0}".format(estring)
+            code += ",{0}){0}".format(estring)
         elif self.rRGBA.isChecked():
             code += "getColor({0}".format(os.linesep)
             if not self.eRGB.text():
@@ -187,6 +187,6 @@ class ColorDialogWizardDialog(QDialog, Ui_ColorDialogWizardDialog):
                 istring, self.eTitle.text(), os.linesep
             )
             code += "{0}QColorDialog.ColorDialogOption.ShowAlphaChannel".format(istring)
-            code += "{0}){0}".format(estring)
+            code += ",{0}){0}".format(estring)
 
         return code
