@@ -23,15 +23,14 @@ from PyQt6.QtWidgets import (
     QTableWidgetItem,
 )
 
-from EricWidgets import EricMessageBox, EricFileDialog
-from EricWidgets.EricMainWindow import EricMainWindow
+from eric7.EricWidgets import EricMessageBox, EricFileDialog
+from eric7.EricWidgets.EricMainWindow import EricMainWindow
 
 from .Ui_PyRegExpWizardDialog import Ui_PyRegExpWizardDialog
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
-import Utilities
-import Preferences
+from eric7 import Preferences, Utilities
 
 
 class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
@@ -50,25 +49,25 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
         self.setupUi(self)
 
         # initialize icons of the tool buttons
-        self.commentButton.setIcon(UI.PixmapCache.getIcon("comment"))
-        self.charButton.setIcon(UI.PixmapCache.getIcon("characters"))
-        self.anycharButton.setIcon(UI.PixmapCache.getIcon("anychar"))
-        self.repeatButton.setIcon(UI.PixmapCache.getIcon("repeat"))
-        self.nonGroupButton.setIcon(UI.PixmapCache.getIcon("nongroup"))
-        self.groupButton.setIcon(UI.PixmapCache.getIcon("group"))
-        self.namedGroupButton.setIcon(UI.PixmapCache.getIcon("namedgroup"))
-        self.namedReferenceButton.setIcon(UI.PixmapCache.getIcon("namedreference"))
-        self.altnButton.setIcon(UI.PixmapCache.getIcon("altn"))
-        self.beglineButton.setIcon(UI.PixmapCache.getIcon("begline"))
-        self.endlineButton.setIcon(UI.PixmapCache.getIcon("endline"))
-        self.wordboundButton.setIcon(UI.PixmapCache.getIcon("wordboundary"))
-        self.nonwordboundButton.setIcon(UI.PixmapCache.getIcon("nonwordboundary"))
-        self.poslookaheadButton.setIcon(UI.PixmapCache.getIcon("poslookahead"))
-        self.neglookaheadButton.setIcon(UI.PixmapCache.getIcon("neglookahead"))
-        self.poslookbehindButton.setIcon(UI.PixmapCache.getIcon("poslookbehind"))
-        self.neglookbehindButton.setIcon(UI.PixmapCache.getIcon("neglookbehind"))
-        self.undoButton.setIcon(UI.PixmapCache.getIcon("editUndo"))
-        self.redoButton.setIcon(UI.PixmapCache.getIcon("editRedo"))
+        self.commentButton.setIcon(EricPixmapCache.getIcon("comment"))
+        self.charButton.setIcon(EricPixmapCache.getIcon("characters"))
+        self.anycharButton.setIcon(EricPixmapCache.getIcon("anychar"))
+        self.repeatButton.setIcon(EricPixmapCache.getIcon("repeat"))
+        self.nonGroupButton.setIcon(EricPixmapCache.getIcon("nongroup"))
+        self.groupButton.setIcon(EricPixmapCache.getIcon("group"))
+        self.namedGroupButton.setIcon(EricPixmapCache.getIcon("namedgroup"))
+        self.namedReferenceButton.setIcon(EricPixmapCache.getIcon("namedreference"))
+        self.altnButton.setIcon(EricPixmapCache.getIcon("altn"))
+        self.beglineButton.setIcon(EricPixmapCache.getIcon("begline"))
+        self.endlineButton.setIcon(EricPixmapCache.getIcon("endline"))
+        self.wordboundButton.setIcon(EricPixmapCache.getIcon("wordboundary"))
+        self.nonwordboundButton.setIcon(EricPixmapCache.getIcon("nonwordboundary"))
+        self.poslookaheadButton.setIcon(EricPixmapCache.getIcon("poslookahead"))
+        self.neglookaheadButton.setIcon(EricPixmapCache.getIcon("neglookahead"))
+        self.poslookbehindButton.setIcon(EricPixmapCache.getIcon("poslookbehind"))
+        self.neglookbehindButton.setIcon(EricPixmapCache.getIcon("neglookbehind"))
+        self.undoButton.setIcon(EricPixmapCache.getIcon("editUndo"))
+        self.redoButton.setIcon(EricPixmapCache.getIcon("editRedo"))
 
         self.namedGroups = re.compile(r"""\(?P<([^>]+)>""").findall
 
@@ -651,14 +650,14 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
 
         code = ""
         if self.importCheckBox.isChecked():
-            code += "import re{0}{1}".format(os.linesep, istring)
+            code += "import re{0}{0}{1}".format(os.linesep, istring)
         code += "{0} = re.compile(".format(reVar)
         code += '{0}{1}r"""{2}"""'.format(
             os.linesep, i1string, regexp.replace('"', '\\"')
         )
         if flags:
             code += ",{0}{1}{2}".format(os.linesep, i1string, flags)
-        code += "{0}){0}".format(estring)
+        code += ",{0}){0}".format(estring)
         return code
 
 
