@@ -24,16 +24,14 @@ from PyQt6.QtWidgets import (
     QTableWidgetItem,
 )
 
-from EricWidgets import EricMessageBox, EricFileDialog
-from EricWidgets.EricMainWindow import EricMainWindow
+from eric7.EricWidgets import EricMessageBox, EricFileDialog
+from eric7.EricWidgets.EricMainWindow import EricMainWindow
 
 from .Ui_QRegularExpressionWizardDialog import Ui_QRegularExpressionWizardDialog
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
-import Globals
-import Utilities
-import Preferences
+from eric7 import Globals, Preferences, Utilities
 
 
 class QRegularExpressionWizardWidget(QWidget, Ui_QRegularExpressionWizardDialog):
@@ -52,26 +50,26 @@ class QRegularExpressionWizardWidget(QWidget, Ui_QRegularExpressionWizardDialog)
         self.setupUi(self)
 
         # initialize icons of the tool buttons
-        self.commentButton.setIcon(UI.PixmapCache.getIcon("comment"))
-        self.charButton.setIcon(UI.PixmapCache.getIcon("characters"))
-        self.anycharButton.setIcon(UI.PixmapCache.getIcon("anychar"))
-        self.repeatButton.setIcon(UI.PixmapCache.getIcon("repeat"))
-        self.nonGroupButton.setIcon(UI.PixmapCache.getIcon("nongroup"))
-        self.atomicGroupButton.setIcon(UI.PixmapCache.getIcon("atomicgroup"))
-        self.groupButton.setIcon(UI.PixmapCache.getIcon("group"))
-        self.namedGroupButton.setIcon(UI.PixmapCache.getIcon("namedgroup"))
-        self.namedReferenceButton.setIcon(UI.PixmapCache.getIcon("namedreference"))
-        self.altnButton.setIcon(UI.PixmapCache.getIcon("altn"))
-        self.beglineButton.setIcon(UI.PixmapCache.getIcon("begline"))
-        self.endlineButton.setIcon(UI.PixmapCache.getIcon("endline"))
-        self.wordboundButton.setIcon(UI.PixmapCache.getIcon("wordboundary"))
-        self.nonwordboundButton.setIcon(UI.PixmapCache.getIcon("nonwordboundary"))
-        self.poslookaheadButton.setIcon(UI.PixmapCache.getIcon("poslookahead"))
-        self.neglookaheadButton.setIcon(UI.PixmapCache.getIcon("neglookahead"))
-        self.poslookbehindButton.setIcon(UI.PixmapCache.getIcon("poslookbehind"))
-        self.neglookbehindButton.setIcon(UI.PixmapCache.getIcon("neglookbehind"))
-        self.undoButton.setIcon(UI.PixmapCache.getIcon("editUndo"))
-        self.redoButton.setIcon(UI.PixmapCache.getIcon("editRedo"))
+        self.commentButton.setIcon(EricPixmapCache.getIcon("comment"))
+        self.charButton.setIcon(EricPixmapCache.getIcon("characters"))
+        self.anycharButton.setIcon(EricPixmapCache.getIcon("anychar"))
+        self.repeatButton.setIcon(EricPixmapCache.getIcon("repeat"))
+        self.nonGroupButton.setIcon(EricPixmapCache.getIcon("nongroup"))
+        self.atomicGroupButton.setIcon(EricPixmapCache.getIcon("atomicgroup"))
+        self.groupButton.setIcon(EricPixmapCache.getIcon("group"))
+        self.namedGroupButton.setIcon(EricPixmapCache.getIcon("namedgroup"))
+        self.namedReferenceButton.setIcon(EricPixmapCache.getIcon("namedreference"))
+        self.altnButton.setIcon(EricPixmapCache.getIcon("altn"))
+        self.beglineButton.setIcon(EricPixmapCache.getIcon("begline"))
+        self.endlineButton.setIcon(EricPixmapCache.getIcon("endline"))
+        self.wordboundButton.setIcon(EricPixmapCache.getIcon("wordboundary"))
+        self.nonwordboundButton.setIcon(EricPixmapCache.getIcon("nonwordboundary"))
+        self.poslookaheadButton.setIcon(EricPixmapCache.getIcon("poslookahead"))
+        self.neglookaheadButton.setIcon(EricPixmapCache.getIcon("neglookahead"))
+        self.poslookbehindButton.setIcon(EricPixmapCache.getIcon("poslookbehind"))
+        self.neglookbehindButton.setIcon(EricPixmapCache.getIcon("neglookbehind"))
+        self.undoButton.setIcon(EricPixmapCache.getIcon("editUndo"))
+        self.redoButton.setIcon(EricPixmapCache.getIcon("editRedo"))
 
         self.namedGroups = re.compile(r"""\(?P<([^>]+)>""").findall
 
@@ -795,7 +793,7 @@ class QRegularExpressionWizardWidget(QWidget, Ui_QRegularExpressionWizardDialog)
             )
         if self.captureCheckBox.isChecked():
             options.append("QRegularExpression.PatternOption.DontCaptureOption")
-        options = " |{0}{1}".format(os.linesep, i1string).join(options)
+        options = "{0}{1}| ".format(os.linesep, i1string).join(options)
 
         code = "{0} = QRegularExpression(".format(reVar)
         if options:
@@ -805,7 +803,7 @@ class QRegularExpressionWizardWidget(QWidget, Ui_QRegularExpressionWizardDialog)
             code += "{0}{1}{2}".format(os.linesep, i1string, options)
         else:
             code += 'r"""{0}"""'.format(regexp.replace('"', '\\"'))
-        code += "{0}){0}".format(estring)
+        code += ",{0}){0}".format(estring)
         return code
 
 
