@@ -34,15 +34,15 @@ from PyQt6.QtWidgets import (
     QLineEdit,
 )
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
-from EricWidgets.EricMainWindow import EricMainWindow
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricMainWindow import EricMainWindow
 
-from Globals import isMacPlatform, getWebBrowserSupport
+from eric7.Globals import isMacPlatform, getWebBrowserSupport
 
-import Preferences
+from eric7 import Preferences
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
 from eric7config import getConfig
 
@@ -63,7 +63,7 @@ class ConfigurationPageItem(QTreeWidgetItem):
         @param iconFile file name of the icon to be shown (string)
         """
         super().__init__(parent, [text])
-        self.setIcon(0, UI.PixmapCache.getIcon(iconFile))
+        self.setIcon(0, EricPixmapCache.getIcon(iconFile))
 
         self.__pageName = pageName
 
@@ -136,7 +136,7 @@ class ConfigurationWidget(QWidget):
         self.itmDict = {}
 
         if not fromEric:
-            from PluginManager.PluginManager import PluginManager
+            from eric7.PluginManager.PluginManager import PluginManager
 
             try:
                 self.pluginManager = ericApp().getObject("PluginManager")
@@ -144,7 +144,7 @@ class ConfigurationWidget(QWidget):
                 self.pluginManager = PluginManager(self)
                 ericApp().registerObject("PluginManager", self.pluginManager)
 
-            from VirtualEnv.VirtualenvManager import VirtualenvManager
+            from eric7.VirtualEnv.VirtualenvManager import VirtualenvManager
 
             try:
                 self.virtualenvManager = ericApp().getObject("VirtualEnvManager")
@@ -1101,11 +1101,11 @@ class ConfigurationWidget(QWidget):
         """
         Private method to initialize the dictionary of preferences lexers.
         """
-        import QScintilla.Lexers
+        from eric7.QScintilla import Lexers
         from .PreferencesLexer import PreferencesLexer, PreferencesLexerLanguageError
 
         self.lexers = {}
-        for language in QScintilla.Lexers.getSupportedLanguages():
+        for language in Lexers.getSupportedLanguages():
             if language not in self.lexers:
                 with contextlib.suppress(PreferencesLexerLanguageError):
                     self.lexers[language] = PreferencesLexer(language, self)
@@ -1117,7 +1117,7 @@ class ConfigurationWidget(QWidget):
         @param name name of the configuration page module (string)
         @return reference to the configuration page module
         """
-        modName = "Preferences.ConfigurationPages.{0}".format(name)
+        modName = "eric7.Preferences.ConfigurationPages.{0}".format(name)
         try:
             mod = __import__(modName)
             components = modName.split(".")
