@@ -24,9 +24,9 @@ from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_EditorHighlightingStylesPage import Ui_EditorHighlightingStylesPage
 from ..SubstyleDefinitionDialog import SubstyleDefinitionDialog
 
-from EricWidgets import EricMessageBox, EricFileDialog
+from eric7.EricWidgets import EricMessageBox, EricFileDialog
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
 
 class EditorHighlightingStylesPage(
@@ -54,11 +54,11 @@ class EditorHighlightingStylesPage(
         self.setupUi(self)
         self.setObjectName("EditorHighlightingStylesPage")
 
-        self.defaultSubstylesButton.setIcon(UI.PixmapCache.getIcon("editUndo"))
-        self.addSubstyleButton.setIcon(UI.PixmapCache.getIcon("plus"))
-        self.deleteSubstyleButton.setIcon(UI.PixmapCache.getIcon("minus"))
-        self.editSubstyleButton.setIcon(UI.PixmapCache.getIcon("edit"))
-        self.copySubstyleButton.setIcon(UI.PixmapCache.getIcon("editCopy"))
+        self.defaultSubstylesButton.setIcon(EricPixmapCache.getIcon("editUndo"))
+        self.addSubstyleButton.setIcon(EricPixmapCache.getIcon("plus"))
+        self.deleteSubstyleButton.setIcon(EricPixmapCache.getIcon("minus"))
+        self.editSubstyleButton.setIcon(EricPixmapCache.getIcon("edit"))
+        self.copySubstyleButton.setIcon(EricPixmapCache.getIcon("editCopy"))
 
         self.__fontButtonMenu = QMenu()
         act = self.__fontButtonMenu.addAction(self.tr("Font"))
@@ -90,12 +90,12 @@ class EditorHighlightingStylesPage(
         self.lexers = lexers
 
         # set initial values
-        import QScintilla.Lexers
+        from eric7.QScintilla import Lexers
 
         languages = sorted([""] + list(self.lexers.keys()))
         for language in languages:
             self.lexerLanguageComboBox.addItem(
-                QScintilla.Lexers.getLanguageIcon(language, False), language
+                Lexers.getLanguageIcon(language, False), language
             )
         self.on_lexerLanguageComboBox_activated(0)
 
@@ -597,7 +597,7 @@ class EditorHighlightingStylesPage(
         )
 
         if ok:
-            from Preferences.HighlightingStylesFile import HighlightingStylesFile
+            from eric7.Preferences.HighlightingStylesFile import HighlightingStylesFile
 
             highlightingStylesFile = HighlightingStylesFile()
             highlightingStylesFile.writeFile(str(fpath), lexers)
@@ -629,7 +629,7 @@ class EditorHighlightingStylesPage(
 
         if fn.endswith(".ehj"):
             # new JSON based file
-            from Preferences.HighlightingStylesFile import HighlightingStylesFile
+            from eric7.Preferences.HighlightingStylesFile import HighlightingStylesFile
 
             highlightingStylesFile = HighlightingStylesFile()
             styles = highlightingStylesFile.readFile(fn)
@@ -639,7 +639,9 @@ class EditorHighlightingStylesPage(
             # old XML based file
             f = QFile(fn)
             if f.open(QIODevice.OpenModeFlag.ReadOnly):
-                from EricXML.HighlightingStylesReader import HighlightingStylesReader
+                from eric7.EricXML.HighlightingStylesReader import (
+                    HighlightingStylesReader,
+                )
 
                 reader = HighlightingStylesReader(f, self.lexers)
                 styles = reader.readXML()
