@@ -14,13 +14,13 @@ from PyQt6.QtCore import pyqtSignal, pyqtSlot, Qt
 from PyQt6.QtGui import QKeySequence
 from PyQt6.QtWidgets import QHeaderView, QDialog, QTreeWidgetItem
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
 
 from .Ui_ShortcutsDialog import Ui_ShortcutsDialog
 
-import Preferences
-from Preferences import Shortcuts
+from eric7 import Preferences
+from eric7.Preferences import Shortcuts
 
 
 class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
