@@ -13,11 +13,11 @@ import typing
 
 from PyQt6.QtCore import QObject
 
-from EricWidgets import EricMessageBox
-from EricGui.EricOverrideCursor import EricOverridenCursor
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricGui.EricOverrideCursor import EricOverridenCursor
+from eric7.EricWidgets.EricApplication import ericApp
 
-import Preferences
+from eric7 import Preferences
 
 HelpViewer = typing.TypeVar("WebBrowserWindow")
 
