@@ -12,7 +12,7 @@ import os
 from PyQt6.QtCore import pyqtSlot
 from PyQt6.QtWidgets import QDialog
 
-from EricWidgets.EricPathPicker import EricPathPickerModes
+from eric7.EricWidgets.EricPathPicker import EricPathPickerModes
 
 from .Ui_AddFileDialog import Ui_AddFileDialog
 
