@@ -24,16 +24,15 @@ from PyQt6.QtGui import QStandardItemModel, QStandardItem, QBrush, QColor
 from PyQt6.QtWidgets import QDialog, QDialogButtonBox
 
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
 
 from .Ui_CreateDialogCodeDialog import Ui_CreateDialogCodeDialog
 from .NewDialogClassDialog import NewDialogClassDialog
 
 from eric7config import getConfig
 
-import Globals
-import Preferences
+from eric7 import Globals, Preferences
 
 
 pyqtSignatureRole = Qt.ItemDataRole.UserRole + 1
@@ -117,7 +116,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
             with contextlib.suppress(ImportError):
                 splitExt = os.path.splitext(self.srcFile)
                 exts = [splitExt[1]] if len(splitExt) == 2 else None
-                from Utilities import ModuleParser
+                from eric7.Utilities import ModuleParser
 
                 self.__module = ModuleParser.readModule(
                     self.srcFile, extensions=exts, caching=False
@@ -526,7 +525,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                     child.flags() & Qt.ItemFlag.ItemIsUserCheckable
                     == Qt.ItemFlag.ItemIsUserCheckable
                 ):
-                    slotsCode.append("{0}\n".format(indentStr))
+                    slotsCode.append("\n")
                     slotsCode.append(
                         "{0}{1}\n".format(
                             indentStr,
@@ -544,7 +543,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                         "{0}Slot documentation goes here.\n".format(indentStr2)
                     )
                     if child.data(returnTypeRole) or child.data(parameterTypesListRole):
-                        slotsCode.append("{0}\n".format(indentStr2))
+                        slotsCode.append("\n")
                         if child.data(parameterTypesListRole):
                             for name, type_ in zip(
                                 child.data(parameterNamesListRole),
