@@ -16,9 +16,9 @@ import pathlib
 from PyQt6.QtCore import QThread, pyqtSignal, QProcess
 from PyQt6.QtWidgets import QDialog, QInputDialog, QApplication, QMenu
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox, EricFileDialog
-from EricWidgets.EricProgressDialog import EricProgressDialog
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox, EricFileDialog
+from eric7.EricWidgets.EricProgressDialog import EricProgressDialog
 
 from .ProjectBrowserModel import (
     ProjectBrowserFileItem,
@@ -28,12 +28,11 @@ from .ProjectBrowserModel import (
 )
 from .ProjectBaseBrowser import ProjectBaseBrowser
 
-import UI.PixmapCache
-from UI.NotificationWidget import NotificationTypes
+from eric7.EricGui import EricPixmapCache
+from eric7.UI.NotificationWidget import NotificationTypes
 
 
-import Preferences
-import Utilities
+from eric7 import Preferences, Utilities
 
 from eric7config import getConfig
 
@@ -668,7 +667,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
             fn = self.project.getRelativePath(fn2)
             files.append(fn)
 
-        from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+        from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
         dlg = DeleteFilesConfirmationDialog(
             self.parent(),
@@ -777,14 +776,14 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                 if self.compiledFile not in self.project.pdata["SOURCES"]:
                     self.project.appendFile(ofn)
                 ui.showNotification(
-                    UI.PixmapCache.getPixmap("designer48"),
+                    EricPixmapCache.getPixmap("designer48"),
                     self.tr("Form Compilation"),
                     self.tr("The compilation of the form file" " was successful."),
                 )
                 self.project.projectFormCompiled.emit(self.compiledFile)
             except OSError as msg:
                 ui.showNotification(
-                    UI.PixmapCache.getPixmap("designer48"),
+                    EricPixmapCache.getPixmap("designer48"),
                     self.tr("Form Compilation"),
                     self.tr(
                         "<p>The compilation of the form file failed.</p>"
@@ -795,7 +794,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                 )
         else:
             ui.showNotification(
-                UI.PixmapCache.getPixmap("designer48"),
+                EricPixmapCache.getPixmap("designer48"),
                 self.tr("Form Compilation"),
                 self.tr("The compilation of the form file failed."),
                 kind=NotificationTypes.CRITICAL,
@@ -909,14 +908,14 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
             sys.path.insert(0, self.project.getProjectPath())
             cwd = os.getcwd()
             os.chdir(os.path.dirname(os.path.abspath(fn)))
-
-            dlg = CreateDialogCodeDialog(fn, self.project, self)
-            if not dlg.initError():
-                dlg.exec()
-
-            # reset the environment
-            os.chdir(cwd)
-            del sys.path[0]
+            try:
+                dlg = CreateDialogCodeDialog(fn, self.project, self)
+                if not dlg.initError():
+                    dlg.exec()
+            finally:
+                # reset the environment
+                os.chdir(cwd)
+                del sys.path[0]
 
     def __compileForm(self):
         """
