@@ -15,9 +15,9 @@ import contextlib
 from PyQt6.QtCore import QThread, pyqtSignal, QProcess
 from PyQt6.QtWidgets import QDialog, QApplication, QMenu
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
-from EricWidgets.EricProgressDialog import EricProgressDialog
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricProgressDialog import EricProgressDialog
 
 from .ProjectBrowserModel import (
     ProjectBrowserFileItem,
@@ -27,17 +27,16 @@ from .ProjectBrowserModel import (
 )
 from .ProjectBaseBrowser import ProjectBaseBrowser
 
-from UI.BrowserModel import (
+from eric7.UI.BrowserModel import (
     BrowserFileItem,
     BrowserClassItem,
     BrowserMethodItem,
     BrowserClassAttributeItem,
 )
-import UI.PixmapCache
-from UI.NotificationWidget import NotificationTypes
+from eric7.EricGui import EricPixmapCache
+from eric7.UI.NotificationWidget import NotificationTypes
 
-import Preferences
-import Utilities
+from eric7 import Preferences, Utilities
 
 
 class ProjectInterfacesBrowser(ProjectBaseBrowser):
@@ -459,7 +458,7 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
             fn = self.project.getRelativePath(fn2)
             files.append(fn)
 
-        from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+        from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
         dlg = DeleteFilesConfirmationDialog(
             self.parent(),
@@ -532,13 +531,13 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
             for file in fileList:
                 self.project.appendFile(file)
             ui.showNotification(
-                UI.PixmapCache.getPixmap("corba48"),
+                EricPixmapCache.getPixmap("corba48"),
                 self.tr("Interface Compilation"),
                 self.tr("The compilation of the interface file was" " successful."),
             )
         else:
             ui.showNotification(
-                UI.PixmapCache.getPixmap("corba48"),
+                EricPixmapCache.getPixmap("corba48"),
                 self.tr("Interface Compilation"),
                 self.tr("The compilation of the interface file failed."),
                 kind=NotificationTypes.CRITICAL,
