@@ -15,9 +15,9 @@ import contextlib
 from PyQt6.QtCore import QThread, pyqtSignal, QProcess
 from PyQt6.QtWidgets import QDialog, QApplication, QMenu
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
-from EricWidgets.EricProgressDialog import EricProgressDialog
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricProgressDialog import EricProgressDialog
 
 from .ProjectBrowserModel import (
     ProjectBrowserFileItem,
@@ -27,18 +27,16 @@ from .ProjectBrowserModel import (
 )
 from .ProjectBaseBrowser import ProjectBaseBrowser
 
-from UI.BrowserModel import (
+from eric7.UI.BrowserModel import (
     BrowserFileItem,
     BrowserClassItem,
     BrowserMethodItem,
     BrowserClassAttributeItem,
 )
-import UI.PixmapCache
-from UI.NotificationWidget import NotificationTypes
+from eric7.EricGui import EricPixmapCache
+from eric7.UI.NotificationWidget import NotificationTypes
 
-import Globals
-import Preferences
-import Utilities
+from eric7 import Globals, Preferences, Utilities
 
 
 class ProjectProtocolsBrowser(ProjectBaseBrowser):
@@ -466,7 +464,7 @@ class ProjectProtocolsBrowser(ProjectBaseBrowser):
             fn = self.project.getRelativePath(fn2)
             files.append(fn)
 
-        from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+        from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
         dlg = DeleteFilesConfirmationDialog(
             self.parent(),
@@ -567,9 +565,9 @@ class ProjectProtocolsBrowser(ProjectBaseBrowser):
             for file in fileList:
                 self.project.appendFile(file)
             if grpc:
-                icon = UI.PixmapCache.getPixmap("gRPC48")
+                icon = EricPixmapCache.getPixmap("gRPC48")
             else:
-                icon = UI.PixmapCache.getPixmap("protobuf48")
+                icon = EricPixmapCache.getPixmap("protobuf48")
             ui.showNotification(
                 icon,
                 self.tr("Protocol Compilation"),
@@ -577,9 +575,9 @@ class ProjectProtocolsBrowser(ProjectBaseBrowser):
             )
         else:
             if grpc:
-                icon = UI.PixmapCache.getPixmap("gRPC48")
+                icon = EricPixmapCache.getPixmap("gRPC48")
             else:
-                icon = UI.PixmapCache.getPixmap("protobuf48")
+                icon = EricPixmapCache.getPixmap("protobuf48")
             ui.showNotification(
                 icon,
                 self.tr("Protocol Compilation"),
