@@ -14,9 +14,9 @@ import pathlib
 from PyQt6.QtCore import QThread, pyqtSignal, QProcess
 from PyQt6.QtWidgets import QDialog, QApplication, QMenu
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox, EricFileDialog
-from EricWidgets.EricProgressDialog import EricProgressDialog
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox, EricFileDialog
+from eric7.EricWidgets.EricProgressDialog import EricProgressDialog
 
 from .ProjectBrowserModel import (
     ProjectBrowserFileItem,
@@ -26,11 +26,10 @@ from .ProjectBrowserModel import (
 )
 from .ProjectBaseBrowser import ProjectBaseBrowser
 
-import UI.PixmapCache
-from UI.NotificationWidget import NotificationTypes
+from eric7.EricGui import EricPixmapCache
+from eric7.UI.NotificationWidget import NotificationTypes
 
-import Preferences
-import Utilities
+from eric7 import Preferences, Utilities
 
 
 class ProjectResourcesBrowser(ProjectBaseBrowser):
@@ -558,7 +557,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
             fn = self.project.getRelativePath(fn2)
             files.append(fn)
 
-        from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+        from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
         dlg = DeleteFilesConfirmationDialog(
             self.parent(),
@@ -633,7 +632,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                 if self.compiledFile not in self.project.pdata["SOURCES"]:
                     self.project.appendFile(ofn)
                 ui.showNotification(
-                    UI.PixmapCache.getPixmap("resourcesCompiler48"),
+                    EricPixmapCache.getPixmap("resourcesCompiler48"),
                     self.tr("Resource Compilation"),
                     self.tr("The compilation of the resource file" " was successful."),
                 )
@@ -649,7 +648,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                     )
         else:
             ui.showNotification(
-                UI.PixmapCache.getPixmap("resourcesCompiler48"),
+                EricPixmapCache.getPixmap("resourcesCompiler48"),
                 self.tr("Resource Compilation"),
                 self.tr("The compilation of the resource file failed."),
                 kind=NotificationTypes.CRITICAL,
