@@ -13,10 +13,10 @@ import contextlib
 from PyQt6.QtCore import QTimer
 from PyQt6.QtWidgets import QWidget, QGridLayout, QComboBox
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
-import UI.PixmapCache
-import Preferences
+from eric7.EricGui import EricPixmapCache
+from eric7 import Preferences
 
 
 class EditorAssembly(QWidget):
@@ -197,11 +197,11 @@ class EditorAssembly(QWidget):
                     items = []
                     for cl in entry.classes.values():
                         if cl.isPrivate():
-                            icon = UI.PixmapCache.getIcon("class_private")
+                            icon = EricPixmapCache.getIcon("class_private")
                         elif cl.isProtected():
-                            icon = UI.PixmapCache.getIcon("class_protected")
+                            icon = EricPixmapCache.getIcon("class_protected")
                         else:
-                            icon = UI.PixmapCache.getIcon("class")
+                            icon = EricPixmapCache.getIcon("class")
                         items.append((icon, cl.name, cl.lineno, cl.endlineno))
                     for itm in sorted(items, key=lambda x: (x[1], x[2])):
                         self.__membersCombo.addItem(itm[0], itm[1], itm[2])
@@ -211,20 +211,20 @@ class EditorAssembly(QWidget):
                     return
 
                 # step 2.1: add class methods
-                from Utilities.ModuleParser import Function
+                from eric7.Utilities.ModuleParser import Function
 
                 items = []
                 for meth in entry.methods.values():
                     if meth.modifier == Function.Static:
-                        icon = UI.PixmapCache.getIcon("method_static")
+                        icon = EricPixmapCache.getIcon("method_static")
                     elif meth.modifier == Function.Class:
-                        icon = UI.PixmapCache.getIcon("method_class")
+                        icon = EricPixmapCache.getIcon("method_class")
                     elif meth.isPrivate():
-                        icon = UI.PixmapCache.getIcon("method_private")
+                        icon = EricPixmapCache.getIcon("method_private")
                     elif meth.isProtected():
-                        icon = UI.PixmapCache.getIcon("method_protected")
+                        icon = EricPixmapCache.getIcon("method_protected")
                     else:
-                        icon = UI.PixmapCache.getIcon("method")
+                        icon = EricPixmapCache.getIcon("method")
                     items.append((icon, meth.name, meth.lineno, meth.endlineno))
                 for itm in sorted(items, key=lambda x: (x[1], x[2])):
                     self.__membersCombo.addItem(itm[0], itm[1], itm[2])
@@ -235,18 +235,18 @@ class EditorAssembly(QWidget):
                 items = []
                 for attr in entry.attributes.values():
                     if attr.isPrivate():
-                        icon = UI.PixmapCache.getIcon("attribute_private")
+                        icon = EricPixmapCache.getIcon("attribute_private")
                     elif attr.isProtected():
-                        icon = UI.PixmapCache.getIcon("attribute_protected")
+                        icon = EricPixmapCache.getIcon("attribute_protected")
                     else:
-                        icon = UI.PixmapCache.getIcon("attribute")
+                        icon = EricPixmapCache.getIcon("attribute")
                     items.append((icon, attr.name, attr.lineno))
                 for itm in sorted(items, key=lambda x: (x[1], x[2])):
                     self.__membersCombo.addItem(itm[0], itm[1], itm[2])
 
                 # step 2.3: add class attributes
                 items = []
-                icon = UI.PixmapCache.getIcon("attribute_class")
+                icon = EricPixmapCache.getIcon("attribute_class")
                 for globalVar in entry.globals.values():
                     items.append((icon, globalVar.name, globalVar.lineno))
                 for itm in sorted(items, key=lambda x: (x[1], x[2])):
@@ -282,7 +282,7 @@ class EditorAssembly(QWidget):
         Private method to parse the editor source and repopulate the globals
         combo.
         """
-        from Utilities.ModuleParser import Module, getTypeFromTypeName
+        from eric7.Utilities.ModuleParser import Module, getTypeFromTypeName
 
         self.__module = None
         sourceType = getTypeFromTypeName(self.__editor.determineFileType())
@@ -312,7 +312,7 @@ class EditorAssembly(QWidget):
                 for module in self.__module.modules.values():
                     items.append(
                         (
-                            UI.PixmapCache.getIcon("module"),
+                            EricPixmapCache.getIcon("module"),
                             module.name,
                             module.lineno,
                             module.endlineno,
@@ -327,11 +327,11 @@ class EditorAssembly(QWidget):
                 items = []
                 for cl in self.__module.classes.values():
                     if cl.isPrivate():
-                        icon = UI.PixmapCache.getIcon("class_private")
+                        icon = EricPixmapCache.getIcon("class_private")
                     elif cl.isProtected():
-                        icon = UI.PixmapCache.getIcon("class_protected")
+                        icon = EricPixmapCache.getIcon("class_protected")
                     else:
-                        icon = UI.PixmapCache.getIcon("class")
+                        icon = EricPixmapCache.getIcon("class")
                     items.append((icon, cl.name, cl.lineno, cl.endlineno))
                 for itm in sorted(items, key=lambda x: (x[1], x[2])):
                     self.__globalsCombo.addItem(itm[0], itm[1], itm[2])
@@ -342,11 +342,11 @@ class EditorAssembly(QWidget):
                 items = []
                 for func in self.__module.functions.values():
                     if func.isPrivate():
-                        icon = UI.PixmapCache.getIcon("method_private")
+                        icon = EricPixmapCache.getIcon("method_private")
                     elif func.isProtected():
-                        icon = UI.PixmapCache.getIcon("method_protected")
+                        icon = EricPixmapCache.getIcon("method_protected")
                     else:
-                        icon = UI.PixmapCache.getIcon("method")
+                        icon = EricPixmapCache.getIcon("method")
                     items.append((icon, func.name, func.lineno, func.endlineno))
                 for itm in sorted(items, key=lambda x: (x[1], x[2])):
                     self.__globalsCombo.addItem(itm[0], itm[1], itm[2])
@@ -357,11 +357,11 @@ class EditorAssembly(QWidget):
                 items = []
                 for globalValue in self.__module.globals.values():
                     if globalValue.isPrivate():
-                        icon = UI.PixmapCache.getIcon("attribute_private")
+                        icon = EricPixmapCache.getIcon("attribute_private")
                     elif globalValue.isProtected():
-                        icon = UI.PixmapCache.getIcon("attribute_protected")
+                        icon = EricPixmapCache.getIcon("attribute_protected")
                     else:
-                        icon = UI.PixmapCache.getIcon("attribute")
+                        icon = EricPixmapCache.getIcon("attribute")
                     items.append((icon, globalValue.name, globalValue.lineno))
                 for itm in sorted(items, key=lambda x: (x[1], x[2])):
                     self.__globalsCombo.addItem(itm[0], itm[1], itm[2])
