@@ -13,8 +13,8 @@ import functools
 from PyQt6.QtCore import pyqtSlot, Qt, QCoreApplication, QModelIndex, QPoint
 from PyQt6.QtWidgets import QTreeView, QAbstractItemView, QMenu, QApplication, QDialog
 
-from UI.BrowserSortFilterProxyModel import BrowserSortFilterProxyModel
-from UI.BrowserModel import (
+from eric7.UI.BrowserSortFilterProxyModel import BrowserSortFilterProxyModel
+from eric7.UI.BrowserModel import (
     BrowserImportsItem,
     BrowserGlobalsItem,
     BrowserClassAttributeItem,
@@ -23,7 +23,7 @@ from UI.BrowserModel import (
 
 from .EditorOutlineModel import EditorOutlineModel
 
-import Preferences
+from eric7 import Preferences
 
 
 class EditorOutlineView(QTreeView):
