@@ -15,9 +15,9 @@ from pygments.util import ClassNotFound
 
 from PyQt6.QtGui import QColor, QFont
 
-from QScintilla.Lexers.LexerContainer import LexerContainer
+from eric7.QScintilla.Lexers.LexerContainer import LexerContainer
 
-import Utilities
+from eric7 import Utilities
 
 PYGMENTS_DEFAULT = 0
 PYGMENTS_COMMENT = 1
