@@ -13,7 +13,7 @@ from PyQt6.QtGui import QColor
 
 from .Lexer import Lexer
 
-import Preferences
+from eric7 import Preferences
 
 
 class SubstyledLexer(Lexer):
