@@ -9,8 +9,8 @@ Package implementing lexers for the various supported programming languages.
 
 from PyQt6.QtCore import QCoreApplication
 
-import Preferences
-import UI.PixmapCache
+from eric7 import Preferences
+from eric7.EricGui import EricPixmapCache
 
 # The lexer registry
 # Dictionary with the language name as key. Each entry is a list with
@@ -272,9 +272,9 @@ def getLanguageIcon(language, pixmap):
         supportedLanguages[language][2] if language in supportedLanguages else ""
     )
     if pixmap:
-        return UI.PixmapCache.getPixmap(iconFileName)
+        return EricPixmapCache.getPixmap(iconFileName)
     else:
-        return UI.PixmapCache.getIcon(iconFileName)
+        return EricPixmapCache.getIcon(iconFileName)
 
 
 def getLexer(language, parent=None, pyname=""):
