@@ -22,12 +22,12 @@ from PyQt6.QtWidgets import (
 
 from .Editor import Editor
 
-from EricGui.EricAction import EricAction
-from EricWidgets import EricMessageBox
+from eric7.EricGui.EricAction import EricAction
+from eric7.EricWidgets import EricMessageBox
 
-import Preferences
+from eric7 import Preferences
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
 
 class SearchReplaceWidget(QWidget):
@@ -137,17 +137,17 @@ the documentation of your C++ runtime for details on what is supported.<p>
         self.setWhatsThis(whatsThis)
 
         # set icons
-        self.ui.closeButton.setIcon(UI.PixmapCache.getIcon("close"))
-        self.ui.findPrevButton.setIcon(UI.PixmapCache.getIcon("1leftarrow"))
-        self.ui.findNextButton.setIcon(UI.PixmapCache.getIcon("1rightarrow"))
-        self.ui.extendButton.setIcon(UI.PixmapCache.getIcon("2rightarrow"))
+        self.ui.closeButton.setIcon(EricPixmapCache.getIcon("close"))
+        self.ui.findPrevButton.setIcon(EricPixmapCache.getIcon("1leftarrow"))
+        self.ui.findNextButton.setIcon(EricPixmapCache.getIcon("1rightarrow"))
+        self.ui.extendButton.setIcon(EricPixmapCache.getIcon("2rightarrow"))
 
         if replace:
-            self.ui.replaceButton.setIcon(UI.PixmapCache.getIcon("editReplace"))
+            self.ui.replaceButton.setIcon(EricPixmapCache.getIcon("editReplace"))
             self.ui.replaceSearchButton.setIcon(
-                UI.PixmapCache.getIcon("editReplaceSearch")
+                EricPixmapCache.getIcon("editReplaceSearch")
             )
-            self.ui.replaceAllButton.setIcon(UI.PixmapCache.getIcon("editReplaceAll"))
+            self.ui.replaceAllButton.setIcon(EricPixmapCache.getIcon("editReplaceAll"))
 
         # set line edit completers
         self.ui.findtextCombo.setCompleter(None)
