@@ -27,17 +27,16 @@ from PyQt6.QtWidgets import (
 )
 from PyQt6.Qsci import QsciScintilla
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox, EricFileDialog
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox, EricFileDialog
 
 from .QsciScintillaCompat import QsciScintillaCompat
 
-import Preferences
-import Utilities
+from eric7 import Preferences, Utilities
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
-from Debugger.DebugClientCapabilities import HasCompleter
+from eric7.Debugger.DebugClientCapabilities import HasCompleter
 
 
 class ShellAssembly(QWidget):
@@ -64,7 +63,7 @@ class ShellAssembly(QWidget):
 
         self.__shell = Shell(dbs, vm, project, False, self)
 
-        from UI.SearchWidget import SearchWidget
+        from eric7.UI.SearchWidget import SearchWidget
 
         self.__searchWidget = SearchWidget(self.__shell, self, horizontal)
         self.__searchWidget.setSizePolicy(
@@ -345,7 +344,7 @@ class Shell(QsciScintillaCompat):
         self.__setAutoCompletion()
         self.__setCallTips()
 
-        self.setWindowIcon(UI.PixmapCache.getIcon("eric"))
+        self.setWindowIcon(EricPixmapCache.getIcon("eric"))
 
         self.incrementalSearchString = ""
         self.incrementalSearchActive = False
