@@ -13,8 +13,8 @@ from PyQt6.Qsci import QsciLexerPython, QsciScintilla
 
 from .CompleterBase import CompleterBase
 
-import Preferences
-from Utilities import rxIndex
+from eric7 import Preferences
+from eric7.Utilities import rxIndex
 
 
 class CompleterPython(CompleterBase):
