@@ -29,18 +29,17 @@ from PyQt6.QtWidgets import (
     QTreeWidgetItem,
 )
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
-from EricWidgets.EricProgressDialog import EricProgressDialog
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricProgressDialog import EricProgressDialog
 
 from .Task import Task, TaskType, TaskPriority
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
-import Preferences
-import Utilities
+from eric7 import Preferences, Utilities
 
-from Utilities.AutoSaver import AutoSaver
+from eric7.Utilities.AutoSaver import AutoSaver
 
 
 class TaskViewer(QTreeWidget):
@@ -67,8 +66,8 @@ class TaskViewer(QTreeWidget):
         self.__headerItem = QTreeWidgetItem(
             ["", "", self.tr("Summary"), self.tr("Filename"), self.tr("Line"), ""]
         )
-        self.__headerItem.setIcon(0, UI.PixmapCache.getIcon("taskCompleted"))
-        self.__headerItem.setIcon(1, UI.PixmapCache.getIcon("taskPriority"))
+        self.__headerItem.setIcon(0, EricPixmapCache.getIcon("taskCompleted"))
+        self.__headerItem.setIcon(1, EricPixmapCache.getIcon("taskPriority"))
         self.setHeaderItem(self.__headerItem)
 
         self.header().setSortIndicator(2, Qt.SortOrder.AscendingOrder)
@@ -172,7 +171,7 @@ class TaskViewer(QTreeWidget):
         self.customContextMenuRequested.connect(self.__showContextMenu)
         self.itemActivated.connect(self.__taskItemActivated)
 
-        self.setWindowIcon(UI.PixmapCache.getIcon("eric"))
+        self.setWindowIcon(EricPixmapCache.getIcon("eric"))
 
         self.__generateTopLevelItems()
 
