@@ -15,13 +15,11 @@ import re
 from PyQt6.QtCore import QFile, QIODevice, Qt, QCoreApplication
 from PyQt6.QtWidgets import QTreeWidget, QDialog, QApplication, QMenu, QTreeWidgetItem
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox, EricFileDialog
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox, EricFileDialog
 
-import Preferences
-
-import UI.PixmapCache
-import Utilities
+from eric7.EricGui import EricPixmapCache
+from eric7 import Preferences, Utilities
 
 from .TemplatesFile import TemplatesFile
 
@@ -437,7 +435,7 @@ class TemplateViewer(QTreeWidget):
         self.customContextMenuRequested.connect(self.__showContextMenu)
         self.itemActivated.connect(self.__templateItemActivated)
 
-        self.setWindowIcon(UI.PixmapCache.getIcon("eric"))
+        self.setWindowIcon(EricPixmapCache.getIcon("eric"))
 
     def __resort(self):
         """
@@ -1006,7 +1004,7 @@ class TemplateViewer(QTreeWidget):
         else:
             f = QFile(filename)
             if f.open(QIODevice.OpenModeFlag.ReadOnly):
-                from EricXML.TemplatesReader import TemplatesReader
+                from eric7.EricXML.TemplatesReader import TemplatesReader
 
                 reader = TemplatesReader(f, viewer=self)
                 reader.readXML()
