@@ -356,7 +356,7 @@ if __name__ == "__main__":
 
     elif command == "runtest":
         import pytest
-        from EricNetwork.EricJsonStreamWriter import EricJsonWriter
+        from eric7.EricNetwork.EricJsonStreamWriter import EricJsonWriter
 
         writer = EricJsonWriter(sys.argv[2], int(sys.argv[3]))
         pytest.main(sys.argv[4:], plugins=[EricPlugin(writer)])
