@@ -14,7 +14,7 @@ from enum import IntEnum
 
 from PyQt6.QtCore import pyqtSignal, QObject, QProcess, QProcessEnvironment
 
-import Preferences
+from eric7 import Preferences
 
 
 class TestResultCategory(IntEnum):
