@@ -27,9 +27,9 @@ from PyQt6.QtCore import (
 from PyQt6.QtGui import QBrush, QColor
 from PyQt6.QtWidgets import QMenu, QTreeView
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
-import Preferences
+from eric7 import Preferences
 
 from .Interfaces.TestExecutorBase import TestResultCategory
 
