@@ -24,9 +24,8 @@ from PyQt6.QtCore import (
 from PyQt6.QtGui import QImageReader, QFont
 from PyQt6.QtWidgets import QApplication
 
-import UI.PixmapCache
-import Preferences
-import Utilities
+from eric7.EricGui import EricPixmapCache
+from eric7 import Preferences, Utilities
 
 BrowserItemRoot = 0
 BrowserItemDirectory = 1
@@ -626,12 +625,12 @@ class BrowserModel(QAbstractItemModel):
         @param parentItem reference to the file item to be populated
         @param repopulate flag indicating a repopulation (boolean)
         """
-        import Utilities.ClassBrowsers
+        from eric7.Utilities import ClassBrowsers
 
         moduleName = parentItem.moduleName()
         fileName = parentItem.fileName()
         try:
-            dictionary = Utilities.ClassBrowsers.readmodule(
+            dictionary = ClassBrowsers.readmodule(
                 moduleName,
                 [parentItem.dirName()],
                 parentItem.isPython3File() or parentItem.isCythonFile(),
@@ -886,7 +885,7 @@ class BrowserItem:
         self.parentItem = parent
         self.itemData = [data]
         self.type_ = BrowserItemRoot
-        self.icon = UI.PixmapCache.getIcon("empty")
+        self.icon = EricPixmapCache.getIcon("empty")
         self._populated = True
         self._lazyPopulation = False
         self.symlink = False
@@ -1065,9 +1064,9 @@ class BrowserDirectoryItem(BrowserItem):
             and os.path.islink(self._dirName)
         ):
             self.symlink = True
-            self.icon = UI.PixmapCache.getSymlinkIcon("dirClosed")
+            self.icon = EricPixmapCache.getSymlinkIcon("dirClosed")
         else:
-            self.icon = UI.PixmapCache.getIcon("dirClosed")
+            self.icon = EricPixmapCache.getIcon("dirClosed")
         self._populated = False
         self._lazyPopulation = True
 
@@ -1129,7 +1128,7 @@ class BrowserSysPathItem(BrowserItem):
         BrowserItem.__init__(self, parent, "sys.path")
 
         self.type_ = BrowserItemSysPath
-        self.icon = UI.PixmapCache.getIcon("filePython")
+        self.icon = EricPixmapCache.getIcon("filePython")
         self._populated = False
         self._lazyPopulation = True
 
@@ -1223,9 +1222,9 @@ class BrowserFileItem(BrowserItem):
 
         if os.path.lexists(self._filename) and os.path.islink(self._filename):
             self.symlink = True
-            self.icon = UI.PixmapCache.getSymlinkIcon(pixName)
+            self.icon = EricPixmapCache.getSymlinkIcon(pixName)
         else:
-            self.icon = UI.PixmapCache.getIcon(pixName)
+            self.icon = EricPixmapCache.getIcon(pixName)
 
     def setName(self, finfo, full=True):
         """
@@ -1485,24 +1484,18 @@ class BrowserClassItem(BrowserItem):
         self._classObject = cl
         self._filename = filename
 
-        import Utilities.ClassBrowsers.ClbrBaseClasses
+        from eric7.Utilities.ClassBrowsers import ClbrBaseClasses
 
-        self.isfunction = isinstance(
-            self._classObject, Utilities.ClassBrowsers.ClbrBaseClasses.Function
-        )
-        self.ismodule = isinstance(
-            self._classObject, Utilities.ClassBrowsers.ClbrBaseClasses.Module
-        )
-        self.isenum = isinstance(
-            self._classObject, Utilities.ClassBrowsers.ClbrBaseClasses.Enum
-        )
+        self.isfunction = isinstance(self._classObject, ClbrBaseClasses.Function)
+        self.ismodule = isinstance(self._classObject, ClbrBaseClasses.Module)
+        self.isenum = isinstance(self._classObject, ClbrBaseClasses.Enum)
         if self.isfunction:
             if cl.isPrivate():
-                self.icon = UI.PixmapCache.getIcon("method_private")
+                self.icon = EricPixmapCache.getIcon("method_private")
             elif cl.isProtected():
-                self.icon = UI.PixmapCache.getIcon("method_protected")
+                self.icon = EricPixmapCache.getIcon("method_protected")
             else:
-                self.icon = UI.PixmapCache.getIcon("method")
+                self.icon = EricPixmapCache.getIcon("method")
             self.itemData[0] = "{0}({1})".format(
                 name, ", ".join(self._classObject.parameters)
             )
@@ -1515,16 +1508,16 @@ class BrowserClassItem(BrowserItem):
             # -            ", ".join([e.split('=')[0].strip()
             # -                       for e in self._classObject.parameters]))
         elif self.ismodule:
-            self.icon = UI.PixmapCache.getIcon("module")
+            self.icon = EricPixmapCache.getIcon("module")
         elif self.isenum:
-            self.icon = UI.PixmapCache.getIcon("attribute")
+            self.icon = EricPixmapCache.getIcon("attribute")
         else:
             if cl.isPrivate():
-                self.icon = UI.PixmapCache.getIcon("class_private")
+                self.icon = EricPixmapCache.getIcon("class_private")
             elif cl.isProtected():
-                self.icon = UI.PixmapCache.getIcon("class_protected")
+                self.icon = EricPixmapCache.getIcon("class_protected")
             else:
-                self.icon = UI.PixmapCache.getIcon("class")
+                self.icon = EricPixmapCache.getIcon("class")
         if self._classObject and (
             self._classObject.methods
             or self._classObject.classes
@@ -1619,28 +1612,22 @@ class BrowserMethodItem(BrowserItem):
         name = fn.name
         BrowserItem.__init__(self, parent, name)
 
-        import Utilities.ClassBrowsers.ClbrBaseClasses
+        from eric7.Utilities.ClassBrowsers import ClbrBaseClasses
 
         self.type_ = BrowserItemMethod
         self._name = name
         self._functionObject = fn
         self._filename = filename
-        if (
-            self._functionObject.modifier
-            == Utilities.ClassBrowsers.ClbrBaseClasses.Function.Static
-        ):
-            self.icon = UI.PixmapCache.getIcon("method_static")
-        elif (
-            self._functionObject.modifier
-            == Utilities.ClassBrowsers.ClbrBaseClasses.Function.Class
-        ):
-            self.icon = UI.PixmapCache.getIcon("method_class")
+        if self._functionObject.modifier == ClbrBaseClasses.Function.Static:
+            self.icon = EricPixmapCache.getIcon("method_static")
+        elif self._functionObject.modifier == ClbrBaseClasses.Function.Class:
+            self.icon = EricPixmapCache.getIcon("method_class")
         elif self._functionObject.isPrivate():
-            self.icon = UI.PixmapCache.getIcon("method_private")
+            self.icon = EricPixmapCache.getIcon("method_private")
         elif self._functionObject.isProtected():
-            self.icon = UI.PixmapCache.getIcon("method_protected")
+            self.icon = EricPixmapCache.getIcon("method_protected")
         else:
-            self.icon = UI.PixmapCache.getIcon("method")
+            self.icon = EricPixmapCache.getIcon("method")
         self.itemData[0] = "{0}({1})".format(
             name, ", ".join(self._functionObject.parameters)
         )
@@ -1753,9 +1740,9 @@ class BrowserClassAttributesItem(BrowserItem):
         self._populated = False
         self._lazyPopulation = True
         if isClass:
-            self.icon = UI.PixmapCache.getIcon("attributes_class")
+            self.icon = EricPixmapCache.getIcon("attributes_class")
         else:
-            self.icon = UI.PixmapCache.getIcon("attributes")
+            self.icon = EricPixmapCache.getIcon("attributes")
         self.__isClass = isClass
 
     def name(self):
@@ -1818,13 +1805,13 @@ class BrowserClassAttributeItem(BrowserItem):
         self._attributeObject = attribute
         self.__public = attribute.isPublic()
         if isClass:
-            self.icon = UI.PixmapCache.getIcon("attribute_class")
+            self.icon = EricPixmapCache.getIcon("attribute_class")
         elif attribute.isPrivate():
-            self.icon = UI.PixmapCache.getIcon("attribute_private")
+            self.icon = EricPixmapCache.getIcon("attribute_private")
         elif attribute.isProtected():
-            self.icon = UI.PixmapCache.getIcon("attribute_protected")
+            self.icon = EricPixmapCache.getIcon("attribute_protected")
         else:
-            self.icon = UI.PixmapCache.getIcon("attribute")
+            self.icon = EricPixmapCache.getIcon("attribute")
 
     def isPublic(self):
         """
@@ -1919,7 +1906,7 @@ class BrowserCodingItem(BrowserItem):
         BrowserItem.__init__(self, parent, text)
 
         self.type_ = BrowserItemCoding
-        self.icon = UI.PixmapCache.getIcon("textencoding")
+        self.icon = EricPixmapCache.getIcon("textencoding")
 
         self.__lineno = linenumber
 
@@ -1965,7 +1952,7 @@ class BrowserImportsItem(BrowserItem):
         BrowserItem.__init__(self, parent, text)
 
         self.type_ = BrowserItemImports
-        self.icon = UI.PixmapCache.getIcon("imports")
+        self.icon = EricPixmapCache.getIcon("imports")
 
     def lessThan(self, other, column, order):
         """
@@ -2006,9 +1993,9 @@ class BrowserImportItem(BrowserItem):
 
         self.type_ = BrowserItemImport
         if isModule:
-            self.icon = UI.PixmapCache.getIcon("importedModule")
+            self.icon = EricPixmapCache.getIcon("importedModule")
         else:
-            self.icon = UI.PixmapCache.getIcon("importedName")
+            self.icon = EricPixmapCache.getIcon("importedName")
 
     def fileName(self):
         """
