@@ -15,15 +15,15 @@ from PyQt6.QtCore import QTimer, QEvent, pyqtSlot
 from PyQt6.QtGui import QFontMetrics, QBrush, QTextCursor
 from PyQt6.QtWidgets import QWidget, QApplication, QDialogButtonBox
 
-from EricWidgets import EricMessageBox
-from EricWidgets.EricMainWindow import EricMainWindow
-from EricWidgets.EricPathPicker import EricPathPickerModes
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricMainWindow import EricMainWindow
+from eric7.EricWidgets.EricPathPicker import EricPathPickerModes
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
 from .Ui_CompareDialog import Ui_CompareDialog
 
-import Preferences
+from eric7 import Preferences
 
 
 def sbsdiff(a, b, linenumberwidth=4):
@@ -126,10 +126,10 @@ class CompareDialog(QWidget, Ui_CompareDialog):
         self.diffButton.setEnabled(False)
         self.diffButton.setDefault(True)
 
-        self.firstButton.setIcon(UI.PixmapCache.getIcon("2uparrow"))
-        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow"))
-        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow"))
-        self.lastButton.setIcon(UI.PixmapCache.getIcon("2downarrow"))
+        self.firstButton.setIcon(EricPixmapCache.getIcon("2uparrow"))
+        self.upButton.setIcon(EricPixmapCache.getIcon("1uparrow"))
+        self.downButton.setIcon(EricPixmapCache.getIcon("1downarrow"))
+        self.lastButton.setIcon(EricPixmapCache.getIcon("2downarrow"))
 
         self.totalLabel.setText(self.tr("Total: {0}").format(0))
         self.changedLabel.setText(self.tr("Changed: {0}").format(0))
