@@ -23,14 +23,13 @@ from PyQt6.QtWidgets import (
     QTreeWidgetItem,
 )
 
-from EricWidgets import EricMessageBox, EricFileDialog
-from EricGui.EricOverrideCursor import EricOverrideCursor
+from eric7.EricWidgets import EricMessageBox, EricFileDialog
+from eric7.EricGui.EricOverrideCursor import EricOverrideCursor
 
 from .Ui_EmailDialog import Ui_EmailDialog
 
 from .Info import BugAddress, FeatureAddress
-import Preferences
-import Utilities
+from eric7 import Preferences, Utilities
 
 from email.mime.text import MIMEText
 from email.mime.image import MIMEImage
@@ -160,18 +159,16 @@ class EmailDialog(QDialog, Ui_EmailDialog):
         """
         if self.__helpDialog is None:
             try:
-                from EricNetwork.EricGoogleMail import GoogleMailHelp
+                from eric7.EricNetwork.EricGoogleMail import GoogleMailHelp
 
                 helpStr = GoogleMailHelp()
             except ImportError:
-                from EricNetwork.EricGoogleMailHelpers import getInstallCommand
-
                 helpStr = self.tr(
                     "<p>The Google Mail Client API is not installed."
-                    " Use <code>{0}</code> to install it.</p>"
-                ).format(getInstallCommand())
+                    " Change to the Email configuration page for more.</p>"
+                )
 
-            from EricWidgets.EricSimpleHelpDialog import EricSimpleHelpDialog
+            from eric7.EricWidgets.EricSimpleHelpDialog import EricSimpleHelpDialog
 
             self.__helpDialog = EricSimpleHelpDialog(
                 title=self.tr("Gmail API Help"), helpStr=helpStr, parent=self
@@ -411,13 +408,23 @@ class EmailDialog(QDialog, Ui_EmailDialog):
         @param msg email message to be sent
         @type email.mime.text.MIMEBase
         """
-        from EricNetwork.EricGoogleMail import EricGoogleMail
+        try:
+            from eric7.EricNetwork.EricGoogleMail import EricGoogleMail
 
-        if self.__googleMail is None:
-            self.__googleMail = EricGoogleMail(self)
-            self.__googleMail.sendResult.connect(self.__gmailSendResult)
+            if self.__googleMail is None:
+                self.__googleMail = EricGoogleMail(self)
+                self.__googleMail.sendResult.connect(self.__gmailSendResult)
 
-        self.__googleMail.sendMessage(msg)
+            self.__googleMail.sendMessage(msg)
+        except ImportError:
+            EricMessageBox.critical(
+                self,
+                self.tr("Send Message"),
+                self.tr(
+                    "The Google Mail Client API is not installed. The message cannot be"
+                    " sent."
+                ),
+            )
 
     @pyqtSlot(bool, str)
     def __gmailSendResult(self, ok, message):
