@@ -27,10 +27,9 @@ from PyQt6.QtWidgets import (
     QToolTip,
 )
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
-import Utilities
-import Preferences
+from eric7 import Preferences, Utilities
 
 
 class PreviewerHTML(QWidget):
