@@ -22,9 +22,9 @@ from PyQt6.QtWidgets import (
 
 from asttokens import ASTTokens
 
-from EricGui.EricOverrideCursor import EricOverrideCursor
+from eric7.EricGui.EricOverrideCursor import EricOverrideCursor
 
-import Preferences
+from eric7 import Preferences
 
 
 class PythonAstViewer(QWidget):
