@@ -18,10 +18,10 @@ from PyQt6.QtCore import pyqtSlot, Qt, QTimer
 from PyQt6.QtGui import QBrush
 from PyQt6.QtWidgets import QTreeWidgetItem, QAbstractItemView, QWidget, QMenu
 
-from EricWidgets.EricApplication import ericApp
-from EricGui.EricOverrideCursor import EricOverrideCursor
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricGui.EricOverrideCursor import EricOverrideCursor
 
-import Preferences
+from eric7 import Preferences
 
 from .Ui_PythonDisViewer import Ui_PythonDisViewer
 
