@@ -13,9 +13,9 @@ from PyQt6.QtCore import pyqtSlot, Qt
 from PyQt6.QtGui import QGuiApplication
 from PyQt6.QtWidgets import QDialog, QDialogButtonBox
 
-from EricGui.EricOverrideCursor import EricOverrideCursor
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
+from eric7.EricGui.EricOverrideCursor import EricOverrideCursor
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
 
 from .Ui_VersionsDialog import Ui_VersionsDialog
 
