@@ -19,11 +19,9 @@ from PyQt6.QtCore import QProcess, pyqtSignal, QTimer, QThread
 from PyQt6.QtWidgets import QApplication
 from PyQt6.QtNetwork import QTcpServer, QHostAddress
 
-from EricWidgets import EricMessageBox
-from EricWidgets.EricApplication import ericApp
-import Preferences
-import Utilities
-import Globals
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7 import Globals, Preferences, Utilities
 
 
 class BackgroundService(QTcpServer):
@@ -278,7 +276,6 @@ class BackgroundService(QTcpServer):
                 else:
                     self.batchJobDone.emit(fx, lang)
                     self.restartService(lang, forceKill=True)
-                    # TODO: monitor this change
             else:
                 callback = self.services.get((fx, lang))
                 if callback:
