@@ -14,8 +14,8 @@ import sys
 import re
 from functools import reduce
 
-import Utilities
-import Utilities.ClassBrowsers as ClassBrowsers
+from eric7 import Utilities
+from eric7.Utilities import ClassBrowsers
 from . import ClbrBaseClasses
 
 TABWIDTH = 4
