@@ -9,7 +9,7 @@ Module implementing mimetype dependent functions.
 
 import mimetypes
 
-import Preferences
+from eric7 import Preferences
 
 
 def isTextFile(filename):
