@@ -20,7 +20,7 @@ import importlib.machinery
 import re
 import contextlib
 
-import Utilities
+from eric7 import Utilities
 from functools import reduce
 
 __all__ = [
