@@ -59,7 +59,7 @@ from PyQt6.QtCore import (
 from PyQt6.Qsci import QSCINTILLA_VERSION_STR, QsciScintilla
 
 # import these methods into the Utilities namespace
-from Globals import (  # __IGNORE_WARNING__
+from eric7.Globals import (  # __IGNORE_WARNING__
     isWindowsPlatform,
     isLinuxPlatform,
     isMacPlatform,
@@ -68,6 +68,7 @@ from Globals import (  # __IGNORE_WARNING__
     getConfigDir,
     setConfigDir,
     getPythonLibraryDirectory,
+    getPythonScriptsDirectory,
     getPyQt6ModulesDirectory,
     getQtBinariesPath,
     getPyQtToolsPath,
@@ -75,12 +76,12 @@ from Globals import (  # __IGNORE_WARNING__
     getPythonExecutable,
 )
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
-from UI.Info import Program, Version
+from eric7.UI.Info import Program, Version
 
-import Preferences
-from Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheck import (
+from eric7 import Preferences
+from eric7.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheck import (
     # __IGNORE_WARNING__
     normalizeCode,
 )
@@ -2071,7 +2072,7 @@ def generateVersionInfo(linesep="\n"):
     info.append("  sip {0}".format(sip_version_str))
     with contextlib.suppress(ImportError):
         from PyQt6 import QtWebEngineWidgets  # __IGNORE_WARNING__
-        from WebBrowser.Tools import WebBrowserTools
+        from eric7.WebBrowser.Tools import WebBrowserTools
 
         (
             chromiumVersion,
