@@ -15,7 +15,7 @@ the requested view manager type is not available, tabview will be used by
 default.
 """
 
-import Preferences
+from eric7 import Preferences
 
 ######################################################################
 ## Below is the factory function to instantiate the appropriate
