@@ -14,13 +14,13 @@ import os
 from PyQt6.QtCore import pyqtSlot
 from PyQt6.QtWidgets import QDialog, QDialogButtonBox
 
-from EricWidgets.EricPathPicker import EricPathPickerModes
+from eric7.EricWidgets.EricPathPicker import EricPathPickerModes
 
 from .Ui_VirtualenvInterpreterSelectionDialog import (
     Ui_VirtualenvInterpreterSelectionDialog,
 )
 
-import Globals
+from eric7 import Globals
 
 
 class VirtualenvInterpreterSelectionDialog(
