@@ -13,17 +13,16 @@ import contextlib
 from PyQt6.QtCore import pyqtSignal, QObject, QUrl, QUrlQuery, QByteArray, QMutex
 from PyQt6.QtWebEngineCore import QWebEngineUrlRequestInfo
 
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets import EricMessageBox
 
-from EricUtilities.EricMutexLocker import EricMutexLocker
+from eric7.EricUtilities.EricMutexLocker import EricMutexLocker
 
 from .AdBlockSubscription import AdBlockSubscription
 from .AdBlockUrlInterceptor import AdBlockUrlInterceptor
 from .AdBlockMatcher import AdBlockMatcher
 
-from Utilities.AutoSaver import AutoSaver
-import Utilities
-import Preferences
+from eric7.Utilities.AutoSaver import AutoSaver
+from eric7 import Preferences, Utilities
 
 
 class AdBlockManager(QObject):
@@ -84,7 +83,7 @@ class AdBlockManager(QObject):
 
         self.__interceptor = AdBlockUrlInterceptor(self)
 
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         WebBrowserWindow.networkManager().installUrlInterceptor(self.__interceptor)
 
@@ -92,7 +91,7 @@ class AdBlockManager(QObject):
         """
         Private slot handling a change of the AdBlock rules.
         """
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         WebBrowserWindow.mainWindow().reloadUserStyleSheet()
         self.__updateMatcher()
@@ -128,7 +127,7 @@ class AdBlockManager(QObject):
         if self.isEnabled() == enabled:
             return
 
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         self.__enabled = enabled
         for mainWindow in WebBrowserWindow.mainWindows():
@@ -349,7 +348,7 @@ class AdBlockManager(QObject):
         )
         if res:
             from .AdBlockSubscription import AdBlockSubscription
-            from WebBrowser.WebBrowserWindow import WebBrowserWindow
+            from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
             dlg = WebBrowserWindow.adBlockManager().showDialog()
             subscription = AdBlockSubscription(
@@ -663,7 +662,7 @@ class AdBlockManager(QObject):
         """
         Private slot to update the adblock matcher.
         """
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         WebBrowserWindow.networkManager().removeUrlInterceptor(self.__interceptor)
 
