@@ -27,7 +27,7 @@ class AdBlockPage(QObject):
         if page is None:
             return
 
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         manager = WebBrowserWindow.adBlockManager()
         if not manager.isEnabled():
