@@ -13,7 +13,7 @@ from enum import IntEnum
 from PyQt6.QtCore import Qt
 from PyQt6.QtWebEngineCore import QWebEngineUrlRequestInfo
 
-from EricNetwork import EricTldExtractor
+from eric7.EricNetwork import EricTldExtractor
 
 
 def toSecondLevelDomain(url):
