@@ -21,12 +21,12 @@ from PyQt6.QtCore import (
 )
 from PyQt6.QtWidgets import QMenu
 
-from EricWidgets.EricModelMenu import EricModelMenu
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricModelMenu import EricModelMenu
+from eric7.EricWidgets import EricMessageBox
 
 from .HistoryModel import HistoryModel
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
 
 class HistoryMenuModel(QAbstractProxyModel):
@@ -342,7 +342,7 @@ class HistoryMenu(EricModelMenu):
         @return flag indicating if any actions were added (boolean)
         """
         if self.__historyManager is None:
-            from WebBrowser.WebBrowserWindow import WebBrowserWindow
+            from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
             self.__historyManager = WebBrowserWindow.historyManager()
             self.__historyMenuModel = HistoryMenuModel(
@@ -376,16 +376,16 @@ class HistoryMenu(EricModelMenu):
             self.__mostVisitedMenu.newPrivateWindow.connect(self.newPrivateWindow)
         self.addMenu(self.__mostVisitedMenu)
         act = self.addMenu(self.__closedTabsMenu)
-        act.setIcon(UI.PixmapCache.getIcon("trash"))
+        act.setIcon(EricPixmapCache.getIcon("trash"))
         act.setEnabled(self.__tabWidget.canRestoreClosedTab())
         self.addSeparator()
 
         act = self.addAction(
-            UI.PixmapCache.getIcon("history"), self.tr("Show All History...")
+            EricPixmapCache.getIcon("history"), self.tr("Show All History...")
         )
         act.triggered.connect(self.showHistoryDialog)
         act = self.addAction(
-            UI.PixmapCache.getIcon("historyClear"), self.tr("Clear History...")
+            EricPixmapCache.getIcon("historyClear"), self.tr("Clear History...")
         )
         act.triggered.connect(self.__clearHistoryDialog)
 
@@ -436,16 +436,14 @@ class HistoryMenu(EricModelMenu):
         except AttributeError:
             maxWidth = fm.width("m") * 40
 
-        import WebBrowser.WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         self.__closedTabsMenu.clear()
         for index, tab in enumerate(
             self.__tabWidget.closedTabsManager().allClosedTabs()
         ):
             title = fm.elidedText(tab.title, Qt.TextElideMode.ElideRight, maxWidth)
-            act = self.__closedTabsMenu.addAction(
-                WebBrowser.WebBrowserWindow.WebBrowserWindow.icon(tab.url), title
-            )
+            act = self.__closedTabsMenu.addAction(WebBrowserWindow.icon(tab.url), title)
             act.setData(index)
             act.triggered.connect(
                 functools.partial(self.__tabWidget.restoreClosedTab, act)
@@ -527,7 +525,7 @@ class HistoryMostVisitedMenu(EricModelMenu):
         @return flag indicating if any actions were added (boolean)
         """
         if self.__historyMenuModel is None:
-            from WebBrowser.WebBrowserWindow import WebBrowserWindow
+            from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
             historyManager = WebBrowserWindow.historyManager()
             self.__historyMenuModel = HistoryMostVisitedMenuModel(
