@@ -28,11 +28,9 @@ class OpenSearchEngineAction(QAction):
 
         self.__engine = engine
         if self.__engine.networkAccessManager() is None:
-            import WebBrowser.WebBrowserWindow
+            from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
-            self.__engine.setNetworkAccessManager(
-                WebBrowser.WebBrowserWindow.WebBrowserWindow.networkManager()
-            )
+            self.__engine.setNetworkAccessManager(WebBrowserWindow.networkManager())
 
         self.setText(engine.name())
         self.__imageChanged()
@@ -45,12 +43,8 @@ class OpenSearchEngineAction(QAction):
         """
         image = self.__engine.image()
         if image.isNull():
-            import WebBrowser.WebBrowserWindow
+            from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
-            self.setIcon(
-                WebBrowser.WebBrowserWindow.WebBrowserWindow.icon(
-                    QUrl(self.__engine.imageUrl())
-                )
-            )
+            self.setIcon(WebBrowserWindow.icon(QUrl(self.__engine.imageUrl())))
         else:
             self.setIcon(QIcon(QPixmap.fromImage(image)))
