@@ -14,12 +14,11 @@ from PyQt6.QtCore import pyqtSignal, QObject, QUrl, QFile, QDir, QIODevice, QUrl
 from PyQt6.QtWidgets import QLineEdit, QInputDialog
 from PyQt6.QtNetwork import QNetworkRequest, QNetworkReply
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
 
-from Utilities.AutoSaver import AutoSaver
-import Utilities
-import Preferences
+from eric7.Utilities.AutoSaver import AutoSaver
+from eric7 import Preferences, Utilities
 
 
 class OpenSearchManager(QObject):
@@ -172,7 +171,7 @@ class OpenSearchManager(QObject):
         if not url.isValid():
             return False
 
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         reply = WebBrowserWindow.networkManager().get(QNetworkRequest(url))
         reply.finished.connect(lambda: self.__engineFromUrlAvailable(reply))
@@ -500,7 +499,7 @@ class OpenSearchManager(QObject):
                 return
         else:
             # some error happened
-            from WebBrowser.WebBrowserWindow import WebBrowserWindow
+            from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
             WebBrowserWindow.getWindow().statusBar().showMessage(
                 reply.errorString(), 10000
