@@ -37,11 +37,10 @@ from PyQt6.QtWidgets import (
     QVBoxLayout,
 )
 
-from EricWidgets import EricMessageBox
-from EricGui.EricOverrideCursor import EricOverrideCursor
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricGui.EricOverrideCursor import EricOverrideCursor
 
-import Utilities
-import Preferences
+from eric7 import Preferences, Utilities
 
 
 class SessionMetaData:
@@ -192,7 +191,7 @@ class SessionManager(QObject):
         @param startTimer flag indicating to restart the timer
         @type bool
         """
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         if not WebBrowserWindow.isPrivate():
             Preferences.setWebBrowser("SessionLastActivePath", self.__lastActiveSession)
@@ -208,7 +207,7 @@ class SessionManager(QObject):
         @param sessionFileName file name of the session
         @type str
         """
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         sessionData = {"Windows": []}
 
@@ -414,7 +413,7 @@ class SessionManager(QObject):
         if not sessionData or not sessionData["Windows"]:
             return
 
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         window = WebBrowserWindow.mainWindow()
 
@@ -445,7 +444,7 @@ class SessionManager(QObject):
         @type WebBrowserWindow
         @param sessionData dictionary containing the session data
         """
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         if window is None:
             window = WebBrowserWindow.mainWindow()
@@ -485,7 +484,7 @@ class SessionManager(QObject):
         @param flags flags determining a rename or clone operation
         @type int
         """
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         suggestedName = pathlib.Path(sessionFilePath).stem
         if flags & SessionManager.CloneSession:
@@ -551,7 +550,7 @@ class SessionManager(QObject):
         """
         Public method to save the current session.
         """
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         newName, ok = QInputDialog.getText(
             WebBrowserWindow.getWindow(),
@@ -593,7 +592,7 @@ class SessionManager(QObject):
         @return flag indicating success
         @rtype bool
         """
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         res = EricMessageBox.yesNo(
             WebBrowserWindow.getWindow(),
@@ -634,7 +633,7 @@ class SessionManager(QObject):
         @param sessionFilePath file name of the session file to be deleted
         @type str
         """
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         sfp = pathlib.Path(sessionFilePath)
         res = EricMessageBox.yesNo(
@@ -651,7 +650,7 @@ class SessionManager(QObject):
         """
         Public method to start a new session.
         """
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         newName, ok = QInputDialog.getText(
             WebBrowserWindow.getWindow(),
@@ -697,7 +696,7 @@ class SessionManager(QObject):
         """
         Public method to show the session manager dialog.
         """
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
         from .SessionManagerDialog import SessionManagerDialog
 
         dlg = SessionManagerDialog(WebBrowserWindow.getWindow())
@@ -710,7 +709,7 @@ class SessionManager(QObject):
         @return name of the session file to be restored
         @rtype str
         """
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         self.__fillMetaDataList()
 
