@@ -12,7 +12,7 @@ Module implementing the status bar icon base class.
 # Copyright (C) 2014  David Rosca <nowrep@gmail.com>
 #
 
-from EricWidgets.EricClickableLabel import EricClickableLabel
+from eric7.EricWidgets.EricClickableLabel import EricClickableLabel
 
 
 class StatusBarIcon(EricClickableLabel):
