@@ -11,7 +11,7 @@ from PyQt6.QtWidgets import QDialog
 
 from .Ui_VirusTotalWhoisDialog import Ui_VirusTotalWhoisDialog
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
 
 class VirusTotalWhoisDialog(QDialog, Ui_VirusTotalWhoisDialog):
@@ -36,5 +36,5 @@ class VirusTotalWhoisDialog(QDialog, Ui_VirusTotalWhoisDialog):
         self.headerLabel.setText(
             self.tr("<b>Whois information for domain {0}</b>").format(domain)
         )
-        self.headerPixmap.setPixmap(UI.PixmapCache.getPixmap("virustotal"))
+        self.headerPixmap.setPixmap(EricPixmapCache.getPixmap("virustotal"))
         self.whoisEdit.setPlainText(whois)
