@@ -28,17 +28,16 @@ try:
 except ImportError:
     SSL_AVAILABLE = False
 
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets import EricMessageBox
 
-from WebBrowser.WebBrowserWindow import WebBrowserWindow
+from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
 from .JavaScript.ExternalJsObject import ExternalJsObject
 
 from .Tools.WebHitTestResult import WebHitTestResult
 from .Tools import Scripts
 
-import Preferences
-import Globals
+from eric7 import Globals, Preferences
 
 
 class WebBrowserPage(QWebEnginePage):
@@ -81,7 +80,6 @@ class WebBrowserPage(QWebEnginePage):
 
         self.__printer = None
         self.__badSite = False
-        self.__registerProtocolHandlerRequest = None
 
         self.__view = view
 
@@ -177,7 +175,9 @@ class WebBrowserPage(QWebEnginePage):
 
         # Safe Browsing
         self.__badSite = False
-        from WebBrowser.SafeBrowsing.SafeBrowsingManager import SafeBrowsingManager
+        from eric7.WebBrowser.SafeBrowsing.SafeBrowsingManager import (
+            SafeBrowsingManager,
+        )
 
         if (
             SafeBrowsingManager.isEnabled()
@@ -547,42 +547,36 @@ class WebBrowserPage(QWebEnginePage):
         @param request reference to the registration request
         @type QWebEngineRegisterProtocolHandlerRequest
         """
-        from PyQt6.QtWebEngineCore import QWebEngineRegisterProtocolHandlerRequest
-
-        if self.__registerProtocolHandlerRequest:
-            del self.__registerProtocolHandlerRequest
-            self.__registerProtocolHandlerRequest = None
-        self.__registerProtocolHandlerRequest = (
-            QWebEngineRegisterProtocolHandlerRequest(request)
-        )
-
-    def registerProtocolHandlerRequestUrl(self):
-        """
-        Public method to get the registered protocol handler request URL.
-
-        @return registered protocol handler request URL
-        @rtype QUrl
-        """
-        if self.__registerProtocolHandlerRequest and (
-            self.url().host() == self.__registerProtocolHandlerRequest.origin().host()
-        ):
-            return self.__registerProtocolHandlerRequest.origin()
+        acceptRequest = Preferences.getWebBrowser("AcceptProtocolHandlerRequest")
+        # map yes/no/ask from (0, 1, 2)
+        if acceptRequest == 0:
+            # always yes
+            ok = True
+        elif acceptRequest == 1:
+            # always no
+            ok = False
         else:
-            return QUrl()
+            # ask user
+            ok = EricMessageBox.yesNo(
+                self,
+                self.tr("Register Protocol Handler"),
+                self.tr(
+                    "<p>Allow the Web Site <b>{0}</b> to handle all <b>{1}</b>"
+                    " links?</p>"
+                ).format(request.origin().host(), request.scheme()),
+            )
 
-    def registerProtocolHandlerRequestScheme(self):
-        """
-        Public method to get the registered protocol handler request scheme.
+        if ok:
+            if self.url().host() == request.origin().host():
+                url = request.origin()
+                scheme = request.scheme()
+            else:
+                url = QUrl()
+                scheme = ""
+            WebBrowserWindow.protocolHandlerManager().addProtocolHandler(scheme, url)
 
-        @return registered protocol handler request scheme
-        @rtype str
-        """
-        if self.__registerProtocolHandlerRequest and (
-            self.url().host() == self.__registerProtocolHandlerRequest.origin().host()
-        ):
-            return self.__registerProtocolHandlerRequest.scheme()
-        else:
-            return ""
+        # always reject the original request
+        request.reject()
 
     #############################################################
     ## SSL configuration handling below
@@ -650,7 +644,7 @@ class WebBrowserPage(QWebEnginePage):
         @type QPoint
         """
         if SSL_AVAILABLE and self.__sslConfiguration is not None:
-            from EricNetwork.EricSslInfoWidget import EricSslInfoWidget
+            from eric7.EricNetwork.EricSslInfoWidget import EricSslInfoWidget
 
             widget = EricSslInfoWidget(self.url(), self.__sslConfiguration, self.__view)
             widget.showAt(pos)
