@@ -14,21 +14,19 @@ from PyQt6.QtGui import QIcon, QPixmap, QPainter, QPageLayout
 from PyQt6.QtWidgets import QWidget, QHBoxLayout, QMenu, QToolButton, QDialog
 from PyQt6.QtPrintSupport import QPrinter, QPrintDialog, QAbstractPrintDialog
 
-from EricWidgets.EricTabWidget import EricTabWidget
-from EricWidgets import EricMessageBox
-from EricWidgets.EricApplication import ericApp
-from EricGui.EricOverrideCursor import EricOverrideCursor
+from eric7.EricWidgets.EricTabWidget import EricTabWidget
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricGui.EricOverrideCursor import EricOverrideCursor
 
 from .WebBrowserView import WebBrowserView
 from .WebBrowserPage import WebBrowserPage
 from .Tools import WebBrowserTools
 from . import WebInspector
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
-import Utilities
-import Preferences
-import Globals
+from eric7 import Globals, Preferences, Utilities
 
 
 def isCupsAvailable():
@@ -118,7 +116,7 @@ class WebBrowserTabWidget(EricTabWidget):
         self.__navigationMenu.triggered.connect(self.__navigationMenuTriggered)
 
         self.__navigationButton = QToolButton(self)
-        self.__navigationButton.setIcon(UI.PixmapCache.getIcon("1downarrow"))
+        self.__navigationButton.setIcon(EricPixmapCache.getIcon("1downarrow"))
         self.__navigationButton.setToolTip(self.tr("Show a navigation menu"))
         self.__navigationButton.setPopupMode(
             QToolButton.ToolButtonPopupMode.InstantPopup
@@ -131,7 +129,7 @@ class WebBrowserTabWidget(EricTabWidget):
         self.__closedTabsMenu.aboutToShow.connect(self.__aboutToShowClosedTabsMenu)
 
         self.__closedTabsButton = QToolButton(self)
-        self.__closedTabsButton.setIcon(UI.PixmapCache.getIcon("trash"))
+        self.__closedTabsButton.setIcon(EricPixmapCache.getIcon("trash"))
         self.__closedTabsButton.setToolTip(
             self.tr("Show a navigation menu for closed tabs")
         )
@@ -148,7 +146,7 @@ class WebBrowserTabWidget(EricTabWidget):
         self.setCornerWidget(self.__rightCornerWidget, Qt.Corner.TopRightCorner)
 
         self.__newTabButton = QToolButton(self)
-        self.__newTabButton.setIcon(UI.PixmapCache.getIcon("plus"))
+        self.__newTabButton.setIcon(EricPixmapCache.getIcon("plus"))
         self.__newTabButton.setToolTip(self.tr("Open a new web browser tab"))
         self.setCornerWidget(self.__newTabButton, Qt.Corner.TopLeftCorner)
         self.__newTabButton.clicked.connect(self.__newBrowser)
@@ -163,16 +161,16 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         self.__tabContextMenu = QMenu(self)
         self.tabContextNewAct = self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("tabNew"), self.tr("New Tab"), self.newBrowser
+            EricPixmapCache.getIcon("tabNew"), self.tr("New Tab"), self.newBrowser
         )
         self.__tabContextMenu.addSeparator()
         self.leftMenuAct = self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("1leftarrow"),
+            EricPixmapCache.getIcon("1leftarrow"),
             self.tr("Move Left"),
             self.__tabContextMenuMoveLeft,
         )
         self.rightMenuAct = self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("1rightarrow"),
+            EricPixmapCache.getIcon("1rightarrow"),
             self.tr("Move Right"),
             self.__tabContextMenuMoveRight,
         )
@@ -182,29 +180,29 @@ class WebBrowserTabWidget(EricTabWidget):
         )
         self.__tabContextMenu.addSeparator()
         self.tabContextCloseAct = self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("tabClose"),
+            EricPixmapCache.getIcon("tabClose"),
             self.tr("Close"),
             self.__tabContextMenuClose,
         )
         self.tabContextCloseOthersAct = self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("tabCloseOther"),
+            EricPixmapCache.getIcon("tabCloseOther"),
             self.tr("Close Others"),
             self.__tabContextMenuCloseOthers,
         )
         self.__tabContextMenu.addAction(self.tr("Close All"), self.closeAllBrowsers)
         self.__tabContextMenu.addSeparator()
         self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("printPreview"),
+            EricPixmapCache.getIcon("printPreview"),
             self.tr("Print Preview"),
             self.__tabContextMenuPrintPreview,
         )
         self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("print"),
+            EricPixmapCache.getIcon("print"),
             self.tr("Print"),
             self.__tabContextMenuPrint,
         )
         self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("printPdf"),
+            EricPixmapCache.getIcon("printPdf"),
             self.tr("Print as PDF"),
             self.__tabContextMenuPrintPdf,
         )
@@ -217,13 +215,13 @@ class WebBrowserTabWidget(EricTabWidget):
         else:
             self.__audioAct = None
         self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("reload"),
+            EricPixmapCache.getIcon("reload"),
             self.tr("Reload All"),
             self.reloadAllBrowsers,
         )
         self.__tabContextMenu.addSeparator()
         self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("addBookmark"),
+            EricPixmapCache.getIcon("addBookmark"),
             self.tr("Bookmark All Tabs"),
             self.__mainWindow.bookmarkAll,
         )
@@ -231,18 +229,18 @@ class WebBrowserTabWidget(EricTabWidget):
         self.__tabBackContextMenu = QMenu(self)
         self.__tabBackContextMenu.addAction(self.tr("Close All"), self.closeAllBrowsers)
         self.__tabBackContextMenu.addAction(
-            UI.PixmapCache.getIcon("reload"),
+            EricPixmapCache.getIcon("reload"),
             self.tr("Reload All"),
             self.reloadAllBrowsers,
         )
         self.__tabBackContextMenu.addAction(
-            UI.PixmapCache.getIcon("addBookmark"),
+            EricPixmapCache.getIcon("addBookmark"),
             self.tr("Bookmark All Tabs"),
             self.__mainWindow.bookmarkAll,
         )
         self.__tabBackContextMenu.addSeparator()
         self.__restoreClosedTabAct = self.__tabBackContextMenu.addAction(
-            UI.PixmapCache.getIcon("trash"), self.tr("Restore Closed Tab")
+            EricPixmapCache.getIcon("trash"), self.tr("Restore Closed Tab")
         )
         self.__restoreClosedTabAct.setEnabled(False)
         self.__restoreClosedTabAct.setData(0)
@@ -270,10 +268,10 @@ class WebBrowserTabWidget(EricTabWidget):
             if self.__audioAct is not None:
                 if self.widget(self.__tabContextMenuIndex).page().isAudioMuted():
                     self.__audioAct.setText(self.tr("Unmute Tab"))
-                    self.__audioAct.setIcon(UI.PixmapCache.getIcon("audioVolumeHigh"))
+                    self.__audioAct.setIcon(EricPixmapCache.getIcon("audioVolumeHigh"))
                 else:
                     self.__audioAct.setText(self.tr("Mute Tab"))
-                    self.__audioAct.setIcon(UI.PixmapCache.getIcon("audioVolumeMuted"))
+                    self.__audioAct.setIcon(EricPixmapCache.getIcon("audioVolumeMuted"))
 
             self.__tabContextMenu.popup(coord)
 
@@ -370,9 +368,9 @@ class WebBrowserTabWidget(EricTabWidget):
             painter = QPainter(pix)
             icon.paint(painter, 0, 0, 22, 22)
             if page.isAudioMuted():
-                audioIcon = UI.PixmapCache.getIcon("audioMuted")
+                audioIcon = EricPixmapCache.getIcon("audioMuted")
             else:
-                audioIcon = UI.PixmapCache.getIcon("audioPlaying")
+                audioIcon = EricPixmapCache.getIcon("audioPlaying")
             audioIcon.paint(painter, 13, 13, 18, 18)
             painter.end()
             self.setTabIcon(index, QIcon(pix))
@@ -416,13 +414,13 @@ class WebBrowserTabWidget(EricTabWidget):
 
         urlbar = UrlBar(self.__mainWindow, self)
         if self.__historyCompleter is None:
-            import WebBrowser.WebBrowserWindow
+            from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
             from .History.HistoryCompleter import (
                 HistoryCompletionModel,
                 HistoryCompleter,
             )
 
-            histMgr = WebBrowser.WebBrowserWindow.WebBrowserWindow.historyManager()
+            histMgr = WebBrowserWindow.historyManager()
             self.__historyCompletionModel = HistoryCompletionModel(self)
             self.__historyCompletionModel.setSourceModel(histMgr.historyFilterModel())
             self.__historyCompleter = HistoryCompleter(
@@ -927,7 +925,7 @@ class WebBrowserTabWidget(EricTabWidget):
             # page loading has started
             anim = self.animationLabel(index, "loadingAnimation", 40)
             if not anim:
-                self.setTabIcon(index, UI.PixmapCache.getIcon("loading"))
+                self.setTabIcon(index, EricPixmapCache.getIcon("loading"))
             else:
                 self.setTabIcon(index, QIcon())
             self.setTabText(index, self.tr("Loading..."))
@@ -936,12 +934,10 @@ class WebBrowserTabWidget(EricTabWidget):
 
             self.__mainWindow.setLoadingActions(True)
         elif progress == 100:
-            import WebBrowser.WebBrowserWindow
+            from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
             self.resetAnimation(index)
-            self.setTabIcon(
-                index, WebBrowser.WebBrowserWindow.WebBrowserWindow.icon(browser.url())
-            )
+            self.setTabIcon(index, WebBrowserWindow.icon(browser.url()))
             self.showMessage.emit(self.tr("Finished loading"))
 
             self.__mainWindow.setLoadingActions(False)
@@ -990,11 +986,11 @@ class WebBrowserTabWidget(EricTabWidget):
                 parent=self,
             )
             quitButton = mb.addButton(self.tr("&Quit"), EricMessageBox.AcceptRole)
-            quitButton.setIcon(UI.PixmapCache.getIcon("exit"))
+            quitButton.setIcon(EricPixmapCache.getIcon("exit"))
             closeTabButton = mb.addButton(
                 self.tr("C&lose Current Tab"), EricMessageBox.AcceptRole
             )
-            closeTabButton.setIcon(UI.PixmapCache.getIcon("tabClose"))
+            closeTabButton.setIcon(EricPixmapCache.getIcon("tabClose"))
             mb.addButton(EricMessageBox.Cancel)
             mb.exec()
             if mb.clickedButton() == quitButton:
