@@ -17,13 +17,10 @@ import sys
 import glob
 import fnmatch
 
-sys.path.insert(1, os.path.dirname(__file__))
-
-import Utilities.ModuleParser
-from DocumentationTools.APIGenerator import APIGenerator
-from UI.Info import Version
-import Utilities
-import DocumentationTools
+from eric7.Utilities import ModuleParser
+from eric7.DocumentationTools.APIGenerator import APIGenerator
+from eric7.UI.Info import Version
+from eric7 import DocumentationTools, Utilities
 
 
 def usage():
@@ -292,7 +289,7 @@ def main():
                         continue
 
                     try:
-                        module = Utilities.ModuleParser.readModule(
+                        module = ModuleParser.readModule(
                             file,
                             basename=basename,
                             inpackage=inpackage,
