@@ -95,8 +95,8 @@ def windowsDesktopEntries():
     iconsDir = os.path.join(os.path.dirname(eric7.__file__), "pixmaps")
     entriesTemplates = [
         (
-            "eric7 (Python {0}.{1}).lnk",
-            os.path.join(scriptsDir, "eric7.exe"),
+            "eric7 IDE (Python {0}.{1}).lnk",
+            os.path.join(scriptsDir, "eric7_ide.exe"),
             os.path.join(iconsDir, "eric7.ico"),
         ),
         (
@@ -156,11 +156,12 @@ def copyLinuxMetaData():
     """
     import eric7
 
+    ericDir = os.path.dirname(eric7.__file__)
     scriptsDir = sysconfig.get_path("scripts")
     dstDir = os.path.join(os.path.expanduser("~"), ".local", "share")
-    iconsDir = os.path.join(os.path.dirname(eric7.__file__), "pixmaps")
-    svgIconsDir = os.path.join(os.path.dirname(eric7.__file__), "icons", "breeze-dark")
-    linuxDir = os.path.join(os.path.dirname(eric7.__file__), "data", "linux")
+    iconsDir = os.path.join(ericDir, "pixmaps")
+    svgIconsDir = os.path.join(ericDir, "icons", "breeze-dark")
+    linuxDir = os.path.join(ericDir, "data", "linux")
 
     for metaDir in ["appdata", "metainfo"]:
         copyMetaFile(
@@ -186,7 +187,7 @@ def copyLinuxMetaData():
         "ericWeb.png",
     )
 
-    for desktop in ["eric7.desktop", "eric7_browser.desktop"]:
+    for desktop in ["eric7_ide.desktop", "eric7_browser.desktop"]:
         copyDesktopFile(
             os.path.join(linuxDir, desktop),
             os.path.join(dstDir, "applications"),
